@@ -131,22 +131,25 @@ namespace Magick
   using MagickLib::MatteChannel;
   
   // Color-space types
+  using MagickLib::CMYKColorspace;
   using MagickLib::ColorspaceType;
-  using MagickLib::UndefinedColorspace;
-  using MagickLib::RGBColorspace;
   using MagickLib::GRAYColorspace;
-  using MagickLib::TransparentColorspace;
+  using MagickLib::HSLColorspace;
+  using MagickLib::HWBColorspace;
+  using MagickLib::LABColorspace;
   using MagickLib::OHTAColorspace;
+  using MagickLib::Rec601LumaColorspace;
+  using MagickLib::Rec709LumaColorspace;
+  using MagickLib::RGBColorspace;
+  using MagickLib::sRGBColorspace;
+  using MagickLib::TransparentColorspace;
+  using MagickLib::UndefinedColorspace;
   using MagickLib::XYZColorspace;
   using MagickLib::YCbCrColorspace;
   using MagickLib::YCCColorspace;
   using MagickLib::YIQColorspace;
   using MagickLib::YPbPrColorspace;
   using MagickLib::YUVColorspace;
-  using MagickLib::CMYKColorspace;
-  using MagickLib::sRGBColorspace;
-  using MagickLib::HSLColorspace;
-  using MagickLib::HWBColorspace;
   
   // Composition operations
   using MagickLib::AddCompositeOp;
