@@ -323,6 +323,12 @@ $example->Label('Shear');
 $example->Shear('-20x20');
 push(@$images,$example);
 
+print "Sigmoidal Contrast...\n";
+$example=$model->Clone();
+$example->Label('Sigmoidal Contrast');
+$example->SigmoidalContrast("3x50%");
+push(@$images,$example);
+
 print "Spread...\n";
 $example=$model->Clone();
 $example->Label('Spread');
