@@ -141,12 +141,19 @@ register IndexPacket *indexes;
 static Image *ReadARTImage(const ImageInfo *image_info,ExceptionInfo *exception)
 {
   Image *image;
-  int i;
   unsigned long width,height,dummy;
   long ldblk;
   unsigned char *BImgBuff=NULL;
   unsigned char k;
-  MagickBooleanType status;
+
+  MagickBooleanType
+    status;
+
+  register long
+    i;
+
+  ssize_t
+    count;
 
   /*
     Open image file.
@@ -190,14 +197,18 @@ static Image *ReadARTImage(const ImageInfo *image_info,ExceptionInfo *exception)
  if (BImgBuff==NULL)
 NoMemory:
   ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
- for (i=0;i< (int) height;i++)
-      {
-      (void) ReadBlob(image,(size_t) ldblk,BImgBuff);
-      (void) ReadBlob(image,(size_t) k,(unsigned char *) &dummy);
-      InsertRow(BImgBuff,i,image);
-      }
+  for (i=0; i < (int) height; i++)
+  {
+    count=ReadBlob(image,(size_t) ldblk,BImgBuff);
+    if (count != (ssize_t) ldblk)
+      break;
+    count=ReadBlob(image,(size_t) k,(unsigned char *) &dummy);
+    if (count != (ssize_t) k)
+      break;
+    InsertRow(BImgBuff,i,image);
+  }
   BImgBuff=(unsigned char *) RelinquishMagickMemory(BImgBuff);
-  if (EOFBlob(image) != MagickFalse)
+  if (i < (long) height)
     ThrowFileException(exception,CorruptImageError,"UnexpectedEndOfFile",
       image->filename);
   CloseBlob(image);
