@@ -24,7 +24,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -1130,7 +1130,7 @@ static Image *ReadAVIImage(const ImageInfo *image_info,ExceptionInfo *exception)
   for ( ; ; )
   {
     count=ReadBlob(image,4,(unsigned char *) id);
-    if (count == 0)
+    if (count != 4)
       break;
     id[4]='\0';
     chunk_size=ReadBlobLSBLong(image);
@@ -1138,6 +1138,8 @@ static Image *ReadAVIImage(const ImageInfo *image_info,ExceptionInfo *exception)
       break;
     if ((chunk_size & 0x01) != 0)
       chunk_size++;
+    if ((GetBlobSize(image) != 0) && (chunk_size > GetBlobSize(image)))
+      ThrowReaderException(CorruptImageError,"NotEnoughPixelData");
     if (image_info->verbose != MagickFalse)
       {
         (void) fprintf(stdout,"AVI cid %s\n",id);
@@ -1626,7 +1628,12 @@ LosslessJPEGCompression : JPEGCompression;
             Max(bytes_per_line,image->columns+1)*image->rows);
 
           if (LocaleCompare(id,"00db") == 0)
-            (void) ReadBlob(image,(size_t) bytes_per_line*image->rows,pixels);
+            {
+              count=ReadBlob(image,(size_t) bytes_per_line*image->rows,pixels);
+              if (count != (ssize_t) (bytes_per_line*image->rows))
+                ThrowReaderException(CorruptImageError,
+                  "InsufficientImageDataInFile");
+            }
           else
             {
               status=DecodeImage(image,MagickTrue,pixels);
@@ -1912,7 +1919,7 @@ LosslessJPEGCompression : JPEGCompression;
         /*
           List of chunks.
         */
-        (void) ReadBlob(image,4,(unsigned char *) id);
+        count=ReadBlob(image,4,(unsigned char *) id);
         if (image_info->verbose != MagickFalse)
           (void) fprintf(stdout,"  List type %s\n",id);
         continue;
@@ -1922,7 +1929,7 @@ LosslessJPEGCompression : JPEGCompression;
         /*
           File header.
         */
-        (void) ReadBlob(image,4,(unsigned char *) id);
+        count=ReadBlob(image,4,(unsigned char *) id);
         if (image_info->verbose != MagickFalse)
           (void) fprintf(stdout,"  RIFF form type %s\n",id);
         continue;
@@ -1941,7 +1948,7 @@ LosslessJPEGCompression : JPEGCompression;
             bmp_info.height=ReadBlobLSBLong(image);
             bmp_info.planes=ReadBlobLSBShort(image);
             bmp_info.bits_per_pixel=ReadBlobLSBShort(image);
-            (void) ReadBlob(image,4,(unsigned char *) bmp_info.compression);
+            count=ReadBlob(image,4,(unsigned char *) bmp_info.compression);
             bmp_info.compression[4]='\0';
             bmp_info.image_size=ReadBlobLSBLong(image);
             bmp_info.x_pixels=ReadBlobLSBLong(image);
@@ -1983,9 +1990,9 @@ LosslessJPEGCompression : JPEGCompression;
       {
         if (image_info->verbose != MagickFalse)
           (void) fprintf(stdout,"  Stream header\n");
-        (void) ReadBlob(image,4,(unsigned char *) stream_info.data_type);
+        count=ReadBlob(image,4,(unsigned char *) stream_info.data_type);
         stream_info.data_type[4]='\0';
-        (void) ReadBlob(image,4,(unsigned char *) stream_info.data_handler);
+        count=ReadBlob(image,4,(unsigned char *) stream_info.data_handler);
         stream_info.data_handler[4]='\0';
         stream_info.flags=ReadBlobLSBLong(image);
         stream_info.priority=ReadBlobLSBLong(image);
