@@ -24,7 +24,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -569,7 +569,7 @@ static Image *ReadBMPImage(const ImageInfo *image_info,ExceptionInfo *exception)
       bmp_info.ba_offset=ReadBlobLSBLong(image);
       bmp_info.offset_bits=ReadBlobLSBLong(image);
       count=ReadBlob(image,2,magick);
-      if (count == 0)
+      if (count != 2)
         break;
     }
     if (image->debug != MagickFalse)
@@ -844,7 +844,9 @@ static Image *ReadBMPImage(const ImageInfo *image_info,ExceptionInfo *exception)
         else
           packet_size=4;
         (void) SeekBlob(image,start_position+14+bmp_info.size,SEEK_SET);
-        (void) ReadBlob(image,packet_size*image->colors,bmp_colormap);
+        count=ReadBlob(image,packet_size*image->colors,bmp_colormap);
+        if (count != (ssize_t) (packet_size*image->colors))
+          ThrowReaderException(CorruptImageError,"InsufficientImageDataInFile");
         p=bmp_colormap;
         for (i=0; i < (long) image->colors; i++)
         {
@@ -877,7 +879,9 @@ static Image *ReadBMPImage(const ImageInfo *image_info,ExceptionInfo *exception)
         if (image->debug != MagickFalse)
           (void) LogMagickEvent(CoderEvent,GetMagickModule(),
             "  Reading pixels (%ld bytes)",(long) length);
-        (void) ReadBlob(image,length,pixels);
+        count=ReadBlob(image,length,pixels);
+        if (count != (ssize_t) length)
+          ThrowReaderException(CorruptImageError,"InsufficientImageDataInFile");
       }
     else
       {
@@ -1277,8 +1281,8 @@ static Image *ReadBMPImage(const ImageInfo *image_info,ExceptionInfo *exception)
     *magick='\0';
     if (bmp_info.ba_offset != 0)
       (void) SeekBlob(image,(MagickOffsetType) bmp_info.ba_offset,SEEK_SET);
-    (void) ReadBlob(image,2,magick);
-    if (IsBMP(magick,2) != MagickFalse)
+    count=ReadBlob(image,2,magick);
+    if ((count == 2) && (IsBMP(magick,2) != MagickFalse))
       {
         /*
           Acquire next image structure.
