@@ -26,7 +26,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -188,7 +188,7 @@ static Image *ReadCINImage(const ImageInfo *image_info,
     Read CIN image.
   */
   count=ReadBlob(image,4,(unsigned char *) magick);
-  if ((count == 0) ||
+  if ((count != 4) ||
       ((LocaleNCompare((char *) magick,"\200\052\137\327",4) != 0)))
     ThrowReaderException(CorruptImageError,"ImproperImageHeader");
   headersize=ReadBlobMSBLong(image);
@@ -199,8 +199,8 @@ static Image *ReadCINImage(const ImageInfo *image_info,
     (void) ReadBlobByte(image);
   image->depth=ReadBlobByte(image) > 8 ? 16UL  : 8UL;
   (void) ReadBlobByte(image);
-  image->columns= ReadBlobMSBLong(image);
-  image->rows= ReadBlobMSBLong(image);
+  image->columns=ReadBlobMSBLong(image);
+  image->rows=ReadBlobMSBLong(image);
   (void) SeekBlob(image,(MagickOffsetType) headersize,SEEK_SET);
   if (image_info->ping)
     {
@@ -365,6 +365,10 @@ static MagickBooleanType WriteCINImage(const ImageInfo *image_info,Image *image)
   MagickBooleanType
     status;
 
+  PixelPacket
+    max_color,
+    min_color;
+
   register const PixelPacket
     *p;
 
@@ -375,44 +379,6 @@ static MagickBooleanType WriteCINImage(const ImageInfo *image_info,Image *image)
   unsigned long
     pixel;
 
-  unsigned long
-    maxb,
-    maxg,
-    maxr,
-    minb,
-    ming,
-    minr;
-
-  /*
-    Get the max values for each component... I guess it "needs" it...
-  */
-  maxr=maxg=maxb=0;
-  minr=ming=minb=MaxRGB;
-  for (y=0; y < (long) image->rows; y++)
-  {
-    p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
-    if (p == (const PixelPacket *) NULL)
-      break;
-    for (x=0; x < (long) image->columns; x++)
-    {
-      if ( (unsigned long) p->red > maxr ) maxr = p->red;
-      if ( (unsigned long) p->green > maxg ) maxg = p->green;
-      if ( (unsigned long) p->blue > maxb ) maxb = p->blue;
-      if ( (unsigned long) p->red < minr ) minr = p->red;
-      if ( (unsigned long) p->green < ming ) ming = p->green;
-      if ( (unsigned long) p->blue < minb ) minb = p->blue;
-      p++;
-    }
-  }
-  /*
-    Div by 64 to get 10bit values since that's all I'll do right now.
-  */
-  maxr/=64;
-  maxg/=64;
-  maxb/=64;
-  minr/=64;
-  ming/=64;
-  minb/=64;
   /*
     Open output image file.
   */
@@ -425,165 +391,168 @@ static MagickBooleanType WriteCINImage(const ImageInfo *image_info,Image *image)
   status=OpenBlob(image_info,image,WriteBinaryBlobMode,&image->exception);
   if (status == MagickFalse)
     return(status);
-  /* Magick Number... */
   (void) SetImageColorspace(image,RGBColorspace);
-  (void) WriteBlobMSBLong(image,0x802A5FD7UL);
-  /* Offset to image */
-  (void) WriteBlobMSBLong(image,0x0800);
-  /* Generic section header length */
-  (void) WriteBlobMSBLong(image,0x400);
-  /* Industry Specific lenght */
-  (void) WriteBlobMSBLong(image,0x400);
-  /* variable length section */
+  /*
+    Compute range for each color component (10-bits).
+  */
+  max_color.red=0;
+	max_color.green=0;
+	max_color.blue=0;
+  min_color.red=MaxRGB;
+	min_color.green=MaxRGB;
+	min_color.blue=MaxRGB;
+  for (y=0; y < (long) image->rows; y++)
+  {
+    p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
+    if (p == (const PixelPacket *) NULL)
+      break;
+    for (x=0; x < (long) image->columns; x++)
+    {
+      if (p->red > max_color.red)
+        max_color.red=p->red;
+      if (p->green > max_color.green)
+        max_color.green=p->green;
+      if (p->blue > max_color.blue)
+        max_color.blue=p->blue;
+      if (p->red < min_color.red)
+        min_color.red=p->red;
+      if (p->green < min_color.green)
+        min_color.green=p->green;
+      if (p->blue < min_color.blue)
+        min_color.blue=p->blue;
+      p++;
+    }
+  }
+  max_color.red/=64;
+  max_color.green/=64;
+  max_color.blue/=64;
+  min_color.red/=64;
+  min_color.green/=64;
+  min_color.blue/=64;
+  /*
+    Write image header.
+  */
+  (void) WriteBlobMSBLong(image,0x802A5FD7UL);  /* magick number */
+  (void) WriteBlobMSBLong(image,0x0800);  /* Offset to image */
+  (void) WriteBlobMSBLong(image,0x400);  /* Generic section header length */
+  (void) WriteBlobMSBLong(image,0x400);  /* Industry Specific lenght */
+  (void) WriteBlobMSBLong(image,0x0);  /* variable length section */
+  (void) WriteBlobMSBLong(image,4*image->columns*image->rows+0x2000);  /* total image file size */
+  (void) WriteBlobString(image,"V4.5");  /* version */
   (void) WriteBlobMSBLong(image,0x0);
-  /* Total image file size */
-  (void) WriteBlobMSBLong(image,4*image->columns*image->rows+0x2000);
-  /* Version number of header format */
-  (void) WriteBlobString(image,"V4.5");
-  (void) WriteBlobMSBLong(image,0x0);
-  /* Filename */
   (void) WriteBlobString(image,image->filename);
-  for ( i =0 ; i < (long) (100-strlen(image->filename)); i++ )
+  for (i=0 ; i < (long) (100-strlen(image->filename)); i++ )
     (void) WriteBlobByte(image,0);
-  /* Creation Date. */
-  (void) WriteBlobString(image,"yyyy:mm:dd  ");
-  /* Creation Time. */
-  (void) WriteBlobString(image,"hh:mm:ssxxx ");
-  for ( i =0 ; i < 36 ; i++)
+  (void) WriteBlobString(image,"yyyy:mm:dd  ");  /* creation date. */
+  (void) WriteBlobString(image,"hh:mm:ssxxx ");  /* creation time. */
+  for (i=0 ; i < 36 ; i++)
     (void) WriteBlobByte(image,0);
-  /* 0 left to right top to bottom */
-  (void) WriteBlobByte(image,0);
-  /* 3 channels */
-  (void) WriteBlobByte(image,3);
-  /* alignment */
-  (void) WriteBlobByte(image,0x0);
-  (void) WriteBlobByte(image,0x0);
-  /* Do R */
-  /* Channel 1 designator byte 0 */
-  (void) WriteBlobByte(image,0);
-  /* Channel 1 designator byte 1 */
-  (void) WriteBlobByte(image,1);
-  /* Bits per pixel... */
-  (void) WriteBlobByte(image,10);
-  /* alignment */
-  (void) WriteBlobByte(image,0);
-  /* pixels per line */
-  (void) WriteBlobMSBLong(image,image->columns);
-  /* lines per image */
-  (void) WriteBlobMSBLong(image,image->rows);
-  /* Minimum data value */
-  (void) WriteBlobMSBLong(image,minr);
-  /* Minimum quantity represented */
-  (void) WriteBlobMSBLong(image,0x0);
-  /* Maximum data value */
-  (void) WriteBlobMSBLong(image,maxr);
-  /* Maximum quantity represented */
-  (void) WriteBlobMSBLong(image,0x40000000);
-  /* Do G */
-  /* see above. */
-  (void) WriteBlobByte(image,0);
+  (void) WriteBlobByte(image,0);  /* 0 left to right top to bottom */
+  (void) WriteBlobByte(image,3);  /* 3 channels */
+  (void) WriteBlobByte(image,0x0);  /* alignment */
+  (void) WriteBlobByte(image,0x0);  /* red */
+  (void) WriteBlobByte(image,0);  /* Channel 1 designator byte 0 */
+  (void) WriteBlobByte(image,1);  /* Channel 1 designator byte 1 */
+  (void) WriteBlobByte(image,10);  /* Bits per pixel... */
+  (void) WriteBlobByte(image,0);  /* alignment */
+  (void) WriteBlobMSBLong(image,image->columns);  /* pixels per line */
+  (void) WriteBlobMSBLong(image,image->rows);  /* lines per image */
+  (void) WriteBlobMSBLong(image,min_color.red);  /* Minimum data value */
+  (void) WriteBlobMSBLong(image,0x0);  /* Minimum quantity represented */
+  (void) WriteBlobMSBLong(image,max_color.red);  /* Maximum data value */
+  (void) WriteBlobMSBLong(image,0x40000000);  /* Maximum quantity represented */
+  (void) WriteBlobByte(image,0);  /* green */
   (void) WriteBlobByte(image,2);
   (void) WriteBlobByte(image,10);
   (void) WriteBlobByte(image,0);
   (void) WriteBlobMSBLong(image,image->columns);
   (void) WriteBlobMSBLong(image,image->rows);
-  (void) WriteBlobMSBLong(image,ming);
+  (void) WriteBlobMSBLong(image,min_color.green);
   (void) WriteBlobMSBLong(image,0x0);
-  (void) WriteBlobMSBLong(image,maxg);
+  (void) WriteBlobMSBLong(image,max_color.green);
   (void) WriteBlobMSBLong(image,0x40000000);
-  /* Go B */
-  /* see above. */
-  (void) WriteBlobByte(image,0);
+  (void) WriteBlobByte(image,0);  /* blue */
   (void) WriteBlobByte(image,3);
   (void) WriteBlobByte(image,10);
   (void) WriteBlobByte(image,0);
   (void) WriteBlobMSBLong(image,image->columns);
   (void) WriteBlobMSBLong(image,image->rows);
-  (void) WriteBlobMSBLong(image,minb);
+  (void) WriteBlobMSBLong(image,min_color.blue);
   (void) WriteBlobMSBLong(image,0x0);
-  (void) WriteBlobMSBLong(image,maxb);
+  (void) WriteBlobMSBLong(image,max_color.blue);
   (void) WriteBlobMSBLong(image,0x40000000);
-  /* pad channel 4-8 */
-  for (i=0; i < 5*28; i++)
+  /*
+	  Pad channel 4-8.
+  */
+  for (i=0; i < (5*28); i++)
     (void) WriteBlobByte(image,0x00);
-  /* k here's where it gets ugly and I should be shot */
-  /* White point(colour temp.) x */
-  (void) WriteBlobMSBLong(image,0x4EFF0000);
-  /* White point(colour temp.) y */
-  (void) WriteBlobMSBLong(image,0x4EFF0000);
-  /* Red primary chromaticity x */
-  (void) WriteBlobMSBLong(image,0x4EFF0000);
-  /* Red primary chromaticity y */
-  (void) WriteBlobMSBLong(image,0x4EFF0000);
-  /* Green primary chromaticity x */
-  (void) WriteBlobMSBLong(image,0x4EFF0000);
-  /* Green primary chromaticity y */
-  (void) WriteBlobMSBLong(image,0x4EFF0000);
-  /* Blue primary chromaticity x */
-  (void) WriteBlobMSBLong(image,0x4EFF0000);
-  /* Blue primary chromaticity y */
-  (void) WriteBlobMSBLong(image,0x4EFF0000);
-  /* Label Text... */
-  for (i=0; i < 200+28; i++)
+  (void) WriteBlobMSBLong(image,0x4EFF0000);  /* White point(colour temp.) x */
+  (void) WriteBlobMSBLong(image,0x4EFF0000);  /* White point(colour temp.) y */
+  (void) WriteBlobMSBLong(image,0x4EFF0000);  /* Red primary chromaticity x */
+  (void) WriteBlobMSBLong(image,0x4EFF0000);  /* Red primary chromaticity y */
+  (void) WriteBlobMSBLong(image,0x4EFF0000);  /* Green primary chromaticity x */
+  (void) WriteBlobMSBLong(image,0x4EFF0000);  /* Green primary chromaticity y */
+  (void) WriteBlobMSBLong(image,0x4EFF0000);  /* Blue primary chromaticity x */
+  (void) WriteBlobMSBLong(image,0x4EFF0000);  /* Blue primary chromaticity y */
+  /*
+    Label text.
+  */
+  for (i=0; i < (200+28); i++)
     (void) WriteBlobByte(image,0x00);
-  /* pixel interleave (rgbrgbr...) */
-  (void) WriteBlobByte(image,0);
-  /* Packing longword (32bit) boundaries */
-  (void) WriteBlobByte(image,5);
-  /* Data unsigned */
-  (void) WriteBlobByte(image,0);
-  /* Image sense: positive image */
-  (void) WriteBlobByte(image,0);
-  /* End of line padding */
-  (void) WriteBlobMSBLong(image,0x0);
-  /* End of channel padding */
-  (void) WriteBlobMSBLong(image,0x0);
-  /* Reseved for future Use.. */
+  (void) WriteBlobByte(image,0);  /* pixel interleave (rgbrgbr...) */
+  (void) WriteBlobByte(image,5);  /* packing longword (32bit) boundaries */
+  (void) WriteBlobByte(image,0);  /* data unsigned */
+  (void) WriteBlobByte(image,0);  /* image sense: positive image */
+  (void) WriteBlobMSBLong(image,0x0);  /* end of line padding */
+  (void) WriteBlobMSBLong(image,0x0);  /* end of channel padding */
+  /*
+    Reseved for future Use.
+  */
   for (i=0; i < 20; i++)
     (void) WriteBlobByte(image,0x00);
-  /* X offset */
-  (void) WriteBlobMSBLong(image,0x0);
-  /* Y offset */
-  (void) WriteBlobMSBLong(image,0x0);
-  /* Filename */
+  (void) WriteBlobMSBLong(image,0x0);  /* x offset */
+  (void) WriteBlobMSBLong(image,0x0);  /* y offset */
   (void) WriteBlobString(image,image->filename);
-  for ( i =0 ; i < (long) (100-strlen(image->filename)); i++ )
+  for (i=0 ; i < (long) (100-strlen(image->filename)); i++ )
     (void) WriteBlobByte(image,0);
-  /* date. who cares ? */
-  for ( i =0 ; i < 12 ; i++ )
+  /*
+    Date.
+  */
+  for (i=0 ; i < 12; i++ )
     (void) WriteBlobByte(image,0);
-  /* time who cares ? */
-  for ( i =0 ; i < 12 ; i++ )
+  /*
+    Time.
+  */
+  for (i =0 ; i < 12; i++ )
     (void) WriteBlobByte(image,0);
   (void) WriteBlobString(image,"ImageMagick");
-  for (i = 0; i < 64-11 ; i++)
+  for (i=0; i < (64-11); i++)
     (void) WriteBlobByte(image,0);
-  for (i = 0; i < 32 ; i++)
+  for (i=0; i < 32; i++)
     (void) WriteBlobByte(image,0);
-  for (i = 0; i < 32 ; i++)
+  for (i=0; i < 32; i++)
     (void) WriteBlobByte(image,0);
-  /* X input device pitch */
-  (void) WriteBlobMSBLong(image,0x4326AB85);
-  /* Y input device pitch */
-  (void) WriteBlobMSBLong(image,0x4326AB85);
-  /* Image gamma */
-  (void) WriteBlobMSBLong(image,0x3F800000);
-  /* Reserved for future use */
-  for (i = 0; i < 40 ; i++)
+  (void) WriteBlobMSBLong(image,0x4326AB85);  /* X input device pitch */
+  (void) WriteBlobMSBLong(image,0x4326AB85);  /* Y input device pitch */
+  (void) WriteBlobMSBLong(image,0x3F800000);  /* Image gamma */
+  /*
+    Reserved for future use.
+  */
+  for (i=0; i < 40; i++)
     (void) WriteBlobByte(image,0);
-  for ( i = 0 ; i < 4 ; i++)
+  for (i=0 ; i < 4; i++)
     (void) WriteBlobByte(image,0);
   (void) WriteBlobMSBLong(image,0x0);
   (void) WriteBlobMSBLong(image,0x0);
-  for ( i = 0 ; i < 32 ; i++)
+  for (i=0 ; i < 32; i++)
     (void) WriteBlobByte(image,0);
   (void) WriteBlobMSBLong(image,0x0);
   (void) WriteBlobMSBLong(image,0x0);
-  for ( i = 0 ; i < 32 ; i++)
+  for (i=0 ; i < 32; i++)
     (void) WriteBlobByte(image,0);
-  for ( i = 0 ; i < 200 ; i++)
+  for (i=0 ; i < 200; i++)
     (void) WriteBlobByte(image,0);
-  for ( i = 0 ; i < 740 ; i++)
+  for (i=0 ; i < 740; i++)
     (void) WriteBlobByte(image,0);
   /*
     Convert pixel packets to CIN raster image.
