@@ -22,7 +22,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -186,7 +186,7 @@ static MagickBooleanType WriteCIPImage(const ImageInfo *image_info,Image *image)
   if (status == MagickFalse)
     return(status);
   (void) WriteBlobString(image,"<CiscoIPPhoneImage>\n");
-  attribute=GetImageAttribute(image,"label");
+  attribute=GetImageAttribute(image,"Label");
   if (attribute != (const ImageAttribute *) NULL)
     (void) FormatMagickString(buffer,MaxTextExtent,"<Title>%s</Title>\n",
       attribute->value);
