@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -54,6 +54,7 @@
 #include "magick/monitor.h"
 #include "magick/pixel.h"
 #include "magick/static.h"
+#include "magick/statistic.h"
 #include "magick/string_.h"
 #include "magick/utility.h"
 
@@ -170,7 +171,11 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
       */
       image->scene++;
       for (y=0; y < (long) image->rows; y++)
-        (void) ReadBlob(image,packet_size*image->extract_info.width,scanline);
+      {
+        count=ReadBlob(image,packet_size*image->extract_info.width,scanline);
+        if (count != (ssize_t) (packet_size*image->extract_info.width))
+          ThrowReaderException(CorruptImageError,"InsufficientImageDataInFile");
+      }
     }
   offset=(MagickOffsetType) (packet_size*image->extract_info.x);
   do
@@ -191,12 +196,20 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
           No interlacing:  CMYKCMYKCMYKCMYKCMYKCMYK...
         */
         for (y=0; y < image->extract_info.y; y++)
-          (void) ReadBlob(image,packet_size*image->extract_info.width,scanline);
+        {
+          count=ReadBlob(image,packet_size*image->extract_info.width,scanline);
+          if (count != (ssize_t) (packet_size*image->extract_info.width))
+            break;
+        }
         for (y=0; y < (long) image->rows; y++)
         {
           if ((y > 0) || (image->previous == (Image *) NULL))
-            (void) ReadBlob(image,packet_size*image->extract_info.width,
-              scanline);
+            {
+              count=ReadBlob(image,packet_size*image->extract_info.width,
+                scanline);
+              if (count != (ssize_t) (packet_size*image->extract_info.width))
+                break;
+            }
           q=SetImagePixels(image,0,y,image->columns,1);
           if (q == (PixelPacket *) NULL)
             break;
@@ -218,7 +231,11 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
         }
         width=image->extract_info.height-image->rows-image->extract_info.y;
         for (i=0; i < (long) width; i++)
-          (void) ReadBlob(image,packet_size*image->extract_info.width,scanline);
+        {
+          count=ReadBlob(image,packet_size*image->extract_info.width,scanline);
+          if (count != (ssize_t) (packet_size*image->extract_info.width))
+            break;
+        }
         break;
       }
       case LineInterlace:
@@ -228,26 +245,42 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
         */
         packet_size=(size_t) (image->depth > 8 ? 2 : 1);
         for (y=0; y < image->extract_info.y; y++)
-          (void) ReadBlob(image,packet_size*image->extract_info.width,scanline);
+        {
+          count=ReadBlob(image,packet_size*image->extract_info.width,scanline);
+          if (count != (ssize_t) (packet_size*image->extract_info.width))
+            break;
+        }
         for (y=0; y < (long) image->rows; y++)
         {
           if ((y > 0) || (image->previous == (Image *) NULL))
-            (void) ReadBlob(image,packet_size*image->extract_info.width,
-              scanline);
+            {
+              count=ReadBlob(image,packet_size*image->extract_info.width,
+                scanline);
+              if (count != (ssize_t) (packet_size*image->extract_info.width))
+                break;
+            }
           q=SetImagePixels(image,0,y,image->columns,1);
           if (q == (PixelPacket *) NULL)
             break;
           (void) ExportQuantumPixels(image,CyanQuantum,0,scanline+offset);
-          (void) ReadBlob(image,packet_size*image->extract_info.width,scanline);
+          count=ReadBlob(image,packet_size*image->extract_info.width,scanline);
+          if (count != (ssize_t) (packet_size*image->extract_info.width))
+            break;
           (void) ExportQuantumPixels(image,MagentaQuantum,0,scanline+offset);
-          (void) ReadBlob(image,packet_size*image->extract_info.width,scanline);
+          count=ReadBlob(image,packet_size*image->extract_info.width,scanline);
+          if (count != (ssize_t) (packet_size*image->extract_info.width))
+            break;
           (void) ExportQuantumPixels(image,YellowQuantum,0,scanline+offset);
-          (void) ReadBlob(image,packet_size*image->extract_info.width,scanline);
+          count=ReadBlob(image,packet_size*image->extract_info.width,scanline);
+          if (count != (ssize_t) (packet_size*image->extract_info.width))
+            break;
           (void) ExportQuantumPixels(image,BlackQuantum,0,scanline+offset);
           if (image->matte != MagickFalse)
             {
-              (void) ReadBlob(image,packet_size*image->extract_info.width,
+              count=ReadBlob(image,packet_size*image->extract_info.width,
                 scanline);
+              if (count != (ssize_t) (packet_size*image->extract_info.width))
+                break;
               (void) ExportQuantumPixels(image,AlphaQuantum,0,scanline+offset);
             }
           if (SyncImagePixels(image) == MagickFalse)
@@ -264,7 +297,11 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
         }
         width=image->extract_info.height-image->rows-image->extract_info.y;
         for (i=0; i < (long) width; i++)
-          (void) ReadBlob(image,packet_size*image->extract_info.width,scanline);
+        {
+          count=ReadBlob(image,packet_size*image->extract_info.width,scanline);
+          if (count != (ssize_t) (packet_size*image->extract_info.width))
+            break;
+        }
         break;
       }
       case PlaneInterlace:
@@ -288,14 +325,22 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
           }
         packet_size=(size_t) (image->depth > 8 ? 2 : 1);
         for (y=0; y < image->extract_info.y; y++)
-          (void) ReadBlob(image,packet_size*image->extract_info.width,scanline);
+        {
+          count=ReadBlob(image,packet_size*image->extract_info.width,scanline);
+          if (count != (ssize_t) (packet_size*image->extract_info.width))
+            break;
+        }
         i=0;
         span=image->rows*(image->matte != MagickFalse ? 5 : 4);
         for (y=0; y < (long) image->rows; y++)
         {
           if ((y > 0) || (image->previous == (Image *) NULL))
-            (void) ReadBlob(image,packet_size*image->extract_info.width,
-              scanline);
+            {
+              count=ReadBlob(image,packet_size*image->extract_info.width,
+                scanline);
+              if (count != (ssize_t) (packet_size*image->extract_info.width))
+                break;
+            }
           q=SetImagePixels(image,0,y,image->columns,1);
           if (q == (PixelPacket *) NULL)
             break;
@@ -315,7 +360,11 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
         }
         width=image->extract_info.height-image->rows-image->extract_info.y;
         for (i=0; i < (long) width; i++)
-          (void) ReadBlob(image,packet_size*image->extract_info.width,scanline);
+        {
+          count=ReadBlob(image,packet_size*image->extract_info.width,scanline);
+          if (count != (ssize_t) (packet_size*image->extract_info.width))
+            break;
+        }
         if (image_info->interlace == PartitionInterlace)
           {
             CloseBlob(image);
@@ -328,10 +377,16 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
               }
           }
         for (y=0; y < image->extract_info.y; y++)
-          (void) ReadBlob(image,packet_size*image->extract_info.width,scanline);
+        {
+          count=ReadBlob(image,packet_size*image->extract_info.width,scanline);
+          if (count != (ssize_t) (packet_size*image->extract_info.width))
+            break;
+        }
         for (y=0; y < (long) image->rows; y++)
         {
-          (void) ReadBlob(image,packet_size*image->extract_info.width,scanline);
+          count=ReadBlob(image,packet_size*image->extract_info.width,scanline);
+          if (count != (ssize_t) (packet_size*image->extract_info.width))
+            break;
           q=GetImagePixels(image,0,y,image->columns,1);
           if (q == (PixelPacket *) NULL)
             break;
@@ -351,7 +406,11 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
         }
         width=image->extract_info.height-image->rows-image->extract_info.y;
         for (i=0; i < (long) width; i++)
-          (void) ReadBlob(image,packet_size*image->extract_info.width,scanline);
+        {
+          count=ReadBlob(image,packet_size*image->extract_info.width,scanline);
+          if (count != (ssize_t) (packet_size*image->extract_info.width))
+            break;
+        }
         if (image_info->interlace == PartitionInterlace)
           {
             CloseBlob(image);
@@ -364,10 +423,16 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
               }
           }
         for (y=0; y < image->extract_info.y; y++)
-          (void) ReadBlob(image,packet_size*image->extract_info.width,scanline);
+        {
+          count=ReadBlob(image,packet_size*image->extract_info.width,scanline);
+          if (count != (ssize_t) (packet_size*image->extract_info.width))
+            break;
+        }
         for (y=0; y < (long) image->rows; y++)
         {
-          (void) ReadBlob(image,packet_size*image->extract_info.width,scanline);
+          count=ReadBlob(image,packet_size*image->extract_info.width,scanline);
+          if (count != (ssize_t) (packet_size*image->extract_info.width))
+            break;
           q=GetImagePixels(image,0,y,image->columns,1);
           if (q == (PixelPacket *) NULL)
             break;
@@ -387,7 +452,11 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
         }
         width=image->extract_info.height-image->rows-image->extract_info.y;
         for (i=0; i < (long) width; i++)
-          (void) ReadBlob(image,packet_size*image->extract_info.width,scanline);
+        {
+          count=ReadBlob(image,packet_size*image->extract_info.width,scanline);
+          if (count != (ssize_t) (packet_size*image->extract_info.width))
+            break;
+        }
         if (image_info->interlace == PartitionInterlace)
           {
             CloseBlob(image);
@@ -400,10 +469,16 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
               }
           }
         for (y=0; y < image->extract_info.y; y++)
-          (void) ReadBlob(image,packet_size*image->extract_info.width,scanline);
+        {
+          count=ReadBlob(image,packet_size*image->extract_info.width,scanline);
+          if (count != (ssize_t) (packet_size*image->extract_info.width))
+            break;
+        }
         for (y=0; y < (long) image->rows; y++)
         {
-          (void) ReadBlob(image,packet_size*image->extract_info.width,scanline);
+          count=ReadBlob(image,packet_size*image->extract_info.width,scanline);
+          if (count != (ssize_t) (packet_size*image->extract_info.width))
+            break;
           q=GetImagePixels(image,0,y,image->columns,1);
           if (q == (PixelPacket *) NULL)
             break;
@@ -423,7 +498,11 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
         }
         width=image->extract_info.height-image->rows-image->extract_info.y;
         for (i=0; i < (long) width; i++)
-          (void) ReadBlob(image,packet_size*image->extract_info.width,scanline);
+        {
+          count=ReadBlob(image,packet_size*image->extract_info.width,scanline);
+          if (count != (ssize_t) (packet_size*image->extract_info.width))
+            break;
+        }
         if (image->matte != MagickFalse)
           {
             /*
@@ -441,12 +520,18 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
                   }
               }
             for (y=0; y < image->extract_info.y; y++)
-              (void) ReadBlob(image,packet_size*image->extract_info.width,
+            {
+              count=ReadBlob(image,packet_size*image->extract_info.width,
                 scanline);
+              if (count != (ssize_t) (packet_size*image->extract_info.width))
+                break;
+            }
             for (y=0; y < (long) image->rows; y++)
             {
-              (void) ReadBlob(image,packet_size*image->extract_info.width,
+              count=ReadBlob(image,packet_size*image->extract_info.width,
                 scanline);
+              if (count != (ssize_t) (packet_size*image->extract_info.width))
+                break;
               q=GetImagePixels(image,0,y,image->columns,1);
               if (q == (PixelPacket *) NULL)
                 break;
@@ -466,8 +551,12 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
             }
             width=image->extract_info.height-image->rows-image->extract_info.y;
             for (i=0; i < (long) width; i++)
-              (void) ReadBlob(image,packet_size*image->extract_info.width,
+            {
+              count=ReadBlob(image,packet_size*image->extract_info.width,
                 scanline);
+              if (count != (ssize_t) (packet_size*image->extract_info.width))
+                break;
+            }
           }
         if (image_info->interlace == PartitionInterlace)
           (void) CopyMagickString(image->filename,image_info->filename,
@@ -475,12 +564,8 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
         break;
       }
     }
-    if (EOFBlob(image) != MagickFalse)
-      {
-        ThrowFileException(exception,CorruptImageError,"UnexpectedEndOfFile",
-          image->filename);
-        break;
-      }
+    if (y < (long) image->rows)
+      ThrowReaderException(CorruptImageError,"InsufficientImageDataInFile");
     /*
       Proceed to next image.
     */
@@ -490,7 +575,7 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
     if (image_info->interlace == PartitionInterlace)
       break;
     count=ReadBlob(image,packet_size*image->extract_info.width,scanline);
-    if (count != 0)
+    if (count == (ssize_t) (packet_size*image->extract_info.width))
       {
         /*
           Allocate next image structure.
@@ -510,7 +595,7 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
               break;
           }
       }
-  } while (count != 0);
+  } while (count == (ssize_t) (packet_size*image->extract_info.width));
   scanline=(unsigned char *) RelinquishMagickMemory(scanline);
   CloseBlob(image);
   return(GetFirstImageInList(image));
