@@ -314,6 +314,9 @@ static Image *ReadCUTImage(const ImageInfo *image_info,ExceptionInfo *exception)
   unsigned char *BImgBuff=NULL,*ptrB;
   PixelPacket *q;
 
+  ssize_t
+    count;
+
   /*
     Open image file.
   */
@@ -423,7 +426,7 @@ static Image *ReadCUTImage(const ImageInfo *image_info,ExceptionInfo *exception)
 
   if(palette!=NULL)
     {
-      (void) ReadBlob(palette,2,(unsigned char *) PalHeader.FileId);
+      count=ReadBlob(palette,2,(unsigned char *) PalHeader.FileId);
       if(strncmp(PalHeader.FileId,"AH",2) != 0) goto ErasePalette;
       PalHeader.Version=ReadBlobLSBShort(palette);
       PalHeader.Size=ReadBlobLSBShort(palette);
@@ -435,7 +438,7 @@ static Image *ReadCUTImage(const ImageInfo *image_info,ExceptionInfo *exception)
       PalHeader.MaxRed=ReadBlobLSBShort(palette);
       PalHeader.MaxGreen=ReadBlobLSBShort(palette);
       PalHeader.MaxBlue=ReadBlobLSBShort(palette);
-      (void) ReadBlob(palette,20,(unsigned char *) PalHeader.PaletteId);
+      count=ReadBlob(palette,20,(unsigned char *) PalHeader.PaletteId);
 
       if(PalHeader.MaxIndex<1) goto ErasePalette;
       image->colors=PalHeader.MaxIndex+1;
@@ -529,7 +532,7 @@ static Image *ReadCUTImage(const ImageInfo *image_info,ExceptionInfo *exception)
               (void) ResetMagickMemory(ptrB,(int) RunValue,(size_t) RunCountMasked);
             }
           else {
-            (void) ReadBlob(image,(size_t) RunCountMasked,ptrB);
+            count=ReadBlob(image,(size_t) RunCountMasked,ptrB);
           }
 
           ptrB+=(int) RunCountMasked;
