@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -478,6 +478,9 @@ static Image *ReadDIBImage(const ImageInfo *image_info,ExceptionInfo *exception)
   size_t
     length;
 
+  ssize_t
+    count;
+
   unsigned char
     *pixels;
 
@@ -571,7 +574,9 @@ static Image *ReadDIBImage(const ImageInfo *image_info,ExceptionInfo *exception)
       if (dib_colormap == (unsigned char *) NULL)
         ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
       packet_size=4;
-      (void) ReadBlob(image,packet_size*image->colors,dib_colormap);
+      count=ReadBlob(image,packet_size*image->colors,dib_colormap);
+      if (count != (ssize_t) (packet_size*image->colors))
+        ThrowReaderException(CorruptImageError,"InsufficientImageDataInFile");
       p=dib_colormap;
       for (i=0; i < (long) image->colors; i++)
       {
@@ -595,7 +600,11 @@ static Image *ReadDIBImage(const ImageInfo *image_info,ExceptionInfo *exception)
   if (pixels == (unsigned char *) NULL)
     ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
   if ((dib_info.compression == 0) || (dib_info.compression == 3))
-    (void) ReadBlob(image,length,pixels);
+    {
+      count=ReadBlob(image,length,pixels);
+      if (count != (ssize_t) (length))
+        ThrowReaderException(CorruptImageError,"InsufficientImageDataInFile");
+    }
   else
     {
       /*
