@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -56,6 +56,7 @@
 #include "magick/monitor.h"
 #include "magick/pixel.h"
 #include "magick/static.h"
+#include "magick/statistic.h"
 #include "magick/string_.h"
 
 /*
@@ -382,7 +383,7 @@ static Image *ReadFITSImage(const ImageInfo *image_info,
       Convert FITS pixels to pixel packets.
     */
     count=ReadBlob(image,packet_size*image->columns*image->rows,fits_pixels);
-    if (count == 0)
+    if (count != (ssize_t) (packet_size*image->columns*image->rows))
       ThrowReaderException(CorruptImageError,"InsufficientImageDataInFile");
     if ((fits_info.bits_per_pixel > 0) &&
         (fits_info.min_data == 0.0) && (fits_info.max_data == 0.0))
@@ -733,6 +734,8 @@ static MagickBooleanType WriteFITSImage(const ImageInfo *image_info,
   /*
     Allocate image memory.
   */
+  image->endian=MSBEndian;
+  image->depth=GetImageQuantumDepth(image,MagickTrue);
   packet_size=(size_t) (image->depth > 8 ? 2 : 1);
   fits_info=(char *) AcquireMagickMemory(2880*sizeof(*fits_info));
   pixels=(unsigned char *) AcquireMagickMemory(packet_size*image->columns);
