@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -766,7 +766,7 @@ static ssize_t ReadBlobBlock(Image *image,unsigned char *data)
   assert(image->signature == MagickSignature);
   assert(data != (unsigned char *) NULL);
   count=ReadBlob(image,1,&block_count);
-  if (count == 0)
+  if (count != 1)
     return(0);
   return(ReadBlob(image,(size_t) block_count,data));
 }
@@ -859,7 +859,7 @@ static Image *ReadGIFImage(const ImageInfo *image_info,ExceptionInfo *exception)
     Determine if this is a GIF file.
   */
   count=ReadBlob(image,6,magick);
-  if ((count == 0) || ((LocaleNCompare((char *) magick,"GIF87",5) != 0) &&
+  if ((count != 6) || ((LocaleNCompare((char *) magick,"GIF87",5) != 0) &&
       (LocaleNCompare((char *) magick,"GIF89",5) != 0)))
     ThrowReaderException(CorruptImageError,"ImproperImageHeader");
   page.width=ReadBlobLSBShort(image);
@@ -873,7 +873,7 @@ static Image *ReadGIFImage(const ImageInfo *image_info,ExceptionInfo *exception)
   if (global_colormap == (unsigned char *) NULL)
     ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
   if (BitSet((int) flag,0x80) != 0)
-    (void) ReadBlob(image,(size_t) (3*global_colors),global_colormap);
+    count=ReadBlob(image,(size_t) (3*global_colors),global_colormap);
   delay=0;
   dispose=0;
   iterations=1;
@@ -882,7 +882,7 @@ static Image *ReadGIFImage(const ImageInfo *image_info,ExceptionInfo *exception)
   for ( ; ; )
   {
     count=ReadBlob(image,1,&c);
-    if (count == 0)
+    if (count != 1)
       break;
     if (c == (unsigned char) ';')
       break;  /* terminator */
@@ -892,7 +892,7 @@ static Image *ReadGIFImage(const ImageInfo *image_info,ExceptionInfo *exception)
           GIF Extension block.
         */
         count=ReadBlob(image,1,&c);
-        if (count == 0)
+        if (count != 1)
           ThrowReaderException(CorruptImageError,"UnableToReadExtensionBlock");
         switch (c)
         {
@@ -1040,7 +1040,9 @@ static Image *ReadGIFImage(const ImageInfo *image_info,ExceptionInfo *exception)
           AcquireMagickMemory((size_t) (3*image->colors));
         if (colormap == (unsigned char *) NULL)
           ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
-        (void) ReadBlob(image,(size_t) (3*image->colors),colormap);
+        count=ReadBlob(image,(size_t) (3*image->colors),colormap);
+        if (count != (ssize_t) (3*image->colors))
+          ThrowReaderException(CorruptImageError,"InsufficientImageDataInFile");
         p=colormap;
         for (i=0; i < (long) image->colors; i++)
         {
