@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -54,6 +54,7 @@
 #include "magick/monitor.h"
 #include "magick/pixel.h"
 #include "magick/static.h"
+#include "magick/statistic.h"
 #include "magick/string_.h"
 
 /*
@@ -163,7 +164,11 @@ static Image *ReadGRAYImage(const ImageInfo *image_info,
       */
       image->scene++;
       for (y=0; y < (long) image->rows; y++)
-        (void) ReadBlob(image,packet_size*image->extract_info.width,scanline);
+      {
+        count=ReadBlob(image,packet_size*image->extract_info.width,scanline);
+        if (count != (ssize_t) (packet_size*image->extract_info.width))
+          break;
+      }
     }
   offset=(MagickOffsetType) (packet_size*image->extract_info.x);
   do
@@ -178,11 +183,19 @@ static Image *ReadGRAYImage(const ImageInfo *image_info,
       if (image->scene >= (image_info->scene+image_info->number_scenes-1))
         break;
     for (y=0; y < image->extract_info.y; y++)
-      (void) ReadBlob(image,packet_size*image->extract_info.width,scanline);
+    {
+      count=ReadBlob(image,packet_size*image->extract_info.width,scanline);
+      if (count != (ssize_t) (packet_size*image->extract_info.width))
+        break;
+    }
     for (y=0; y < (long) image->rows; y++)
     {
       if ((y > 0) || (image->previous == (Image *) NULL))
-        (void) ReadBlob(image,packet_size*image->extract_info.width,scanline);
+        {
+          count=ReadBlob(image,packet_size*image->extract_info.width,scanline);
+          if (count != (ssize_t) (packet_size*image->extract_info.width))
+            break;
+        }
       q=SetImagePixels(image,0,y,image->columns,1);
       if (q == (PixelPacket *) NULL)
         break;
@@ -212,8 +225,12 @@ static Image *ReadGRAYImage(const ImageInfo *image_info,
     }
     width=image->extract_info.height-image->rows-image->extract_info.y;
     for (j=0; j < (long) width; j++)
-      (void) ReadBlob(image,packet_size*image->extract_info.width,scanline);
-    if (EOFBlob(image) != MagickFalse)
+    {
+      count=ReadBlob(image,packet_size*image->extract_info.width,scanline);
+      if (count != (ssize_t) (packet_size*image->extract_info.width))
+        break;
+    }
+    if (y < (long) image->rows)
       {
         ThrowFileException(exception,CorruptImageError,"UnexpectedEndOfFile",
           image->filename);
@@ -226,7 +243,7 @@ static Image *ReadGRAYImage(const ImageInfo *image_info,
       if (image->scene >= (image_info->scene+image_info->number_scenes-1))
         break;
     count=ReadBlob(image,packet_size*image->extract_info.width,scanline);
-    if (count != 0)
+    if (count == (ssize_t) (packet_size*image->extract_info.width))
       {
         /*
           Allocate next image structure.
@@ -246,7 +263,7 @@ static Image *ReadGRAYImage(const ImageInfo *image_info,
               break;
           }
       }
-  } while (count != 0);
+  } while (count == (ssize_t) (packet_size*image->extract_info.width));
   scanline=(unsigned char *) RelinquishMagickMemory(scanline);
   CloseBlob(image);
   return(GetFirstImageInList(image));
@@ -388,8 +405,7 @@ static MagickBooleanType WriteGRAYImage(const ImageInfo *image_info,
     (void) SetImageColorspace(image,RGBColorspace);
     depth=GetImageQuantumDepth(image,MagickTrue);
     packet_size=(size_t) (depth/8);
-    scanline=(unsigned char *)
-      AcquireMagickMemory(packet_size*image->columns);
+    scanline=(unsigned char *) AcquireMagickMemory(packet_size*image->columns);
     if (scanline == (unsigned char *) NULL)
       ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
     /*
