@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -55,6 +55,7 @@
 #include "magick/monitor.h"
 #include "magick/resource_.h"
 #include "magick/static.h"
+#include "magick/statistic.h"
 #include "magick/string_.h"
 
 /*
@@ -268,7 +269,7 @@ static MagickBooleanType WriteHISTOGRAMImage(const ImageInfo *image_info,
   */
   (void) QueryColorDatabase("#000000",&histogram_image->background_color,
     &image->exception);
-  SetImage(histogram_image,OpaqueOpacity);
+  SetImageBackgroundColor(histogram_image);
   for (x=0; x < (long) histogram_image->columns; x++)
   {
     q=GetImagePixels(histogram_image,x,0,1,histogram_image->rows);
