@@ -24,7 +24,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -290,7 +290,7 @@ static MagickBooleanType WriteHTMLImage(const ImageInfo *image_info,
       */
       (void) WriteBlobString(image,"<html version=\"2.0\">\n");
       (void) WriteBlobString(image,"<head>\n");
-      attribute=GetImageAttribute(image,"label");
+      attribute=GetImageAttribute(image,"Label");
       if (attribute != (const ImageAttribute *) NULL)
         (void) FormatMagickString(buffer,MaxTextExtent,
           "<title>%s</title>\n",attribute->value);
