@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -194,6 +194,9 @@ static Image *ReadICONImage(const ImageInfo *image_info,
   register unsigned char
     *p;
 
+  ssize_t
+    count;
+
   unsigned long
     bit,
     byte;
@@ -278,7 +281,9 @@ static Image *ReadICONImage(const ImageInfo *image_info,
         AcquireMagickMemory((size_t) (4*image->colors));
       if (icon_colormap == (unsigned char *) NULL)
         ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
-      (void) ReadBlob(image,(size_t) (4*image->colors),icon_colormap);
+      count=ReadBlob(image,(size_t) (4*image->colors),icon_colormap);
+      if (count != (ssize_t) (4*image->colors))
+        ThrowReaderException(CorruptImageError,"InsufficientImageDataInFile");
       p=icon_colormap;
       for (i=0; i < (long) image->colors; i++)
       {
