@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -56,6 +56,7 @@
 #include "magick/option.h"
 #include "magick/profile.h"
 #include "magick/static.h"
+#include "magick/statistic.h"
 #include "magick/string_.h"
 #if defined(HasJP2)
 #if !defined(uchar)
@@ -628,7 +629,7 @@ ModuleExport void RegisterJP2Image(void)
     *entry;
 
   entry=SetMagickInfo("JP2");
-  entry->description=AcquireString("JPEG-2000 JP2 File Format Syntax");
+  entry->description=AcquireString("JPEG-2000 File Format Syntax");
   entry->module=AcquireString("JP2");
   entry->magick=(MagickHandler *) IsJP2;
   entry->adjoin=MagickFalse;
@@ -649,6 +650,18 @@ ModuleExport void RegisterJP2Image(void)
 #if defined(HasJP2)
   entry->decoder=(DecoderHandler *) ReadJP2Image;
   entry->encoder=(EncoderHandler *) WriteJP2Image;
+#endif
+  (void) RegisterMagickInfo(entry);
+  entry=SetMagickInfo("JPX");
+  entry->description=AcquireString("JPEG-2000 File Format Syntax");
+  entry->module=AcquireString("JPX");
+  entry->magick=(MagickHandler *) IsJPC;
+  entry->adjoin=MagickFalse;
+  entry->seekable_stream=MagickTrue;
+  entry->thread_support=MagickFalse;
+#if defined(HasJP2)
+  entry->decoder=(DecoderHandler *) ReadJP2Image;
+  entry->encoder=(EncoderHandler *) WriteJP2Image;
 #endif
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("PGX");
