@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -761,7 +761,7 @@ static Image *ReadJPEGImage(const ImageInfo *image_info,
   if (units == 2)
     image->units=PixelsPerCentimeterResolution;
   number_pixels=(MagickSizeType) image->columns*image->rows;
-  if (number_pixels != 0)
+  if (image_info->size != (char *) NULL)
     {
       double
         scale_factor;
@@ -1085,7 +1085,8 @@ static Image *ReadJPEGImage(const ImageInfo *image_info,
   scanline[0]=(JSAMPROW) jpeg_pixels;
   for (y=0; y < (long) image->rows; y++)
   {
-    (void) jpeg_read_scanlines(&jpeg_info,scanline,1);
+    if (jpeg_read_scanlines(&jpeg_info,scanline,1) != 1)
+      break;
     p=jpeg_pixels;
     q=SetImagePixels(image,0,y,image->columns,1);
     if (q == (PixelPacket *) NULL)
@@ -1724,19 +1725,18 @@ static MagickBooleanType WriteJPEGImage(const ImageInfo *image_info,
         }
 #endif
     }
-  sampling_factors=image_info->sampling_factor;
-  if (sampling_factors == (char *) NULL)
+  sampling_factors=(char *) NULL;
+  attribute=GetImageAttribute(image,"JPEG-Sampling-factors");
+  if ((attribute != (const ImageAttribute *) NULL) &&
+      (attribute->value != (char *) NULL))
     {
-      attribute=GetImageAttribute(image,"JPEG-Sampling-factors");
-      if ((attribute != (const ImageAttribute *) NULL) &&
-          (attribute->value != (char *) NULL))
-        {
-          sampling_factors=attribute->value;
-          if (image->debug != MagickFalse)
-            (void) LogMagickEvent(CoderEvent,GetMagickModule(),
-              "  Input sampling-factors=%s",sampling_factors);
-        }
+      sampling_factors=attribute->value;
+      if (image->debug != MagickFalse)
+        (void) LogMagickEvent(CoderEvent,GetMagickModule(),
+          "  Input sampling-factors=%s",sampling_factors);
     }
+  if (image_info->sampling_factor != (char *) NULL)
+    sampling_factors=image_info->sampling_factor;
   if (sampling_factors == (char *) NULL)
     {
       if (image->quality >= 90)
@@ -1904,7 +1904,7 @@ static MagickBooleanType WriteJPEGImage(const ImageInfo *image_info,
     for (i=0; i < (long) strlen(attribute->value); i+=65533L)
       jpeg_write_marker(&jpeg_info,JPEG_COM,(unsigned char *) attribute->value+
         i,(unsigned int) Min((long) strlen(attribute->value+i),65533L));
-  if (image->profiles != (SplayTreeInfo *) NULL)
+  if (image->profiles != (void *) NULL)
     WriteProfile(&jpeg_info,image);
   /*
     Convert MIFF to JPEG raster pixels.
