@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -170,7 +170,7 @@ static Image *ReadLABELImage(const ImageInfo *image_info,
         image->columns/2.0-metrics.width/2.0,metrics.ascent);
     }
   draw_info->geometry=AcquireString(geometry);
-  SetImage(image,OpaqueOpacity);
+  SetImageBackgroundColor(image);
   (void) AnnotateImage(image,draw_info);
   draw_info=DestroyDrawInfo(draw_info);
   return(GetFirstImageInList(image));
