@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -53,6 +53,7 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/static.h"
+#include "magick/statistic.h"
 #include "magick/string_.h"
 
 /*
@@ -120,6 +121,9 @@ static Image *ReadMAPImage(const ImageInfo *image_info,ExceptionInfo *exception)
   size_t
     packet_size;
 
+  ssize_t
+    count;
+
   unsigned char
     *colormap,
     *pixels;
@@ -164,7 +168,9 @@ static Image *ReadMAPImage(const ImageInfo *image_info,ExceptionInfo *exception)
   /*
     Read image colormap.
   */
-  (void) ReadBlob(image,packet_size*image->colors,colormap);
+  count=ReadBlob(image,packet_size*image->colors,colormap);
+  if (count != (ssize_t) (packet_size*image->colors))
+    ThrowReaderException(CorruptImageError,"InsufficientImageDataInFile");
   p=colormap;
   if (image->depth <= 8)
     for (i=0; i < (long) image->colors; i++)
@@ -200,7 +206,9 @@ static Image *ReadMAPImage(const ImageInfo *image_info,ExceptionInfo *exception)
     if (q == (PixelPacket *) NULL)
       break;
     indexes=GetIndexes(image);
-    (void) ReadBlob(image,(size_t) packet_size*image->columns,pixels);
+    count=ReadBlob(image,(size_t) packet_size*image->columns,pixels);
+    if (count != (ssize_t) (packet_size*image->columns))
+      break;
     for (x=0; x < (long) image->columns; x++)
     {
       index=ConstrainColormapIndex(image,*p);
@@ -217,7 +225,7 @@ static Image *ReadMAPImage(const ImageInfo *image_info,ExceptionInfo *exception)
       break;
   }
   pixels=(unsigned char *) RelinquishMagickMemory(pixels);
-  if (EOFBlob(image) != MagickFalse)
+  if (y < (long) image->rows)
     ThrowFileException(exception,CorruptImageError,"UnexpectedEndOfFile",
       image->filename);
   CloseBlob(image);
