@@ -374,6 +374,9 @@ static Image *ReadMATImage(const ImageInfo *image_info,ExceptionInfo *exception)
     Max,
    *dblrow;
 
+  ssize_t
+    count;
+
   /*
      Open image file.
    */
@@ -387,8 +390,8 @@ static Image *ReadMATImage(const ImageInfo *image_info,ExceptionInfo *exception)
   /*
      Read MATLAB image.
    */
-  (void) ReadBlob(image, 125, (unsigned char *) &MATLAB_HDR.identific);
-  (void) ReadBlob(image, 3, (unsigned char *) &MATLAB_HDR.idx);
+  count=ReadBlob(image, 125, (unsigned char *) &MATLAB_HDR.identific);
+  count=ReadBlob(image, 3, (unsigned char *) &MATLAB_HDR.idx);
   MATLAB_HDR.unknown0 = ReadBlobLSBLong(image);
   MATLAB_HDR.ObjectSize = ReadBlobLSBLong(image);
   MATLAB_HDR.unknown1 = ReadBlobLSBLong(image);
@@ -418,7 +421,7 @@ static Image *ReadMATImage(const ImageInfo *image_info,ExceptionInfo *exception)
   switch (MATLAB_HDR.NameFlag)
   {
     case 0:
-      (void) ReadBlob(image, 4, (unsigned char *) &size); /*Object name string */
+      count=ReadBlob(image, 4, (unsigned char *) &size); /*Object name string */
       size = 4 * (long) ((size + 3 + 1) / 4);
       (void) SeekBlob(image, size, SEEK_CUR);
       break;
@@ -426,7 +429,7 @@ static Image *ReadMATImage(const ImageInfo *image_info,ExceptionInfo *exception)
     case 2:
     case 3:
     case 4:
-      (void) ReadBlob(image, 4, (unsigned char *) &size); /*Object name string */
+      count=ReadBlob(image, 4, (unsigned char *) &size); /*Object name string */
       break;
     default:
       goto MATLAB_KO;
@@ -434,7 +437,7 @@ static Image *ReadMATImage(const ImageInfo *image_info,ExceptionInfo *exception)
 
   CellType = ReadBlobLSBLong(image);    /*Additional object type */
   /*fprintf(stdout,"Cell type:%ld\n",CellType); */
-  (void) ReadBlob(image, 4, (unsigned char *) &size);     /*data size */
+  count=ReadBlob(image, 4, (unsigned char *) &size);     /*data size */
 
   switch (CellType)
   {
@@ -543,7 +546,7 @@ static Image *ReadMATImage(const ImageInfo *image_info,ExceptionInfo *exception)
           InsertFloatRow((double *) BImgBuff, i, image, Min, Max);
           break;
       default:
-        (void) ReadBlob(image, ldblk, BImgBuff);
+        count=ReadBlob(image, ldblk, BImgBuff);
         InsertRow(BImgBuff, i, image);
     }
   }
