@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -1066,7 +1066,7 @@ static Image *ReadMETAImage(const ImageInfo *image_info,
     }
   image->columns=1;
   image->rows=1;
-  SetImage(image,OpaqueOpacity);
+  SetImageBackgroundColor(image);
   length=1;
   if (LocaleNCompare(image_info->magick,"8BIM",4) == 0)
     {
@@ -2134,7 +2134,7 @@ static MagickBooleanType WriteMETAImage(const ImageInfo *image_info,
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),image->filename);
-  if (image->profiles == (SplayTreeInfo *) NULL)
+  if (image->profiles == (void *) NULL)
     return(MagickFalse);
   length=0;
   if (LocaleCompare(image_info->magick,"8BIM") == 0)
