@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -60,8 +60,8 @@
 #include "magick/option.h"
 #include "magick/pixel.h"
 #include "magick/profile.h"
-#include "magick/splay-tree.h"
 #include "magick/static.h"
+#include "magick/statistic.h"
 #include "magick/string_.h"
 #if defined(HasZLIB)
 #include "zlib.h"
@@ -423,6 +423,9 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
     length,
     packet_size;
 
+  ssize_t
+    count;
+
   StringInfo
     *profile;
 
@@ -933,7 +936,7 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
         while (name != (const char *) NULL)
         {
           profile=GetImageProfile(image,name);
-          (void) ReadBlob(image,profile->length,profile->datum);
+          count=ReadBlob(image,profile->length,profile->datum);
           name=(const char *) GetNextValueInLinkedList(profiles);
         }
         profiles=DestroyLinkedList(profiles,RelinquishMagickMemory);
@@ -966,7 +969,7 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
               AcquireMagickMemory(packet_size*image->colors);
             if (colormap == (unsigned char *) NULL)
               ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
-            (void) ReadBlob(image,packet_size*image->colors,colormap);
+            count=ReadBlob(image,packet_size*image->colors,colormap);
             p=colormap;
             switch (depth)
             {
@@ -1159,7 +1162,7 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
           {
             if (length == 0)
               {
-                (void) ReadBlob(image,packet_size,pixels);
+                count=ReadBlob(image,packet_size,pixels);
                 PushRunlengthPacket(image,depth,pixels,&length,&pixel,&index);
               }
             length--;
@@ -1172,7 +1175,7 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
         }
         default:
         {
-          (void) ReadBlob(image,packet_size*image->columns,pixels);
+          count=ReadBlob(image,packet_size*image->columns,pixels);
           (void) ExportQuantumPixels(image,quantum_type,0,pixels);
           break;
         }
@@ -1720,7 +1723,7 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
           image->chromaticity.white_point.x,image->chromaticity.white_point.y);
         (void) WriteBlobString(image,buffer);
       }
-    if (image->profiles != (SplayTreeInfo *) NULL)
+    if (image->profiles != (void *) NULL)
       {
         const char
           *name;
@@ -1751,23 +1754,26 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
           image->montage);
         (void) WriteBlobString(image,buffer);
       }
-    attribute=GetImageAttribute(image,(char *) NULL);
-    for ( ; attribute != (ImageAttribute *) NULL; attribute=attribute->next)
+    ResetImageAttributeIterator(image);
+	  attribute=GetNextImageAttribute(image);
+    while (attribute != (const ImageAttribute *) NULL)
     {
-      if (*attribute->key == '[')
-        continue;
-      (void) FormatMagickString(buffer,MaxTextExtent,"%s=",attribute->key);
-      (void) WriteBlobString(image,buffer);
-      for (i=0; i < (long) strlen(attribute->value); i++)
-        if (isspace((int) ((unsigned char) attribute->value[i])) != 0)
-          break;
-      if (i <= (long) strlen(attribute->value))
-        (void) WriteBlobByte(image,'{');
-      (void) WriteBlob(image,strlen(attribute->value),(unsigned char *)
-        attribute->value);
-      if (i <= (long) strlen(attribute->value))
-        (void) WriteBlobByte(image,'}');
-      (void) WriteBlobByte(image,'\n');
+      if (*attribute->key != '[')
+        {
+          (void) FormatMagickString(buffer,MaxTextExtent,"%s=",attribute->key);
+          (void) WriteBlobString(image,buffer);
+          for (i=0; i < (long) strlen(attribute->value); i++)
+            if (isspace((int) ((unsigned char) attribute->value[i])) != 0)
+              break;
+          if (i <= (long) strlen(attribute->value))
+            (void) WriteBlobByte(image,'{');
+          (void) WriteBlob(image,strlen(attribute->value),(unsigned char *)
+            attribute->value);
+          if (i <= (long) strlen(attribute->value))
+            (void) WriteBlobByte(image,'}');
+          (void) WriteBlobByte(image,'\n');
+        }
+  	  attribute=GetNextImageAttribute(image);
     }
     (void) WriteBlobString(image,"\f\n:\032");
     if (image->montage != (char *) NULL)
@@ -1780,7 +1786,7 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
             (unsigned char *) image->directory);
         (void) WriteBlobByte(image,'\0');
       }
-    if (image->profiles != (SplayTreeInfo *) NULL)
+    if (image->profiles != (void *) NULL)
       {
         const char
           *name;
