@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -60,8 +60,8 @@
 #include "magick/monitor.h"
 #include "magick/option.h"
 #include "magick/profile.h"
-#include "magick/splay-tree.h"
 #include "magick/static.h"
+#include "magick/statistic.h"
 #include "magick/string_.h"
 #include "magick/utility.h"
 
@@ -210,6 +210,9 @@ static Image *ReadMPCImage(const ImageInfo *image_info,ExceptionInfo *exception)
   size_t
     length;
 
+  ssize_t
+    count;
+
   StringInfo
     *profile;
 
@@ -437,6 +440,12 @@ static Image *ReadMPCImage(const ImageInfo *image_info,ExceptionInfo *exception)
               case 'e':
               case 'E':
               {
+                if (LocaleCompare(keyword,"endian") == 0)
+                  {
+                    image->endian=(EndianType) ParseMagickOption(
+                      MagickEndianOptions,MagickFalse,options);
+                    break;
+                  }
                 if (LocaleCompare(keyword,"error") == 0)
                   {
                     image->error.mean_error_per_pixel=atof(options);
@@ -711,7 +720,7 @@ static Image *ReadMPCImage(const ImageInfo *image_info,ExceptionInfo *exception)
         {
           profile=GetImageProfile(image,name);
           if (profile != (StringInfo *) NULL)
-            (void) ReadBlob(image,profile->length,profile->datum);
+            count=ReadBlob(image,profile->length,profile->datum);
           name=(const char *) GetNextValueInLinkedList(profiles);
         }
         profiles=DestroyLinkedList(profiles,RelinquishMagickMemory);
@@ -743,7 +752,10 @@ static Image *ReadMPCImage(const ImageInfo *image_info,ExceptionInfo *exception)
               AcquireMagickMemory(packet_size*image->colors);
             if (colormap == (unsigned char *) NULL)
               ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
-            (void) ReadBlob(image,packet_size*image->colors,colormap);
+            count=ReadBlob(image,packet_size*image->colors,colormap);
+            if (count != (ssize_t) (packet_size*image->colors))
+              ThrowReaderException(CorruptImageError,
+                "InsufficientImageDataInFile");
             p=colormap;
             switch (depth)
             {
@@ -997,6 +1009,12 @@ static MagickBooleanType WriteMPCImage(const ImageInfo *image_info,Image *image)
           MagickOptionToMnemonic(MagickColorspaceOptions,image->colorspace));
         (void) WriteBlobString(image,buffer);
       }
+    if (image->endian != UndefinedEndian)
+      {
+        (void) FormatMagickString(buffer,MaxTextExtent,"endian=%s\n",
+          MagickOptionToMnemonic(MagickEndianOptions,image->endian));
+        (void) WriteBlobString(image,buffer);
+      }
     if (image->compression != UndefinedCompression)
       {
         (void) FormatMagickString(buffer,MaxTextExtent,
@@ -1104,7 +1122,7 @@ static MagickBooleanType WriteMPCImage(const ImageInfo *image_info,Image *image)
           image->chromaticity.white_point.x,image->chromaticity.white_point.y);
         (void) WriteBlobString(image,buffer);
       }
-    if (image->profiles != (SplayTreeInfo *) NULL)
+    if (image->profiles != (void *) NULL)
       {
         const char
           *name;
@@ -1135,23 +1153,26 @@ static MagickBooleanType WriteMPCImage(const ImageInfo *image_info,Image *image)
           image->montage);
         (void) WriteBlobString(image,buffer);
       }
-    attribute=GetImageAttribute(image,(char *) NULL);
-    for ( ; attribute != (const ImageAttribute *) NULL; attribute=attribute->next)
+    ResetImageAttributeIterator(image);
+	  attribute=GetNextImageAttribute(image);
+		while (attribute != (const ImageAttribute *) NULL)
     {
-      if (*attribute->key == '[')
-        continue;
-      (void) FormatMagickString(buffer,MaxTextExtent,"%s=",attribute->key);
-      (void) WriteBlobString(image,buffer);
-      for (i=0; i < (long) strlen(attribute->value); i++)
-        if (isspace((int) ((unsigned char) attribute->value[i])) != 0)
-          break;
-      if (i <= (long) strlen(attribute->value))
-        (void) WriteBlobByte(image,'{');
-      (void) WriteBlob(image,strlen(attribute->value),(unsigned char *)
-        attribute->value);
-      if (i <= (long) strlen(attribute->value))
-        (void) WriteBlobByte(image,'}');
-      (void) WriteBlobByte(image,'\n');
+      if (*attribute->key != '[')
+        {
+          (void) FormatMagickString(buffer,MaxTextExtent,"%s=",attribute->key);
+          (void) WriteBlobString(image,buffer);
+          for (i=0; i < (long) strlen(attribute->value); i++)
+            if (isspace((int) ((unsigned char) attribute->value[i])) != 0)
+              break;
+          if (i <= (long) strlen(attribute->value))
+            (void) WriteBlobByte(image,'{');
+          (void) WriteBlob(image,strlen(attribute->value),(unsigned char *)
+            attribute->value);
+          if (i <= (long) strlen(attribute->value))
+            (void) WriteBlobByte(image,'}');
+          (void) WriteBlobByte(image,'\n');
+        }
+  	  attribute=GetNextImageAttribute(image);
     }
     (void) WriteBlobString(image,"\f\n:\032");
     if (image->montage != (char *) NULL)
