@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -163,7 +163,7 @@ static Image *ReadMTVImage(const ImageInfo *image_info,ExceptionInfo *exception)
     for (y=0; y < (long) image->rows; y++)
     {
       count=(ssize_t) ReadBlob(image,(size_t) (3*image->columns),pixels);
-      if (count == 0)
+      if (count != (ssize_t) (3*image->columns))
         ThrowReaderException(CorruptImageError,"UnableToReadImageData");
       p=pixels;
       q=SetImagePixels(image,0,y,image->columns,1);
