@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -194,7 +194,7 @@ static Image *ReadMVGImage(const ImageInfo *image_info,ExceptionInfo *exception)
     image->y_resolution == 0.0 ? 1.0 : image->y_resolution/DefaultResolution;
   image->columns=(unsigned long) (draw_info->affine.sx*image->columns);
   image->rows=(unsigned long) (draw_info->affine.sy*image->rows);
-  SetImage(image,OpaqueOpacity);
+  SetImageBackgroundColor(image);
   /*
     Render drawing.
   */
