@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -123,7 +123,7 @@ static Image *ReadNULLImage(const ImageInfo *image_info,
   if (AllocateImageColormap(image,1) == MagickFalse)
     ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
   image->colormap[0]=image->background_color;
-  SetImage(image,OpaqueOpacity);
+  SetImageBackgroundColor(image);
   return(GetFirstImageInList(image));
 }
 
