@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %   obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -55,6 +55,7 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/paint.h"
+#include "magick/pixel-private.h"
 #include "magick/quantize.h"
 #include "magick/static.h"
 #include "magick/string_.h"
@@ -385,7 +386,7 @@ static Image *ReadPALMImage(const ImageInfo *image_info,
         {
           /* TODO move out of loop! */
           image->compression=NoCompression;
-          (void) ReadBlob(image,bytes_per_row,one_row);
+          count=ReadBlob(image,bytes_per_row,one_row);
         }
       else
         {
