@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -119,7 +119,7 @@ static MagickBooleanType DecodeImage(Image *image,unsigned char *luma,
   { \
     if (p >= (buffer+0x800)) \
       { \
-        (void) ReadBlob(image,0x800,buffer); \
+        count=ReadBlob(image,0x800,buffer); \
         p=buffer; \
       } \
     sum|=((unsigned int) (*p) << (24-bits)); \
@@ -608,13 +608,13 @@ static Image *ReadPCDImage(const ImageInfo *image_info,ExceptionInfo *exception)
         c2=chroma2;
         for (y=0; y < (long) height; y+=2)
         {
-          (void) ReadBlob(image,width,yy);
+          count=ReadBlob(image,width,yy);
           yy+=image->columns;
-          (void) ReadBlob(image,width,yy);
+          count=ReadBlob(image,width,yy);
           yy+=image->columns;
-          (void) ReadBlob(image,width >> 1,c1);
+          count=ReadBlob(image,width >> 1,c1);
           c1+=image->columns;
-          (void) ReadBlob(image,width >> 1,c2);
+          count=ReadBlob(image,width >> 1,c2);
           c2+=image->columns;
         }
         Upsample(image->columns >> 1,image->rows >> 1,image->columns,chroma1);
@@ -684,13 +684,13 @@ static Image *ReadPCDImage(const ImageInfo *image_info,ExceptionInfo *exception)
   c2=chroma2;
   for (y=0; y < (long) height; y+=2)
   {
-    (void) ReadBlob(image,width,yy);
+    count=ReadBlob(image,width,yy);
     yy+=image->columns;
-    (void) ReadBlob(image,width,yy);
+    count=ReadBlob(image,width,yy);
     yy+=image->columns;
-    (void) ReadBlob(image,width >> 1,c1);
+    count=ReadBlob(image,width >> 1,c1);
     c1+=image->columns;
-    (void) ReadBlob(image,width >> 1,c2);
+    count=ReadBlob(image,width >> 1,c2);
     c2+=image->columns;
   }
   if (scene >= 4)
