@@ -10,7 +10,7 @@
 %                            P       CCCC  LLLLL                              %
 %                                                                             %
 %                                                                             %
-%                        Write HP PCL Printer Format.                         %
+%                      Read/Write HP PCL Printer Format.                      %
 %                                                                             %
 %                              Software Design                                %
 %                                John Cristy                                  %
@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -47,15 +47,23 @@
 #include "magick/color-private.h"
 #include "magick/colorspace.h"
 #include "magick/constitute.h"
+#include "magick/delegate.h"
 #include "magick/exception.h"
 #include "magick/exception-private.h"
 #include "magick/geometry.h"
+#include "magick/image.h"
 #include "magick/image-private.h"
+#include "magick/list.h"
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
+#include "magick/profile.h"
+#include "magick/resource_.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/token.h"
+#include "magick/transform.h"
+#include "magick/utility.h"
 
 /*
   Forward declarations.
@@ -106,6 +114,260 @@ static MagickBooleanType IsPCL(const unsigned char *magick,const size_t length)
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   R e a d P C L I m a g e                                                   %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  ReadPCLImage() reads a Printer Control Language image file and returns it.
+%  It allocates the memory necessary for the new Image structure and returns a
+%  pointer to the new image.
+%
+%  The format of the ReadPCLImage method is:
+%
+%      Image *ReadPCLImage(const ImageInfo *image_info,ExceptionInfo *exception)
+%
+%  A description of each parameter follows:
+%
+%    o image_info: The image info.
+%
+%    o exception: return any errors or warnings in this structure.
+%
+%
+*/
+static Image *ReadPCLImage(const ImageInfo *image_info,ExceptionInfo *exception)
+{
+#define CropBox  "CropBox"
+#define DeviceCMYK  "DeviceCMYK"
+#define MediaBox  "MediaBox"
+#define RenderPCLText  "  Rendering PCL...  "
+
+  char
+    command[MaxTextExtent],
+    density[MaxTextExtent],
+    filename[MaxTextExtent],
+    geometry[MaxTextExtent],
+    options[MaxTextExtent];
+
+  const DelegateInfo
+    *delegate_info;
+
+  double
+    dx_resolution,
+    dy_resolution;
+
+  Image
+    *image,
+    *next_image;
+
+  ImageInfo
+    *read_info;
+
+  MagickBooleanType
+    cmyk,
+    status;
+
+  RectangleInfo
+    bounding_box,
+    page;
+
+  register char
+    *p;
+
+  register long
+    c;
+
+  SegmentInfo
+    bounds;
+
+  ssize_t
+    count;
+
+  unsigned long
+    height,
+    width;
+
+  assert(image_info != (const ImageInfo *) NULL);
+  assert(image_info->signature == MagickSignature);
+  if (image_info->debug != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image_info->filename);
+  assert(exception != (ExceptionInfo *) NULL);
+  assert(exception->signature == MagickSignature);
+  /*
+    Open image file.
+  */
+  image=AllocateImage(image_info);
+  status=OpenBlob(image_info,image,ReadBinaryBlobMode,exception);
+  if (status == MagickFalse)
+    {
+      image=DestroyImageList(image);
+      return((Image *) NULL);
+    }
+  /*
+    Set the page density.
+  */
+  dx_resolution=DefaultResolution;
+  dy_resolution=DefaultResolution;
+  if ((image->x_resolution == 0.0) || (image->y_resolution == 0.0))
+    {
+      GeometryInfo
+        geometry_info;
+
+      MagickStatusType
+        flags;
+
+      flags=ParseGeometry(PSDensityGeometry,&geometry_info);
+      image->x_resolution=geometry_info.rho;
+      image->y_resolution=geometry_info.sigma;
+      if ((flags & SigmaValue) == 0)
+        image->y_resolution=image->x_resolution;
+    }
+  (void) FormatMagickString(density,MaxTextExtent,"%gx%g",
+    image->x_resolution,image->y_resolution);
+  /*
+    Determine page geometry from the PCL media box.
+  */
+  cmyk=MagickFalse;
+  count=0;
+  (void) ResetMagickMemory(&bounding_box,0,sizeof(bounding_box));
+  (void) ResetMagickMemory(&bounds,0,sizeof(bounds));
+  (void) ResetMagickMemory(&page,0,sizeof(page));
+  for (p=command; (c=ReadBlobByte(image)) != EOF; )
+  {
+    if (image_info->page != (char *) NULL)
+      continue;
+    /*
+      Note PCL elements.
+    */
+    *p++=(char) c;
+    if ((c != (int) '/') && ((size_t) (p-command) < (MaxTextExtent-1)))
+      continue;
+    *p='\0';
+    p=command;
+    /*
+      Is this a CMYK document?
+    */
+    if (LocaleNCompare(DeviceCMYK,command,strlen(DeviceCMYK)) == 0)
+      cmyk=MagickTrue;
+    if (LocaleNCompare(CropBox,command,strlen(CropBox)) == 0)
+      {
+        /*
+          Note region defined by crop box.
+        */
+        count=(ssize_t) sscanf(command,"CropBox [%lf %lf %lf %lf",
+          &bounds.x1,&bounds.y1,&bounds.x2,&bounds.y2);
+        if (count != 4)
+          count=(ssize_t) sscanf(command,"CropBox[%lf %lf %lf %lf",
+            &bounds.x1,&bounds.y1,&bounds.x2,&bounds.y2);
+      }
+    if (LocaleNCompare(MediaBox,command,strlen(MediaBox)) == 0)
+      {
+        /*
+          Note region defined by media box.
+        */
+        count=(ssize_t) sscanf(command,"MediaBox [%lf %lf %lf %lf",
+          &bounds.x1,&bounds.y1,&bounds.x2,&bounds.y2);
+        if (count != 4)
+          count=(ssize_t) sscanf(command,"MediaBox[%lf %lf %lf %lf",
+            &bounds.x1,&bounds.y1,&bounds.x2,&bounds.y2);
+      }
+    if (count != 4)
+      continue;
+    /*
+      Set PCL render geometry.
+    */
+    width=(unsigned long) (bounds.x2-bounds.x1+0.5);
+    height=(unsigned long) (bounds.y2-bounds.y1+0.5);
+    if (width > page.width)
+      page.width=width;
+    if (height > page.height)
+      page.height=height;
+  }
+  CloseBlob(image);
+  /*
+    Render PCL with the GhostPCL delegate.
+  */
+  if ((page.width == 0) || (page.height == 0))
+    (void) ParseAbsoluteGeometry(PSPageGeometry,&page);
+  if (image_info->page != (char *) NULL)
+    (void) ParseAbsoluteGeometry(image_info->page,&page);
+  page.width=(unsigned long)
+    (page.width*image->x_resolution/dx_resolution+0.5);
+  page.height=(unsigned long)
+    (page.height*image->y_resolution/dy_resolution+0.5);
+  image=DestroyImage(image);
+  (void) FormatMagickString(geometry,MaxTextExtent,"%lux%lu",
+    page.width,page.height);
+  if (image_info->monochrome != MagickFalse)
+    delegate_info=GetDelegateInfo("pcl-mono",(char *) NULL,exception);
+  else
+     if (cmyk != MagickFalse)
+       delegate_info=GetDelegateInfo("pcl-cmyk",(char *) NULL,exception);
+     else
+       delegate_info=GetDelegateInfo("pcl-color",(char *) NULL,exception);
+  if (delegate_info == (const DelegateInfo *) NULL)
+    return((Image *) NULL);
+  *options='\0';
+  read_info=CloneImageInfo(image_info);
+  *read_info->magick='\0';
+  if (read_info->number_scenes != 0)
+    {
+      if (read_info->number_scenes != 1)
+        (void) FormatMagickString(options,MaxTextExtent,"-dLastPage=%lu",
+          read_info->scene+read_info->number_scenes);
+      else
+        (void) FormatMagickString(options,MaxTextExtent,
+          "-dFirstPage=%lu -dLastPage=%lu",read_info->scene+1,read_info->scene+
+          read_info->number_scenes);
+      read_info->number_scenes=0;
+      if (read_info->scenes != (char *) NULL)
+        *read_info->scenes='\0';
+    }
+  if (read_info->authenticate != (char *) NULL)
+    (void) FormatMagickString(options+strlen(options),MaxTextExtent,
+      " -sPCLPassword=%s",read_info->authenticate);
+  (void) CopyMagickString(filename,read_info->filename,MaxTextExtent);
+  (void) AcquireUniqueFilename(read_info->filename);
+  (void) FormatMagickString(command,MaxTextExtent,
+    GetDelegateCommands(delegate_info),
+    read_info->antialias != MagickFalse ? 4 : 1,
+    read_info->antialias != MagickFalse ? 4 : 1,geometry,density,options,
+    read_info->filename,image_info->filename);
+  status=(MagickBooleanType) SystemCommand(read_info->verbose,command);
+  image=ReadImage(read_info,exception);
+  (void) RelinquishUniqueFileResource(read_info->filename);
+  read_info=DestroyImageInfo(read_info);
+  if (image == (Image *) NULL)
+    ThrowReaderException(DelegateError,"PCLDelegateFailed");
+  if (LocaleCompare(image->magick,"BMP") == 0)
+    {
+      Image
+        *cmyk_image;
+
+      cmyk_image=ConsolidateCMYKImages(image,&image->exception);
+      if (cmyk_image != (Image *) NULL)
+        {
+          image=DestroyImageList(image);
+          image=cmyk_image;
+        }
+    }
+  do
+  {
+    (void) CopyMagickString(image->filename,filename,MaxTextExtent);
+    image->page=page;
+    next_image=SyncNextImageInList(image);
+    if (next_image != (Image *) NULL)
+      image=next_image;
+  } while (next_image != (Image *) NULL);
+  return(GetFirstImageInList(image));
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   R e g i s t e r P C L I m a g e                                           %
 %                                                                             %
 %                                                                             %
@@ -130,10 +392,11 @@ ModuleExport void RegisterPCLImage(void)
     *entry;
 
   entry=SetMagickInfo("PCL");
+  entry->decoder=(DecoderHandler *) ReadPCLImage;
   entry->encoder=(EncoderHandler *) WritePCLImage;
   entry->magick=(MagickHandler *) IsPCL;
   entry->adjoin=MagickFalse;
-  entry->description=AcquireString("Page Control Language");
+  entry->description=AcquireString("Printer Control Language");
   entry->module=AcquireString("PCL");
   (void) RegisterMagickInfo(entry);
 }
