@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -320,7 +320,7 @@ static Image *ReadPCXImage(const ImageInfo *image_info,ExceptionInfo *exception)
       AcquireMagickMemory(3*256*sizeof(*pcx_colormap));
     if (pcx_colormap == (unsigned char *) NULL)
       ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
-    (void) ReadBlob(image,3*image->colors,pcx_colormap);
+    count=ReadBlob(image,3*image->colors,pcx_colormap);
     pcx_info.reserved=ReadBlobByte(image);
     pcx_info.planes=ReadBlobByte(image);
     if ((pcx_info.bits_per_pixel != 8) || (pcx_info.planes == 1))
@@ -365,6 +365,8 @@ static Image *ReadPCXImage(const ImageInfo *image_info,ExceptionInfo *exception)
       while (pcx_packets != 0)
       {
         packet=ReadBlobByte(image);
+        if (EOFBlob(image) != MagickFalse)
+          break;
         *p++=packet;
         pcx_packets--;
       }
@@ -372,6 +374,8 @@ static Image *ReadPCXImage(const ImageInfo *image_info,ExceptionInfo *exception)
       while (pcx_packets != 0)
       {
         packet=ReadBlobByte(image);
+        if (EOFBlob(image) != MagickFalse)
+          break;
         if ((packet & 0xc0) != 0xc0)
           {
             *p++=packet;
@@ -379,7 +383,10 @@ static Image *ReadPCXImage(const ImageInfo *image_info,ExceptionInfo *exception)
             continue;
           }
         count=packet & 0x3f;
-        for (packet=ReadBlobByte(image); count != 0; count--)
+        packet=ReadBlobByte(image);
+        if (EOFBlob(image) != MagickFalse)
+          break;
+        for ( ; count != 0; count--)
         {
           *p++=packet;
           pcx_packets--;
@@ -417,7 +424,7 @@ static Image *ReadPCXImage(const ImageInfo *image_info,ExceptionInfo *exception)
                   256 color images have their color map at the end of the file.
                 */
                 pcx_info.colormap_signature=ReadBlobByte(image);
-                (void) ReadBlob(image,3*image->colors,pcx_colormap);
+                count=ReadBlob(image,3*image->colors,pcx_colormap);
                 p=pcx_colormap;
                 for (i=0; i < (long) image->colors; i++)
                 {
@@ -866,6 +873,7 @@ static MagickBooleanType WritePCXImage(const ImageInfo *image_info,Image *image)
     {
       case UndefinedResolution:
       case PixelsPerInchResolution:
+      default:
       {
         pcx_info.horizontal_resolution=(unsigned short) image->x_resolution;
         pcx_info.vertical_resolution=(unsigned short) image->y_resolution;
