@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -320,8 +320,8 @@ static Image *ReadPDBImage(const ImageInfo *image_info,ExceptionInfo *exception)
   pdb_info.modify_number=ReadBlobMSBLong(image);
   pdb_info.application_info=ReadBlobMSBLong(image);
   pdb_info.sort_info=ReadBlobMSBLong(image);
-  (void) ReadBlob(image,4,(unsigned char *) pdb_info.type);
-  (void) ReadBlob(image,4,(unsigned char *) pdb_info.id);
+  count=ReadBlob(image,4,(unsigned char *) pdb_info.type);
+  count=ReadBlob(image,4,(unsigned char *) pdb_info.id);
   if ((count == 0) || (memcmp(pdb_info.type,"vIMG",4) != 0) ||
       (memcmp(pdb_info.id,"View",4) != 0))
     ThrowReaderException(CorruptImageError,"ImproperImageHeader");
@@ -334,7 +334,7 @@ static Image *ReadPDBImage(const ImageInfo *image_info,ExceptionInfo *exception)
     Read record header.
   */
   offset=(long) ReadBlobMSBLong(image);
-  (void) ReadBlob(image,3,(unsigned char *) tag);
+  count=ReadBlob(image,3,(unsigned char *) tag);
   record_type=ReadBlobByte(image);
   if (((record_type != 0x00) && (record_type != 0x01)) ||
       (memcmp(tag,"\x40\x6f\x80",3) != 0))
@@ -347,7 +347,7 @@ static Image *ReadPDBImage(const ImageInfo *image_info,ExceptionInfo *exception)
   if (pdb_info.number_records > 1)
     {
       offset=(long) ReadBlobMSBLong(image);
-      (void) ReadBlob(image,3,(unsigned char *) tag);
+      count=ReadBlob(image,3,(unsigned char *) tag);
       record_type=ReadBlobByte(image);
       if (((record_type != 0x00) && (record_type != 0x01)) ||
           (memcmp(tag,"\x40\x6f\x80",3) != 0))
@@ -361,7 +361,7 @@ static Image *ReadPDBImage(const ImageInfo *image_info,ExceptionInfo *exception)
   /*
     Read image header.
   */
-  (void) ReadBlob(image,32,(unsigned char *) pdb_image.name);
+  count=ReadBlob(image,32,(unsigned char *) pdb_image.name);
   pdb_image.version=ReadBlobByte(image);
   pdb_image.type=ReadBlobByte(image);
   pdb_image.reserved_1=ReadBlobMSBLong(image);
@@ -397,7 +397,7 @@ static Image *ReadPDBImage(const ImageInfo *image_info,ExceptionInfo *exception)
     case 0:
     {
       image->compression=NoCompression;
-      (void) ReadBlob(image,packets,pixels);
+      count=ReadBlob(image,packets,pixels);
       break;
     }
     case 1:
