@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -144,7 +144,7 @@ static Image *ReadPDFImage(const ImageInfo *image_info,ExceptionInfo *exception)
 #define CropBox  "CropBox"
 #define DeviceCMYK  "DeviceCMYK"
 #define MediaBox  "MediaBox"
-#define RenderPostscriptText  "  Rendering postscript...  "
+#define RenderPostscriptText  "  Rendering Postscript...  "
 
   char
     command[MaxTextExtent],
@@ -193,6 +193,7 @@ static Image *ReadPDFImage(const ImageInfo *image_info,ExceptionInfo *exception)
 
   unsigned long
     height,
+    scene,
     width;
 
   assert(image_info != (const ImageInfo *) NULL);
@@ -306,7 +307,7 @@ static Image *ReadPDFImage(const ImageInfo *image_info,ExceptionInfo *exception)
   (void) write(file," ",1);
   file=close(file)-1;
   /*
-    Render postscript with the Ghostscript delegate.
+    Render Postscript with the Ghostscript delegate.
   */
   if ((page.width == 0) || (page.height == 0))
     (void) ParseAbsoluteGeometry(PSPageGeometry,&page);
@@ -376,10 +377,12 @@ static Image *ReadPDFImage(const ImageInfo *image_info,ExceptionInfo *exception)
           image=cmyk_image;
         }
     }
+  scene=0;
   do
   {
     (void) CopyMagickString(image->filename,filename,MaxTextExtent);
     image->page=page;
+    image->scene=scene++;
     next_image=SyncNextImageInList(image);
     if (next_image != (Image *) NULL)
       image=next_image;
@@ -552,6 +555,7 @@ static MagickBooleanType WritePDFImage(const ImageInfo *image_info,Image *image)
     *tile_image;
 
   MagickBooleanType
+    matte,
     status;
 
   MagickOffsetType
@@ -630,6 +634,15 @@ static MagickBooleanType WritePDFImage(const ImageInfo *image_info,Image *image)
       break;
     }
 #endif
+#if !defined(HasJP2)
+    case JPEG2000Compression:
+    {
+      compression=RLECompression;
+      (void) ThrowMagickException(&image->exception,GetMagickModule(),
+        MissingDelegateError,"JP2LibraryIsNotAvailable","`%s'",image->filename);
+      break;
+    }
+#endif
 #if !defined(HasZLIB)
     case ZipCompression:
     {
@@ -653,10 +666,13 @@ static MagickBooleanType WritePDFImage(const ImageInfo *image_info,Image *image)
     Write Info object.
   */
   object=0;
-  if (image->matte == MagickFalse)
-    (void) WriteBlobString(image,"%PDF-1.3 \n");
+  if (compression == JPEG2000Compression)
+    (void) WriteBlobString(image,"%PDF-1.5 \n");
   else
-    (void) WriteBlobString(image,"%PDF-1.4 \n");
+    if (image->matte != MagickFalse)
+      (void) WriteBlobString(image,"%PDF-1.4 \n");
+    else
+      (void) WriteBlobString(image,"%PDF-1.3 \n");
   xref[object++]=TellBlob(image);
   info_id=object;
   (void) FormatMagickString(buffer,MaxTextExtent,"%lu 0 obj\n",object);
@@ -787,7 +803,7 @@ static MagickBooleanType WritePDFImage(const ImageInfo *image_info,Image *image)
         geometry.y=(long) (media_info.height+page_info.y-image->rows);
       }
     text_size=0;
-    attribute=GetImageAttribute(image,"label");
+    attribute=GetImageAttribute(image,"Label");
     if (attribute != (const ImageAttribute *) NULL)
       text_size=(unsigned long)
         (MultilineCensus(attribute->value)*image_info->pointsize+12);
@@ -806,9 +822,12 @@ static MagickBooleanType WritePDFImage(const ImageInfo *image_info,Image *image)
     (void) FormatMagickString(buffer,MaxTextExtent,
       "/Font << /F%lu %lu 0 R >>\n",image->scene,object+4);
     (void) WriteBlobString(image,buffer);
+    matte=image->matte;
+    if (IsGrayImage(image,&image->exception) != MagickFalse)
+      matte=MagickFalse;
     (void) FormatMagickString(buffer,MaxTextExtent,
       "/XObject << /Im%lu %lu 0 R >>\n",image->scene,object+
-      (image->matte != MagickFalse ? 7 : 5));
+      (matte != MagickFalse ? 7 : 5));
     (void) WriteBlobString(image,buffer);
     (void) FormatMagickString(buffer,MaxTextExtent,"/ProcSet %lu 0 R >>\n",
       object+3);
@@ -824,7 +843,7 @@ static MagickBooleanType WritePDFImage(const ImageInfo *image_info,Image *image)
       object+1);
     (void) WriteBlobString(image,buffer);
     (void) FormatMagickString(buffer,MaxTextExtent,"/Thumb %lu 0 R\n",
-      object+(image->matte != MagickFalse ? 10 : 8));
+      object+(matte != MagickFalse ? 10 : 8));
     (void) WriteBlobString(image,buffer);
     (void) WriteBlobString(image,">>\n");
     (void) WriteBlobString(image,"endobj\n");
@@ -843,7 +862,7 @@ static MagickBooleanType WritePDFImage(const ImageInfo *image_info,Image *image)
     offset=TellBlob(image);
     (void) WriteBlobString(image,"q\n");
     labels=(char **) NULL;
-    attribute=GetImageAttribute(image,"label");
+    attribute=GetImageAttribute(image,"Label");
     if (attribute != (const ImageAttribute *) NULL)
       labels=StringToList(attribute->value);
     if (labels != (char **) NULL)
@@ -917,7 +936,7 @@ static MagickBooleanType WritePDFImage(const ImageInfo *image_info,Image *image)
     (void) WriteBlobString(image,"/Encoding /MacRomanEncoding\n");
     (void) WriteBlobString(image,">>\n");
     (void) WriteBlobString(image,"endobj\n");
-    if (image->matte != MagickFalse)
+    if (matte != MagickFalse)
       {
         /*
           Write softmask object.
@@ -1088,6 +1107,15 @@ static MagickBooleanType WritePDFImage(const ImageInfo *image_info,Image *image)
         (void) strcpy(buffer,"/Decode [1 0 1 0 1 0 1 0]\n");
         break;
       }
+      case JPEG2000Compression:
+      {
+        (void) FormatMagickString(buffer,MaxTextExtent,CFormat,"JPXDecode");
+        if (image->colorspace != CMYKColorspace)
+          break;
+        (void) WriteBlobString(image,buffer);
+        (void) strcpy(buffer,"/Decode [1 0 1 0 1 0 1 0]\n");
+        break;
+      }
       case LZWCompression:
       {
          (void) FormatMagickString(buffer,MaxTextExtent,CFormat,"LZWDecode");
@@ -1126,7 +1154,7 @@ static MagickBooleanType WritePDFImage(const ImageInfo *image_info,Image *image)
     (void) FormatMagickString(buffer,MaxTextExtent,"/BitsPerComponent %d\n",
       compression == FaxCompression ? 1 : 8);
     (void) WriteBlobString(image,buffer);
-    if (image->matte != MagickFalse)
+    if (matte != MagickFalse)
       {
         (void) FormatMagickString(buffer,MaxTextExtent,"/SMask %lu 0 R\n",
           object-2);
@@ -1139,11 +1167,12 @@ static MagickBooleanType WritePDFImage(const ImageInfo *image_info,Image *image)
     (void) WriteBlobString(image,"stream\n");
     offset=TellBlob(image);
     number_pixels=(MagickSizeType) image->columns*image->rows;
-    if (number_pixels != (MagickSizeType) ((size_t) number_pixels))
+    if ((4*number_pixels) != (MagickSizeType) ((size_t) (4*number_pixels)))
       ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
     if ((compression == FaxCompression) ||
         ((image_info->type != TrueColorType) &&
          (IsGrayImage(image,&image->exception) != MagickFalse)))
+
       {
         switch (compression)
         {
@@ -1164,6 +1193,13 @@ static MagickBooleanType WritePDFImage(const ImageInfo *image_info,Image *image)
               ThrowWriterException(CoderError,image->exception.reason);
             break;
           }
+          case JPEG2000Compression:
+          {
+            status=JP2EncodeImage(image_info,image);
+            if (status == MagickFalse)
+              ThrowWriterException(CoderError,image->exception.reason);
+            break;
+          }
           case RLECompression:
           default:
           {
@@ -1251,7 +1287,8 @@ static MagickBooleanType WritePDFImage(const ImageInfo *image_info,Image *image)
       }
     else
       if ((image->storage_class == DirectClass) || (image->colors > 256) ||
-          (compression == JPEGCompression))
+          (compression == JPEGCompression) ||
+          (compression == JPEG2000Compression))
         switch (compression)
         {
           case JPEGCompression:
@@ -1261,6 +1298,13 @@ static MagickBooleanType WritePDFImage(const ImageInfo *image_info,Image *image)
               ThrowWriterException(CoderError,image->exception.reason);
             break;
           }
+          case JPEG2000Compression:
+          {
+            status=JP2EncodeImage(image_info,image);
+            if (status == MagickFalse)
+              ThrowWriterException(CoderError,image->exception.reason);
+            break;
+          }
           case RLECompression:
           default:
           {
@@ -1471,7 +1515,8 @@ static MagickBooleanType WritePDFImage(const ImageInfo *image_info,Image *image)
           (void) strcpy(buffer,"/DeviceGray\n");
       else
         if ((image->storage_class == DirectClass) || (image->colors > 256) ||
-            (compression == JPEGCompression))
+            (compression == JPEGCompression) ||
+            (compression == JPEG2000Compression))
           (void) strcpy(buffer,"/DeviceRGB\n");
         else
           (void) FormatMagickString(buffer,MaxTextExtent,
@@ -1509,6 +1554,15 @@ static MagickBooleanType WritePDFImage(const ImageInfo *image_info,Image *image)
         (void) strcpy(buffer,"/Decode [1 0 1 0 1 0 1 0]\n");
         break;
       }
+      case JPEG2000Compression:
+      {
+        (void) FormatMagickString(buffer,MaxTextExtent,CFormat,"JPXDecode");
+        if (image->colorspace != CMYKColorspace)
+          break;
+        (void) WriteBlobString(image,buffer);
+        (void) strcpy(buffer,"/Decode [1 0 1 0 1 0 1 0]\n");
+        break;
+      }
       case LZWCompression:
       {
         (void) FormatMagickString(buffer,MaxTextExtent,CFormat,"LZWDecode");
@@ -1576,6 +1630,13 @@ static MagickBooleanType WritePDFImage(const ImageInfo *image_info,Image *image)
               ThrowWriterException(CoderError,tile_image->exception.reason);
             break;
           }
+          case JPEG2000Compression:
+          {
+            status=JP2EncodeImage(image_info,tile_image);
+            if (status == MagickFalse)
+              ThrowWriterException(CoderError,tile_image->exception.reason);
+            break;
+          }
           case RLECompression:
           default:
           {
@@ -1649,7 +1710,8 @@ static MagickBooleanType WritePDFImage(const ImageInfo *image_info,Image *image)
       }
     else
       if ((tile_image->storage_class == DirectClass) ||
-          (tile_image->colors > 256) || (compression == JPEGCompression))
+          (tile_image->colors > 256) || (compression == JPEGCompression) ||
+          (compression == JPEG2000Compression))
         switch (compression)
         {
           case JPEGCompression:
@@ -1659,6 +1721,13 @@ static MagickBooleanType WritePDFImage(const ImageInfo *image_info,Image *image)
               ThrowWriterException(CoderError,tile_image->exception.reason);
             break;
           }
+          case JPEG2000Compression:
+          {
+            status=JP2EncodeImage(image_info,tile_image);
+            if (status == MagickFalse)
+              ThrowWriterException(CoderError,tile_image->exception.reason);
+            break;
+          }
           case RLECompression:
           default:
           {
