@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -423,6 +423,9 @@ static unsigned char *DecodeImage(const ImageInfo *image_info,Image *blob,
   size_t
     length;
 
+  ssize_t
+    count;
+
   unsigned char
     *pixels,
     *scanline;
@@ -475,7 +478,7 @@ static unsigned char *DecodeImage(const ImageInfo *image_info,Image *blob,
       {
         q=pixels+y*width;
         number_pixels=bytes_per_line;
-        (void) ReadBlob(blob,number_pixels,scanline);
+        count=ReadBlob(blob,number_pixels,scanline);
         p=ExpandBuffer(scanline,&number_pixels,bits_per_pixel);
         (void) CopyMagickMemory(q,p,number_pixels);
       }
@@ -498,7 +501,7 @@ static unsigned char *DecodeImage(const ImageInfo *image_info,Image *blob,
            CorruptImageError,"UnableToUncompressImage","`%s'",image->filename);
         break;
       }
-    (void) ReadBlob(blob,scanline_length,scanline);
+    count=ReadBlob(blob,scanline_length,scanline);
     for (j=0; j < (long) scanline_length; )
       if ((scanline[j] & 0x80) == 0)
         {
@@ -799,6 +802,9 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
   size_t
     length;
 
+  ssize_t
+    count;
+
   StringInfo
     *profile;
 
@@ -889,7 +895,7 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
               break;
             image->columns=frame.right-frame.left;
             image->rows=frame.bottom-frame.top;
-            SetImage(image,OpaqueOpacity);
+            SetImageBackgroundColor(image);
             break;
           }
           case 0x12:
@@ -1213,7 +1219,7 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
             info=(unsigned char *) AcquireMagickMemory(length);
             if (info == (unsigned char *) NULL)
               break;
-            (void) ReadBlob(image,length,info);
+            count=ReadBlob(image,length,info);
             switch (type)
             {
               case 0xe0:
