@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -295,7 +295,7 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
     /*
       Initialize image structure.
     */
-    if ((count == 0) || (format != 'P'))
+    if ((count != 1) || (format != 'P'))
       ThrowReaderException(CorruptImageError,"ImproperImageHeader");
     format=(char) ReadBlobByte(image);
     if (format == '7')
@@ -323,7 +323,7 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
         */
         if (AllocateImageColormap(image,image->colors) == MagickFalse)
           ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
-        if (format == '7')
+        if ((format == '7') && (image->colors == 256))
           {
             /*
               Initialize 332 colormap.
@@ -542,7 +542,7 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
         for (y=0; y < (long) image->rows; y++)
         {
           count=ReadBlob(image,(size_t) packets*image->columns,pixels);
-          if (count == 0)
+          if (count != (ssize_t) (packets*image->columns))
             ThrowReaderException(CorruptImageError,"UnableToReadImageData");
           p=pixels;
           q=SetImagePixels(image,0,y,image->columns,1);
@@ -607,7 +607,7 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
         for (y=0; y < (long) image->rows; y++)
         {
           count=ReadBlob(image,packets*image->columns,pixels);
-          if (count == 0)
+          if (count != (ssize_t) (packets*image->columns))
             ThrowReaderException(CorruptImageError,"UnableToReadImageData");
           p=pixels;
           q=SetImagePixels(image,0,y,image->columns,1);
@@ -689,7 +689,7 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
           break;
       } while (format != '\n');
     count=ReadBlob(image,1,(unsigned char *) &format);
-    if ((count != 0) && (format == 'P'))
+    if ((count == 1) && (format == 'P'))
       {
         /*
           Allocate next image structure.
@@ -709,7 +709,7 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
               break;
           }
       }
-  } while ((count != 0) && (format == 'P'));
+  } while ((count == 1) && (format == 'P'));
   CloseBlob(image);
   return(GetFirstImageInList(image));
 }
