@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -175,7 +175,7 @@ static Image *ReadPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
 #define PageMedia  "PageMedia:"
 #define PhotoshopProfile  "BeginPhotoshop:"
 #define PostscriptLevel  "%!PS-"
-#define RenderPostscriptText  "  Rendering postscript...  "
+#define RenderPostscriptText  "  Rendering Postscript...  "
 
   char
     command[MaxTextExtent],
@@ -241,6 +241,7 @@ static Image *ReadPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
   unsigned long
     height,
     length,
+    scene,
     width;
 
   /*
@@ -406,7 +407,7 @@ static Image *ReadPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
   (void) write(file,translate_geometry,strlen(translate_geometry));
   file=close(file)-1;
   /*
-    Render postscript with the Ghostscript delegate.
+    Render Postscript with the Ghostscript delegate.
   */
   if ((page.width == 0) || (page.height == 0))
     (void) ParseAbsoluteGeometry(PSPageGeometry,&page);
@@ -492,12 +493,14 @@ static Image *ReadPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
           image=cmyk_image;
         }
     }
+  scene=0;
   do
   {
     (void) CopyMagickString(image->filename,filename,MaxTextExtent);
     if (iptc_profile != (StringInfo *) NULL)
       (void) SetImageProfile(image,"iptc",iptc_profile);
     image->page=page;
+    image->scene=scene++;
     next_image=SyncNextImageInList(image);
     if (next_image != (Image *) NULL)
       image=next_image;
@@ -1064,7 +1067,7 @@ static MagickBooleanType WritePSImage(const ImageInfo *image_info,Image *image)
         geometry.y=(long) (media_info.height+page_info.y-image->rows);
       }
     text_size=0;
-    attribute=GetImageAttribute(image,"label");
+    attribute=GetImageAttribute(image,"Label");
     if (attribute != (const ImageAttribute *) NULL)
       text_size=(unsigned long)
         (MultilineCensus(attribute->value)*image_info->pointsize+12);
@@ -1109,7 +1112,7 @@ static MagickBooleanType WritePSImage(const ImageInfo *image_info,Image *image)
               bounds.x2,bounds.y2);
           }
         (void) WriteBlobString(image,buffer);
-        attribute=GetImageAttribute(image,"label");
+        attribute=GetImageAttribute(image,"Label");
         if (attribute != (const ImageAttribute *) NULL)
           (void) WriteBlobString(image,
             "%%DocumentNeededResources: font Times-Roman\n");
@@ -1221,7 +1224,7 @@ static MagickBooleanType WritePSImage(const ImageInfo *image_info,Image *image)
           (void) FormatMagickString(buffer,MaxTextExtent,"%s\n",*q);
           (void) WriteBlobString(image,buffer);
         }
-        attribute=GetImageAttribute(image,"label");
+        attribute=GetImageAttribute(image,"Label");
         if (attribute != (const ImageAttribute *) NULL)
           for (j=(long) MultilineCensus(attribute->value)-1; j >= 0; j--)
           {
@@ -1257,7 +1260,7 @@ static MagickBooleanType WritePSImage(const ImageInfo *image_info,Image *image)
       bounds.x2=(double) geometry.x+geometry.width-1;
     if ((double) (geometry.y+(geometry.height+text_size)-1) > bounds.y2)
       bounds.y2=(double) geometry.y+(geometry.height+text_size)-1;
-    attribute=GetImageAttribute(image,"label");
+    attribute=GetImageAttribute(image,"Label");
     if (attribute != (const ImageAttribute *) NULL)
       (void) WriteBlobString(image,"%%%%PageResources: font Times-Roman\n");
     if (LocaleCompare(image_info->magick,"PS") != 0)
@@ -1270,7 +1273,7 @@ static MagickBooleanType WritePSImage(const ImageInfo *image_info,Image *image)
       geometry.x,geometry.y,x_scale,y_scale,image_info->pointsize);
     (void) WriteBlobString(image,buffer);
     labels=(char **) NULL;
-    attribute=GetImageAttribute(image,"label");
+    attribute=GetImageAttribute(image,"Label");
     if (attribute != (const ImageAttribute *) NULL)
       labels=StringToList(attribute->value);
     if (labels != (char **) NULL)
