@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -488,7 +488,7 @@ static MagickBooleanType WritePS2Image(const ImageInfo *image_info,Image *image)
         geometry.y=(long) (media_info.height+page_info.y-image->rows);
       }
     text_size=0;
-    attribute=GetImageAttribute(image,"label");
+    attribute=GetImageAttribute(image,"Label");
     if (attribute != (const ImageAttribute *) NULL)
       text_size=(unsigned long)
         (MultilineCensus(attribute->value)*image_info->pointsize+12);
@@ -532,7 +532,7 @@ static MagickBooleanType WritePS2Image(const ImageInfo *image_info,Image *image)
               bounds.x2,bounds.y2);
           }
         (void) WriteBlobString(image,buffer);
-        attribute=GetImageAttribute(image,"label");
+        attribute=GetImageAttribute(image,"Label");
         if (attribute != (const ImageAttribute *) NULL)
           (void) WriteBlobString(image,
             "%%DocumentNeededResources: font Helvetica\n");
@@ -593,7 +593,7 @@ static MagickBooleanType WritePS2Image(const ImageInfo *image_info,Image *image)
           (void) WriteBlobString(image,buffer);
           (void) WriteBlobByte(image,'\n');
         }
-        attribute=GetImageAttribute(image,"label");
+        attribute=GetImageAttribute(image,"Label");
         if (attribute != (const ImageAttribute *) NULL)
           for (j=(long) MultilineCensus(attribute->value)-1; j >= 0; j--)
           {
@@ -629,7 +629,7 @@ static MagickBooleanType WritePS2Image(const ImageInfo *image_info,Image *image)
       bounds.x2=(double) geometry.x+geometry.width-1;
     if ((double) (geometry.y+(geometry.height+text_size)-1) > bounds.y2)
       bounds.y2=(double) geometry.y+(geometry.height+text_size)-1;
-    attribute=GetImageAttribute(image,"label");
+    attribute=GetImageAttribute(image,"Label");
     if (attribute != (const ImageAttribute *) NULL)
       (void) WriteBlobString(image,"%%PageResources: font Times-Roman\n");
     if (LocaleCompare(image_info->magick,"PS2") != 0)
@@ -648,7 +648,7 @@ static MagickBooleanType WritePS2Image(const ImageInfo *image_info,Image *image)
       geometry.x,geometry.y,x_scale,y_scale,image_info->pointsize);
     (void) WriteBlobString(image,buffer);
     labels=(char **) NULL;
-    attribute=GetImageAttribute(image,"label");
+    attribute=GetImageAttribute(image,"Label");
     if (attribute != (const ImageAttribute *) NULL)
       labels=StringToList(attribute->value);
     if (labels != (char **) NULL)
