@@ -24,7 +24,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -937,7 +937,7 @@ static MagickBooleanType WritePS3Image(const ImageInfo *image_info,Image *image)
         geometry.y=(long) (media_info.height+page_info.y-image->rows);
       }
     text_size=0;
-    attribute=GetImageAttribute(image,"label");
+    attribute=GetImageAttribute(image,"Label");
     if (attribute != (const ImageAttribute *) NULL)
       text_size=(unsigned long)
         (MultilineCensus(attribute->value)*image_info->pointsize+12);
@@ -996,7 +996,7 @@ static MagickBooleanType WritePS3Image(const ImageInfo *image_info,Image *image)
         /*
           Font resources
         */
-        attribute=GetImageAttribute(image,"label");
+        attribute=GetImageAttribute(image,"Label");
         if (attribute != (const ImageAttribute *) NULL)
           (void) WriteBlobString(image,
             "%%DocumentNeededResources: font Helvetica\n");
@@ -1030,7 +1030,7 @@ static MagickBooleanType WritePS3Image(const ImageInfo *image_info,Image *image)
         /*
           One label line for each line in label string.
         */
-        attribute=GetImageAttribute(image,"label");
+        attribute=GetImageAttribute(image,"Label");
         if (attribute != (const ImageAttribute *) NULL)
         {
           (void) WriteBlobString(image,"\n  % Labels.\n  /Helvetica findfont "
@@ -1086,7 +1086,7 @@ static MagickBooleanType WritePS3Image(const ImageInfo *image_info,Image *image)
     /*
       Page font resource if there's a label.
     */
-    attribute=GetImageAttribute(image,"label");
+    attribute=GetImageAttribute(image,"Label");
     if (attribute != (const ImageAttribute *) NULL)
       (void) WriteBlobString(image,"%%PageResources: font Helvetica\n");
     /*
@@ -1140,7 +1140,7 @@ static MagickBooleanType WritePS3Image(const ImageInfo *image_info,Image *image)
       Output labels.
     */
     labels=(char **) NULL;
-    attribute=GetImageAttribute(image,"label");
+    attribute=GetImageAttribute(image,"Label");
     if (attribute != (const ImageAttribute *) NULL)
       labels=StringToList(attribute->value);
     if (labels != (char **) NULL)
