@@ -24,7 +24,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -46,6 +46,7 @@
 #include "magick/blob-private.h"
 #include "magick/colorspace.h"
 #include "magick/constitute.h"
+#include "magick/enhance.h"
 #include "magick/exception.h"
 #include "magick/exception-private.h"
 #include "magick/image.h"
@@ -165,7 +166,7 @@ static MagickBooleanType DecodeImage(Image *image,const long channel)
             case 3:
             {
               if (image->colorspace == CMYKColorspace)
-                *indexes=(Quantum) pixel;
+                *indexes=(Quantum) (MaxRGB-pixel);
               else
                 q->opacity=(Quantum) (MaxRGB-pixel);
               break;
@@ -227,7 +228,7 @@ static MagickBooleanType DecodeImage(Image *image,const long channel)
         case 3:
         {
           if (image->colorspace == CMYKColorspace)
-            *indexes=(Quantum) pixel;
+            *indexes=(Quantum) (MaxRGB-pixel);
           else
             q->opacity=(Quantum) (MaxRGB-pixel);
           break;
@@ -659,7 +660,7 @@ static Image *ReadPSDImage(const ImageInfo *image_info,ExceptionInfo *exception)
   if ((count == 0) || (LocaleNCompare(psd_info.signature,"8BPS",4) != 0) ||
       (psd_info.version != 1))
     ThrowReaderException(CorruptImageError,"ImproperImageHeader");
-  (void) ReadBlob(image,6,psd_info.reserved);
+  count=ReadBlob(image,6,psd_info.reserved);
   psd_info.channels=ReadBlobMSBShort(image);
   if (psd_info.channels > MaxPSDChannels)
     ThrowReaderException(CorruptImageError,"MaximumChannelsExceeded");
@@ -678,7 +679,7 @@ static Image *ReadPSDImage(const ImageInfo *image_info,ExceptionInfo *exception)
   image->depth=psd_info.depth <= 8 ? 8UL : QuantumDepth;
   image->columns=psd_info.columns;
   image->rows=psd_info.rows;
-  SetImage(image,OpaqueOpacity);
+  SetImageBackgroundColor(image);
   image->matte=psd_info.channels >= 4 ? MagickTrue : MagickFalse;
   if (psd_info.mode == LabMode)
     image->colorspace=LABColorspace;
@@ -717,7 +718,7 @@ static Image *ReadPSDImage(const ImageInfo *image_info,ExceptionInfo *exception)
           data=(unsigned char *) AcquireMagickMemory(length);
           if (data == (unsigned char *) NULL)
             ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
-          (void) ReadBlob(image,length,data);
+          count=ReadBlob(image,length,data);
           data=(unsigned char *) RelinquishMagickMemory(data);
         }
       else
@@ -865,7 +866,7 @@ static Image *ReadPSDImage(const ImageInfo *image_info,ExceptionInfo *exception)
                     "  layer type was %.4s instead of 8BIM", type);
                  ThrowReaderException(CorruptImageError,"ImproperImageHeader");
               }
-            (void) ReadBlob(image,4,(unsigned char *) layer_info[i].blendkey);
+            count=ReadBlob(image,4,(unsigned char *) layer_info[i].blendkey);
             layer_info[i].opacity=(Quantum)
               (MaxRGB-ScaleCharToQuantum(ReadBlobByte(image)));
             layer_info[i].clipping=(unsigned char) ReadBlobByte(image);
@@ -979,7 +980,7 @@ static Image *ReadPSDImage(const ImageInfo *image_info,ExceptionInfo *exception)
               }
               ThrowReaderException(CorruptImageError,"ImproperImageHeader");
             }
-            (void) ReadBlob(image,4,alkey);
+            count=ReadBlob(image,4,alkey);
             length=ReadBlobMSBLong(image);
               if (debug != MagickFalse)
               {
@@ -1026,7 +1027,7 @@ static Image *ReadPSDImage(const ImageInfo *image_info,ExceptionInfo *exception)
             if (image->debug != MagickFalse)
               (void) LogMagickEvent(CoderEvent,GetMagickModule(),
                 "    setting up new layer image");
-            SetImage(layer_info[i].image,OpaqueOpacity);
+            SetImageBackgroundColor(layer_info[i].image);
             layer_info[i].image->compose=
               PSDBlendModeToCompositeOperator(layer_info[i].blendkey);
             if (layer_info[i].visible == MagickFalse)
@@ -1203,32 +1204,8 @@ static Image *ReadPSDImage(const ImageInfo *image_info,ExceptionInfo *exception)
                 }
               }
             if (layer_info[i].image->colorspace == CMYKColorspace)
-              {
-                /*
-                  Correct CMYK levels.
-                */
-                if (image->debug != MagickFalse)
-                  (void) LogMagickEvent(CoderEvent,GetMagickModule(),
-                    "    correcting CMYK values");
-                for (y=0; y < (long) layer_info[i].image->rows; y++)
-                {
-                  q=GetImagePixels(layer_info[i].image,0,y,
-                    layer_info[i].image->columns,1);
-                  if (q == (PixelPacket *) NULL)
-                    break;
-                  indexes=GetIndexes(layer_info[i].image);
-                  for (x=0; x < (long) layer_info[i].image->columns; x++)
-                  {
-                    q->red=(Quantum) (MaxRGB-q->red);
-                    q->green=(Quantum) (MaxRGB-q->green);
-                    q->blue=(Quantum) (MaxRGB-q->blue);
-                    indexes[x]=(IndexPacket) (MaxRGB-indexes[x]);
-                    q++;
-                  }
-                  if (SyncImagePixels(layer_info[i].image) == MagickFalse)
-                    break;
-                }
-              }
+              (void) NegateImageChannel(layer_info[i].image,AllChannels,
+                MagickFalse);
           }
         diff_offset = TellBlob(image) - offset;
         /* added by palf -> invisible group layer make layer of this group
@@ -1407,28 +1384,7 @@ static Image *ReadPSDImage(const ImageInfo *image_info,ExceptionInfo *exception)
       }
     }
   if (image->colorspace == CMYKColorspace)
-    {
-      /*
-        Correct CMYK levels.
-      */
-      for (y=0; y < (long) image->rows; y++)
-      {
-        q=GetImagePixels(image,0,y,image->columns,1);
-        if (q == (PixelPacket *) NULL)
-          break;
-        indexes=GetIndexes(image);
-        for (x=0; x < (long) image->columns; x++)
-        {
-          q->red=(Quantum) (MaxRGB-q->red);
-          q->green=(Quantum) (MaxRGB-q->green);
-          q->blue=(Quantum) (MaxRGB-q->blue);
-          indexes[x]=(IndexPacket) (MaxRGB-indexes[x]);
-          q++;
-        }
-        if (SyncImagePixels(image) == MagickFalse)
-          break;
-      }
-    }
+    (void) NegateImageChannel(image,AllChannels,MagickFalse);
   CloseBlob(image);
 
   return(GetFirstImageInList(image));
@@ -1563,13 +1519,18 @@ static void WriteImageChannels(Image* image,Image *tmp_image,
     }
   else
     {
+      if (tmp_image->colorspace == CMYKColorspace)
+        NegateImageChannel(image,AllChannels,MagickFalse);
       if (tmp_image->matte)
         WriteOneChannel(image,tmp_image,pixels,AlphaQuantum);
       WriteOneChannel(image,tmp_image,pixels,RedQuantum);
       WriteOneChannel(image,tmp_image,pixels,GreenQuantum);
       WriteOneChannel(image,tmp_image,pixels,BlueQuantum);
       if (tmp_image->colorspace == CMYKColorspace)
-        WriteOneChannel(image,tmp_image,pixels,BlackQuantum);
+        {
+          WriteOneChannel(image,tmp_image,pixels,BlackQuantum);
+          NegateImageChannel(image,AllChannels,MagickFalse);
+        }
     }
 }
 
