@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -54,6 +54,7 @@
 #include "magick/monitor.h"
 #include "magick/pixel.h"
 #include "magick/static.h"
+#include "magick/statistic.h"
 #include "magick/string_.h"
 #include "magick/utility.h"
 
@@ -169,7 +170,11 @@ static Image *ReadRGBImage(const ImageInfo *image_info,ExceptionInfo *exception)
       */
       image->scene++;
       for (y=0; y < (long) image->rows; y++)
-        (void) ReadBlob(image,packet_size*image->extract_info.width,scanline);
+      {
+        count=ReadBlob(image,packet_size*image->extract_info.width,scanline);
+        if (count != (ssize_t) (packet_size*image->extract_info.width))
+          break;
+      }
     }
   offset=(MagickOffsetType) (packet_size*image->extract_info.x);
   do
@@ -189,12 +194,20 @@ static Image *ReadRGBImage(const ImageInfo *image_info,ExceptionInfo *exception)
           No interlacing:  RGBRGBRGBRGBRGBRGB...
         */
         for (y=0; y < image->extract_info.y; y++)
-          (void) ReadBlob(image,packet_size*image->extract_info.width,scanline);
+        {
+          count=ReadBlob(image,packet_size*image->extract_info.width,scanline);
+          if (count != (ssize_t) (packet_size*image->extract_info.width))
+            break;
+        }
         for (y=0; y < (long) image->rows; y++)
         {
           if ((y > 0) || (image->previous == (Image *) NULL))
-            (void) ReadBlob(image,packet_size*image->extract_info.width,
-              scanline);
+            {
+              count=ReadBlob(image,packet_size*image->extract_info.width,
+                scanline);
+              if (count != (ssize_t) (packet_size*image->extract_info.width))
+                break;
+            }
           q=SetImagePixels(image,0,y,image->columns,1);
           if (q == (PixelPacket *) NULL)
             break;
@@ -219,7 +232,11 @@ static Image *ReadRGBImage(const ImageInfo *image_info,ExceptionInfo *exception)
         }
         width=image->extract_info.height-image->rows-image->extract_info.y;
         for (i=0; i < (long) width; i++)
-          (void) ReadBlob(image,packet_size*image->extract_info.width,scanline);
+        {
+          count=ReadBlob(image,packet_size*image->extract_info.width,scanline);
+          if (count != (ssize_t) (packet_size*image->extract_info.width))
+            break;
+        }
         break;
       }
       case LineInterlace:
@@ -229,25 +246,38 @@ static Image *ReadRGBImage(const ImageInfo *image_info,ExceptionInfo *exception)
         */
         packet_size=(size_t) (image->depth > 8 ? 2 : 1);
         for (y=0; y < image->extract_info.y; y++)
-          (void) ReadBlob(image,packet_size*image->extract_info.width,
-            scanline);
+        {
+          count=ReadBlob(image,packet_size*image->extract_info.width,scanline);
+          if (count != (ssize_t) (packet_size*image->extract_info.width))
+            break;
+        }
         for (y=0; y < (long) image->rows; y++)
         {
           if ((y > 0) || (image->previous == (Image *) NULL))
-            (void) ReadBlob(image,packet_size*image->extract_info.width,
-              scanline);
+            {
+              count=ReadBlob(image,packet_size*image->extract_info.width,
+                scanline);
+              if (count != (ssize_t) (packet_size*image->extract_info.width))
+                break;
+            }
           q=SetImagePixels(image,0,y,image->columns,1);
           if (q == (PixelPacket *) NULL)
             break;
           (void) ExportQuantumPixels(image,RedQuantum,0,scanline+offset);
-          (void) ReadBlob(image,packet_size*image->extract_info.width,scanline);
+          count=ReadBlob(image,packet_size*image->extract_info.width,scanline);
+          if (count != (ssize_t) (packet_size*image->extract_info.width))
+            break;
           (void) ExportQuantumPixels(image,GreenQuantum,0,scanline+offset);
-          (void) ReadBlob(image,packet_size*image->extract_info.width,scanline);
+          count=ReadBlob(image,packet_size*image->extract_info.width,scanline);
+          if (count != (ssize_t) (packet_size*image->extract_info.width))
+            break;
           (void) ExportQuantumPixels(image,BlueQuantum,0,scanline+offset);
           if (image->matte != MagickFalse)
             {
-              (void) ReadBlob(image,packet_size*image->extract_info.width,
+              count=ReadBlob(image,packet_size*image->extract_info.width,
                 scanline);
+              if (count != (ssize_t) (packet_size*image->extract_info.width))
+                break;
               if (LocaleCompare(image_info->magick,"RGBA") == 0)
                 (void) ExportQuantumPixels(image,AlphaQuantum,0,
                   scanline+offset);
@@ -269,7 +299,11 @@ static Image *ReadRGBImage(const ImageInfo *image_info,ExceptionInfo *exception)
         }
         width=image->extract_info.height-image->rows-image->extract_info.y;
         for (i=0; i < (long) width; i++)
-          (void) ReadBlob(image,packet_size*image->extract_info.width,scanline);
+        {
+          count=ReadBlob(image,packet_size*image->extract_info.width,scanline);
+          if (count != (ssize_t) (packet_size*image->extract_info.width))
+            break;
+        }
         break;
       }
       case PlaneInterlace:
@@ -293,14 +327,22 @@ static Image *ReadRGBImage(const ImageInfo *image_info,ExceptionInfo *exception)
           }
         packet_size=(size_t) (image->depth > 8 ? 2 : 1);
         for (y=0; y < image->extract_info.y; y++)
-          (void) ReadBlob(image,packet_size*image->extract_info.width,scanline);
+        {
+          count=ReadBlob(image,packet_size*image->extract_info.width,scanline);
+          if (count != (ssize_t) (packet_size*image->extract_info.width))
+            break;
+        }
         i=0;
         span=image->rows*(image->matte != MagickFalse ? 4 : 3);
         for (y=0; y < (long) image->rows; y++)
         {
           if ((y > 0) || (image->previous == (Image *) NULL))
-            (void) ReadBlob(image,packet_size*image->extract_info.width,
-              scanline);
+            {
+              count=ReadBlob(image,packet_size*image->extract_info.width,
+                scanline);
+              if (count != (ssize_t) (packet_size*image->extract_info.width))
+                break;
+            }
           q=SetImagePixels(image,0,y,image->columns,1);
           if (q == (PixelPacket *) NULL)
             break;
@@ -320,7 +362,11 @@ static Image *ReadRGBImage(const ImageInfo *image_info,ExceptionInfo *exception)
         }
         width=image->extract_info.height-image->rows-image->extract_info.y;
         for (i=0; i < (long) width; i++)
-          (void) ReadBlob(image,packet_size*image->extract_info.width,scanline);
+        {
+          count=ReadBlob(image,packet_size*image->extract_info.width,scanline);
+          if (count != (ssize_t) (packet_size*image->extract_info.width))
+            break;
+        }
         if (image_info->interlace == PartitionInterlace)
           {
             CloseBlob(image);
@@ -333,10 +379,16 @@ static Image *ReadRGBImage(const ImageInfo *image_info,ExceptionInfo *exception)
               }
           }
         for (y=0; y < image->extract_info.y; y++)
-          (void) ReadBlob(image,packet_size*image->extract_info.width,scanline);
+        {
+          count=ReadBlob(image,packet_size*image->extract_info.width,scanline);
+          if (count != (ssize_t) (packet_size*image->extract_info.width))
+            break;
+        }
         for (y=0; y < (long) image->rows; y++)
         {
-          (void) ReadBlob(image,packet_size*image->extract_info.width,scanline);
+          count=ReadBlob(image,packet_size*image->extract_info.width,scanline);
+          if (count != (ssize_t) (packet_size*image->extract_info.width))
+            break;
           q=GetImagePixels(image,0,y,image->columns,1);
           if (q == (PixelPacket *) NULL)
             break;
@@ -356,7 +408,11 @@ static Image *ReadRGBImage(const ImageInfo *image_info,ExceptionInfo *exception)
         }
         width=image->extract_info.height-image->rows-image->extract_info.y;
         for (i=0; i < (long) width; i++)
-          (void) ReadBlob(image,packet_size*image->extract_info.width,scanline);
+        {
+          count=ReadBlob(image,packet_size*image->extract_info.width,scanline);
+          if (count != (ssize_t) (packet_size*image->extract_info.width))
+            break;
+        }
         if (image_info->interlace == PartitionInterlace)
           {
             CloseBlob(image);
@@ -369,10 +425,16 @@ static Image *ReadRGBImage(const ImageInfo *image_info,ExceptionInfo *exception)
               }
           }
         for (y=0; y < image->extract_info.y; y++)
-          (void) ReadBlob(image,packet_size*image->extract_info.width,scanline);
+        {
+          count=ReadBlob(image,packet_size*image->extract_info.width,scanline);
+          if (count != (ssize_t) (packet_size*image->extract_info.width))
+            break;
+        }
         for (y=0; y < (long) image->rows; y++)
         {
-          (void) ReadBlob(image,packet_size*image->extract_info.width,scanline);
+          count=ReadBlob(image,packet_size*image->extract_info.width,scanline);
+          if (count != (ssize_t) (packet_size*image->extract_info.width))
+            break;
           q=GetImagePixels(image,0,y,image->columns,1);
           if (q == (PixelPacket *) NULL)
             break;
@@ -392,7 +454,11 @@ static Image *ReadRGBImage(const ImageInfo *image_info,ExceptionInfo *exception)
         }
         width=image->extract_info.height-image->rows-image->extract_info.y;
         for (i=0; i < (long) width; i++)
-          (void) ReadBlob(image,packet_size*image->extract_info.width,scanline);
+        {
+          count=ReadBlob(image,packet_size*image->extract_info.width,scanline);
+          if (count != (ssize_t) (packet_size*image->extract_info.width))
+            break;
+        }
         if (image->matte != MagickFalse)
           {
             /*
@@ -410,12 +476,18 @@ static Image *ReadRGBImage(const ImageInfo *image_info,ExceptionInfo *exception)
                   }
               }
             for (y=0; y < image->extract_info.y; y++)
-              (void) ReadBlob(image,packet_size*image->extract_info.width,
+            {
+              count=ReadBlob(image,packet_size*image->extract_info.width,
                 scanline);
+              if (count != (ssize_t) (packet_size*image->extract_info.width))
+                break;
+            }
             for (y=0; y < (long) image->rows; y++)
             {
-              (void) ReadBlob(image,packet_size*image->extract_info.width,
+              count=ReadBlob(image,packet_size*image->extract_info.width,
                 scanline);
+              if (count != (ssize_t) (packet_size*image->extract_info.width))
+                break;
               q=GetImagePixels(image,0,y,image->columns,1);
               if (q == (PixelPacket *) NULL)
                 break;
@@ -440,8 +512,12 @@ static Image *ReadRGBImage(const ImageInfo *image_info,ExceptionInfo *exception)
             }
             width=image->extract_info.height-image->rows-image->extract_info.y;
             for (i=0; i < (long) width; i++)
-              (void) ReadBlob(image,packet_size*image->extract_info.width,
+            {
+              count=ReadBlob(image,packet_size*image->extract_info.width,
                 scanline);
+              if (count != (ssize_t) (packet_size*image->extract_info.width))
+                break;
+            }
           }
         if (image_info->interlace == PartitionInterlace)
           (void) CopyMagickString(image->filename,image_info->filename,
@@ -449,7 +525,7 @@ static Image *ReadRGBImage(const ImageInfo *image_info,ExceptionInfo *exception)
         break;
       }
     }
-    if (EOFBlob(image) != MagickFalse)
+    if (y < (long) image->rows)
       {
         ThrowFileException(exception,CorruptImageError,"UnexpectedEndOfFile",
           image->filename);
@@ -464,7 +540,7 @@ static Image *ReadRGBImage(const ImageInfo *image_info,ExceptionInfo *exception)
     if (image_info->interlace == PartitionInterlace)
       break;
     count=ReadBlob(image,packet_size*image->extract_info.width,scanline);
-    if (count != 0)
+    if (count == (ssize_t) (packet_size*image->extract_info.width))
       {
         /*
           Allocate next image structure.
@@ -484,7 +560,7 @@ static Image *ReadRGBImage(const ImageInfo *image_info,ExceptionInfo *exception)
               break;
           }
       }
-  } while (count != 0);
+  } while (count == (packet_size*image->extract_info.width));
   scanline=(unsigned char *) RelinquishMagickMemory(scanline);
   CloseBlob(image);
   return(GetFirstImageInList(image));
