@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -175,6 +175,9 @@ static Image *ReadRLAImage(const ImageInfo *image_info,ExceptionInfo *exception)
   register PixelPacket
     *q;
 
+  ssize_t
+    count;
+
   RLAInfo
     rla_info;
 
@@ -214,31 +217,31 @@ static Image *ReadRLAImage(const ImageInfo *image_info,ExceptionInfo *exception)
   rla_info.number_channels+=rla_info.number_matte_channels;
   rla_info.number_auxiliary_channels=ReadBlobMSBShort(image);
   rla_info.revision=ReadBlobMSBShort(image);
-  (void) ReadBlob(image,16,(unsigned char *) rla_info.gamma);
-  (void) ReadBlob(image,24,(unsigned char *) rla_info.red_primary);
-  (void) ReadBlob(image,24,(unsigned char *) rla_info.green_primary);
-  (void) ReadBlob(image,24,(unsigned char *) rla_info.blue_primary);
-  (void) ReadBlob(image,24,(unsigned char *) rla_info.white_point);
+  count=ReadBlob(image,16,(unsigned char *) rla_info.gamma);
+  count=ReadBlob(image,24,(unsigned char *) rla_info.red_primary);
+  count=ReadBlob(image,24,(unsigned char *) rla_info.green_primary);
+  count=ReadBlob(image,24,(unsigned char *) rla_info.blue_primary);
+  count=ReadBlob(image,24,(unsigned char *) rla_info.white_point);
   rla_info.job_number=(long) ReadBlobMSBLong(image);
-  (void) ReadBlob(image,128,(unsigned char *) rla_info.name);
-  (void) ReadBlob(image,128,(unsigned char *) rla_info.description);
-  (void) ReadBlob(image,64,(unsigned char *) rla_info.program);
-  (void) ReadBlob(image,32,(unsigned char *) rla_info.machine);
-  (void) ReadBlob(image,32,(unsigned char *) rla_info.user);
-  (void) ReadBlob(image,20,(unsigned char *) rla_info.date);
-  (void) ReadBlob(image,24,(unsigned char *) rla_info.aspect);
-  (void) ReadBlob(image,8,(unsigned char *) rla_info.aspect_ratio);
-  (void) ReadBlob(image,32,(unsigned char *) rla_info.chan);
+  count=ReadBlob(image,128,(unsigned char *) rla_info.name);
+  count=ReadBlob(image,128,(unsigned char *) rla_info.description);
+  count=ReadBlob(image,64,(unsigned char *) rla_info.program);
+  count=ReadBlob(image,32,(unsigned char *) rla_info.machine);
+  count=ReadBlob(image,32,(unsigned char *) rla_info.user);
+  count=ReadBlob(image,20,(unsigned char *) rla_info.date);
+  count=ReadBlob(image,24,(unsigned char *) rla_info.aspect);
+  count=ReadBlob(image,8,(unsigned char *) rla_info.aspect_ratio);
+  count=ReadBlob(image,32,(unsigned char *) rla_info.chan);
   rla_info.field=ReadBlobMSBShort(image);
-  (void) ReadBlob(image,12,(unsigned char *) rla_info.time);
-  (void) ReadBlob(image,32,(unsigned char *) rla_info.filter);
+  count=ReadBlob(image,12,(unsigned char *) rla_info.time);
+  count=ReadBlob(image,32,(unsigned char *) rla_info.filter);
   rla_info.bits_per_channel=ReadBlobMSBShort(image);
   rla_info.matte_type=ReadBlobMSBShort(image);
   rla_info.matte_bits=ReadBlobMSBShort(image);
   rla_info.auxiliary_type=ReadBlobMSBShort(image);
   rla_info.auxiliary_bits=ReadBlobMSBShort(image);
-  (void) ReadBlob(image,32,(unsigned char *) rla_info.auxiliary);
-  (void) ReadBlob(image,36,(unsigned char *) rla_info.space);
+  count=ReadBlob(image,32,(unsigned char *) rla_info.auxiliary);
+  count=ReadBlob(image,36,(unsigned char *) rla_info.space);
   rla_info.next=(long) ReadBlobMSBLong(image);
   /*
     Initialize image structure.
