@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -269,7 +269,7 @@ static Image *ReadRLEImage(const ImageInfo *image_info,ExceptionInfo *exception)
             comment=(char *) AcquireMagickMemory(length);
             if (comment == (char *) NULL)
               ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
-            (void) ReadBlob(image,length-1,(unsigned char *) comment);
+            count=ReadBlob(image,length-1,(unsigned char *) comment);
             comment[length-1]='\0';
             (void) SetImageAttribute(image,"Comment",comment);
             comment=(char *) RelinquishMagickMemory(comment);
