@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -130,6 +130,9 @@ static Image *ReadSCRImage(const ImageInfo *image_info,ExceptionInfo *exception)
   register PixelPacket
     *q;
 
+  ssize_t
+    count;
+
   /*
     Open image file.
   */
@@ -148,8 +151,8 @@ static Image *ReadSCRImage(const ImageInfo *image_info,ExceptionInfo *exception)
     }
   image->columns = 256;
   image->rows = 192;
-  (void) ReadBlob(image,6144,(unsigned char *) zxscr);
-  (void) ReadBlob(image,768,(unsigned char *) zxattr);
+  count=ReadBlob(image,6144,(unsigned char *) zxscr);
+  count=ReadBlob(image,768,(unsigned char *) zxattr);
   for(zonenr=0;zonenr<3;zonenr++)
   {
       for(zoneline=0;zoneline<8;zoneline++)
