@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -143,6 +143,9 @@ static Image *ReadSCTImage(const ImageInfo *image_info,ExceptionInfo *exception)
   register PixelPacket
     *q;
 
+  ssize_t
+    count;
+
   unsigned char
     buffer[768];
 
@@ -170,8 +173,8 @@ static Image *ReadSCTImage(const ImageInfo *image_info,ExceptionInfo *exception)
   /*
     Read control block.
   */
-  (void) ReadBlob(image,80,buffer);
-  (void) ReadBlob(image,2,(unsigned char *) magick);
+  count=ReadBlob(image,80,buffer);
+  count=ReadBlob(image,2,(unsigned char *) magick);
   if ((LocaleNCompare((char *) magick,"CT",2) != 0) &&
       (LocaleNCompare((char *) magick,"LW",2) != 0) &&
       (LocaleNCompare((char *) magick,"BM",2) != 0) &&
@@ -183,8 +186,8 @@ static Image *ReadSCTImage(const ImageInfo *image_info,ExceptionInfo *exception)
       (LocaleNCompare((char *) magick,"PG",2) == 0) ||
       (LocaleNCompare((char *) magick,"TX",2) == 0))
     ThrowReaderException(CoderError,"OnlyContinuousTonePictureSupported");
-  (void) ReadBlob(image,174,buffer);
-  (void) ReadBlob(image,768,buffer);
+  count=ReadBlob(image,174,buffer);
+  count=ReadBlob(image,768,buffer);
   /*
     Read paramter block.
   */
@@ -193,18 +196,18 @@ static Image *ReadSCTImage(const ImageInfo *image_info,ExceptionInfo *exception)
     image->units=PixelsPerCentimeterResolution;
   separations=ReadBlobByte(image);
   separations_mask=ReadBlobMSBShort(image);
-  (void) ReadBlob(image,14,buffer);
+  count=ReadBlob(image,14,buffer);
   buffer[14]='\0';
   height=atof((char *) buffer);
-  (void) ReadBlob(image,14,buffer);
+  count=ReadBlob(image,14,buffer);
   width=atof((char *) buffer);
-  (void) ReadBlob(image,12,buffer);
+  count=ReadBlob(image,12,buffer);
   buffer[12]='\0';
   image->rows=atol((char *) buffer);
-  (void) ReadBlob(image,12,buffer);
+  count=ReadBlob(image,12,buffer);
   image->columns=atol((char *) buffer);
-  (void) ReadBlob(image,200,buffer);
-  (void) ReadBlob(image,768,buffer);
+  count=ReadBlob(image,200,buffer);
+  count=ReadBlob(image,768,buffer);
   if (separations_mask == 0x0f)
     image->colorspace=CMYKColorspace;
   image->x_resolution=image->columns/width;
