@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -253,6 +253,9 @@ static Image *ReadSGIImage(const ImageInfo *image_info,ExceptionInfo *exception)
   register unsigned char
     *p;
 
+  ssize_t
+    count;
+
   SGIInfo
     iris_info;
 
@@ -310,7 +313,7 @@ static Image *ReadSGIImage(const ImageInfo *image_info,ExceptionInfo *exception)
         break;
     iris_info.minimum_value=ReadBlobMSBLong(image);
     iris_info.maximum_value=ReadBlobMSBLong(image);
-    (void) ReadBlob(image,sizeof(iris_info.filler),iris_info.filler);
+    count=ReadBlob(image,sizeof(iris_info.filler),iris_info.filler);
     /*
       Allocate SGI pixels.
     */
@@ -340,8 +343,10 @@ static Image *ReadSGIImage(const ImageInfo *image_info,ExceptionInfo *exception)
           p=iris_pixels+bytes_per_pixel*z;
           for (y=0; y < (long) iris_info.rows; y++)
           {
-            (void) ReadBlob(image,bytes_per_pixel*iris_info.columns,
+            count=ReadBlob(image,bytes_per_pixel*iris_info.columns,
               scanline);
+            if (EOFBlob(image) != MagickFalse)
+              break;
             if (bytes_per_pixel == 2)
               for (x=0; x < (long) iris_info.columns; x++)
               {
@@ -417,8 +422,10 @@ static Image *ReadSGIImage(const ImageInfo *image_info,ExceptionInfo *exception)
                     offset=offsets[y+z*iris_info.rows];
                     (void) SeekBlob(image,(long) offset,SEEK_SET);
                   }
-                (void) ReadBlob(image,(size_t) runlength[y+z*iris_info.rows],
+                count=ReadBlob(image,(size_t) runlength[y+z*iris_info.rows],
                   max_packets);
+                if (EOFBlob(image) != MagickFalse)
+                  break;
                 offset+=runlength[y+z*iris_info.rows];
                 SGIDecode(iris_info.columns,bytes_per_pixel,max_packets,
                   p+bytes_per_pixel*z);
@@ -442,8 +449,10 @@ static Image *ReadSGIImage(const ImageInfo *image_info,ExceptionInfo *exception)
                     offset=offsets[y+z*iris_info.rows];
                     (void) SeekBlob(image,(long) offset,SEEK_SET);
                   }
-                (void) ReadBlob(image,(size_t) runlength[y+z*iris_info.rows],
+                count=ReadBlob(image,(size_t) runlength[y+z*iris_info.rows],
                   max_packets);
+                if (EOFBlob(image) != MagickFalse)
+                  break;
                 offset+=runlength[y+z*iris_info.rows];
                 SGIDecode(iris_info.columns,bytes_per_pixel,max_packets,
                   p+bytes_per_pixel*z);
