@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -190,7 +190,7 @@ static Image *ReadTGAImage(const ImageInfo *image_info,ExceptionInfo *exception)
   tga_info.image_type=(unsigned char) ReadBlobByte(image);
   do
   {
-    if ((count == 0) ||
+    if ((count != 1) ||
         ((tga_info.image_type != TGAColormap) &&
          (tga_info.image_type != TGARGB) &&
          (tga_info.image_type != TGAMonochrome) &&
@@ -213,7 +213,7 @@ static Image *ReadTGAImage(const ImageInfo *image_info,ExceptionInfo *exception)
     /*
       Initialize image structure.
     */
-    image->matte=tga_info.attributes & 0x0FU ? MagickTrue : MagickFalse;
+    image->matte=(tga_info.attributes & 0x0FU) != 0 ? MagickTrue : MagickFalse;
     image->columns=tga_info.width;
     image->rows=tga_info.height;
     if ((tga_info.image_type != TGAColormap) &&
@@ -258,7 +258,7 @@ static Image *ReadTGAImage(const ImageInfo *image_info,ExceptionInfo *exception)
         comment=(char *) AcquireMagickMemory(tga_info.id_length+MaxTextExtent);
         if (comment == (char *) NULL)
           ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
-        (void) ReadBlob(image,tga_info.id_length,(unsigned char *) comment);
+        count=ReadBlob(image,tga_info.id_length,(unsigned char *) comment);
         comment[tga_info.id_length]='\0';
         (void) SetImageAttribute(image,"Comment",comment);
         comment=(char *) RelinquishMagickMemory(comment);
