@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -62,6 +62,7 @@
 #include "magick/resize.h"
 #include "magick/splay-tree.h"
 #include "magick/static.h"
+#include "magick/statistic.h"
 #include "magick/string_.h"
 #include "magick/version.h"
 #if defined(HasTIFF)
@@ -172,7 +173,7 @@ static MagickBooleanType ReadProfile(Image *image,const char *name,
   if (length < 4)
     return(MagickFalse);
   i=0;
-  if (LocaleCompare(name,"icc") != 0)
+  if ((LocaleCompare(name,"icc") != 0) && (LocaleCompare(name,"xmp") != 0))
     {
       for (i=0; i < length; i+=2)
         if (LocaleNCompare((char *) (datum+i),"8BIM",4) == 0)
@@ -1573,7 +1574,8 @@ static MagickBooleanType WriteTIFFImage(const ImageInfo *image_info,
               {
                 (void) TIFFSetField(tiff,TIFFTAG_SAMPLESPERPIXEL,1);
                 photometric=PHOTOMETRIC_MINISBLACK;
-                if (IsMonochromeImage(image,&image->exception) != MagickFalse)
+                if ((image_info->depth == 0) &&
+                    (IsMonochromeImage(image,&image->exception) != MagickFalse))
                   image->depth=1;
                 for (i=1; i < (long) image->depth; i*=2);
                 (void) TIFFSetField(tiff,TIFFTAG_BITSPERSAMPLE,i);
@@ -1768,7 +1770,7 @@ static MagickBooleanType WriteTIFFImage(const ImageInfo *image_info,
         chromaticity[1]=(float) image->chromaticity.white_point.y;
         (void) TIFFSetField(tiff,TIFFTAG_WHITEPOINT,chromaticity);
       }
-    if (image->profiles != (SplayTreeInfo *) NULL)
+    if (image->profiles != (void *) NULL)
       {
         const char
           *name;
