@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -122,6 +122,9 @@ static Image *ReadTIMImage(const ImageInfo *image_info,ExceptionInfo *exception)
   register unsigned char
     *p;
 
+  ssize_t
+    count;
+
   unsigned char
     *tim_data,
     *tim_pixels;
@@ -192,7 +195,9 @@ static Image *ReadTIMImage(const ImageInfo *image_info,ExceptionInfo *exception)
         tim_colormap=(unsigned char *) AcquireMagickMemory(image->colors*2);
         if (tim_colormap == (unsigned char *) NULL)
           ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
-        (void) ReadBlob(image,2*image->colors,tim_colormap);
+        count=ReadBlob(image,2*image->colors,tim_colormap);
+        if (count != (ssize_t) (2*image->colors))
+          ThrowReaderException(CorruptImageError,"InsufficientImageDataInFile");
         p=tim_colormap;
         for (i=0; i < (long) image->colors; i++)
         {
@@ -224,7 +229,9 @@ static Image *ReadTIMImage(const ImageInfo *image_info,ExceptionInfo *exception)
     tim_data=(unsigned char *) AcquireMagickMemory(image_size);
     if (tim_data == (unsigned char *) NULL)
       ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
-    (void) ReadBlob(image,image_size,tim_data);
+    count=ReadBlob(image,image_size,tim_data);
+    if (count != (ssize_t) (image_size))
+      ThrowReaderException(CorruptImageError,"InsufficientImageDataInFile");
     tim_pixels=tim_data;
     /*
       Initialize image structure.
