@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -58,6 +58,7 @@
 #include "magick/memory_.h"
 #include "magick/monitor.h"
 #include "magick/option.h"
+#include "magick/pixel-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
 
@@ -245,7 +246,7 @@ static Image *ReadTEXTImage(const ImageInfo *image_info,
   /*
     Annotate the text image.
   */
-  SetImage(image,OpaqueOpacity);
+  SetImageBackgroundColor(image);
   draw_info=CloneDrawInfo(image_info,(DrawInfo *) NULL);
   draw_info->fill=image_info->pen;
   (void) CloneString(&draw_info->text,image_info->filename);
@@ -310,7 +311,7 @@ static Image *ReadTEXTImage(const ImageInfo *image_info,
     image->next->rows=image->rows;
     image=SyncNextImageInList(image);
     (void) CopyMagickString(image->filename,filename,MaxTextExtent);
-    SetImage(image,OpaqueOpacity);
+    SetImageBackgroundColor(image);
     if (image->progress_monitor != (MagickProgressMonitor) NULL)
       {
         status=image->progress_monitor(LoadImagesTag,TellBlob(image),
