@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -284,7 +284,7 @@ static Image *ReadVICARImage(const ImageInfo *image_info,
     q=SetImagePixels(image,0,y,image->columns,1);
     if (q == (PixelPacket *) NULL)
       break;
-    (void) ReadBlob(image,image->columns,scanline);
+    count=ReadBlob(image,image->columns,scanline);
     (void) ExportQuantumPixels(image,GrayQuantum,0,scanline);
     if (SyncImagePixels(image) == MagickFalse)
       break;
@@ -438,8 +438,8 @@ static MagickBooleanType WriteVICARImage(const ImageInfo *image_info,
   (void) FormatMagickString(header,MaxTextExtent,
     "LBLSIZE=%lu FORMAT='BYTE' TYPE='IMAGE' BUFSIZE=20000 DIM=2 EOL=0 "
     "RECSIZE=%lu ORG='BSQ' NL=%lu NS=%lu NB=1 N1=0 N2=0 N3=0 N4=0 NBB=0 "
-    "NLB=0 TASK='ImageMagick'",MaxTextExtent,image->columns,image->rows,
-    image->columns);
+    "NLB=0 TASK='ImageMagick'",(unsigned long) MaxTextExtent,image->columns,
+    image->rows,image->columns);
   (void) WriteBlob(image,MaxTextExtent,(unsigned char *) header);
   /*
     Allocate memory for scanline.
