@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -280,12 +280,12 @@ static Image *ReadVIFFImage(const ImageInfo *image_info,
     /*
       Initialize VIFF image.
     */
-    (void) ReadBlob(image,7,buffer);
+    count=ReadBlob(image,7,buffer);
     viff_info.file_type=buffer[0];
     viff_info.release=buffer[1];
     viff_info.version=buffer[2];
     viff_info.machine_dependency=buffer[3];
-    (void) ReadBlob(image,512,(unsigned char *) viff_info.comment);
+    count=ReadBlob(image,512,(unsigned char *) viff_info.comment);
     viff_info.comment[511]='\0';
     if (strlen(viff_info.comment) > 4)
       (void) SetImageAttribute(image,"Comment",viff_info.comment);
@@ -422,7 +422,7 @@ static Image *ReadVIFFImage(const ImageInfo *image_info,
         /*
           Read VIFF raster colormap.
         */
-        (void) ReadBlob(image,bytes_per_pixel*image->colors*viff_info.map_rows,
+        count=ReadBlob(image,bytes_per_pixel*image->colors*viff_info.map_rows,
           viff_colormap);
         lsb_first=1;
         if (*(char *) &lsb_first &&
@@ -507,7 +507,7 @@ static Image *ReadVIFFImage(const ImageInfo *image_info,
       AcquireMagickMemory(bytes_per_pixel*max_packets*sizeof(Quantum));
     if (viff_pixels == (unsigned char *) NULL)
       ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
-    (void) ReadBlob(image,bytes_per_pixel*max_packets,viff_pixels);
+    count=ReadBlob(image,bytes_per_pixel*max_packets,viff_pixels);
     lsb_first=1;
     if (*(char *) &lsb_first &&
         ((viff_info.machine_dependency != VFF_DEP_DECORDER) &&
