@@ -28,7 +28,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -862,7 +862,7 @@ static void util_draw_arc(wmfAPI * API,
     BR,
     O,
     TL,
-    centre,
+    center,
     end,
     start;
 
@@ -879,22 +879,24 @@ static void util_draw_arc(wmfAPI * API,
 
   if (TO_FILL(draw_arc) || TO_DRAW(draw_arc))
     {
-      centre.x = (draw_arc->TL.x + draw_arc->BR.x) / 2;
-      centre.y = (draw_arc->TL.y + draw_arc->BR.y) / 2;
+      center.x = (draw_arc->TL.x + draw_arc->BR.x) / 2;
+      center.y = (draw_arc->TL.y + draw_arc->BR.y) / 2;
+      start = center;
+      end = center;
 
       if (finish != magick_arc_ellipse)
         {
-          draw_arc->start.x += centre.x;
-          draw_arc->start.y += centre.y;
+          draw_arc->start.x += center.x;
+          draw_arc->start.y += center.y;
 
-          draw_arc->end.x += centre.x;
-          draw_arc->end.y += centre.y;
+          draw_arc->end.x += center.x;
+          draw_arc->end.y += center.y;
         }
 
       TL = draw_arc->TL;
       BR = draw_arc->BR;
 
-      O = centre;
+      O = center;
 
       if (finish != magick_arc_ellipse)
         {
