@@ -22,7 +22,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -567,7 +567,7 @@ static Image *ExtractPostscript(Image *image,const ImageInfo *image_info,
   unique_file=AcquireUniqueFileResource((char *) clone_info->filename);
   if (unique_file != -1)
     file=fdopen(unique_file,"wb");
-  if( (unique_file == -1) || (file == NULL))
+  if ((unique_file == -1) || (file == NULL))
     goto FINISH;
   (void) SeekBlob(image,PS_Offset,SEEK_SET);
   for (i=0; i < PS_Size; i++)
@@ -832,6 +832,9 @@ static Image *ReadWPGImage(const ImageInfo *image_info,
   long
     ldblk;
 
+  ssize_t
+    count;
+
   unsigned char
     *BImgBuff;
 
@@ -1137,7 +1140,7 @@ static Image *ReadWPGImage(const ImageInfo *image_info,
 
                     for(i=0;i<(long) image->rows;i++)
                       {
-                        (void) ReadBlob(image,ldblk,BImgBuff);
+                        count=ReadBlob(image,ldblk,BImgBuff);
                         InsertRow(BImgBuff,i,image,bpp);
                       }
                     if(BImgBuff)
