@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -792,7 +792,9 @@ static MagickBooleanType ReadOneLayer(Image* image,XCFDocInfo* inDocInfo,
   }
 
   /* clear the image based on the layer opacity */
-    SetImage(outLayer->image,ScaleCharToQuantum(255-outLayer->opacity));
+  outLayer->image->background_color.opacity=
+    ScaleCharToQuantum(255-outLayer->opacity);    
+  SetImageBackgroundColor(outLayer->image);
 
   /* set the compositing mode */
   outLayer->image->compose = GIMPBlendModeToCompositeOperator( outLayer->mode );
@@ -941,7 +943,7 @@ static Image *ReadXCFImage(const ImageInfo *image_info,ExceptionInfo *exception)
     else
       if ( image_type == GIMP_INDEXED )
         ThrowReaderException(CoderError,"ColormapTypeNotSupported");
-  SetImage(image,TransparentOpacity);
+  SetImageBackgroundColor(image);
   /*
     Read properties.
   */
