@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -54,6 +54,7 @@
 #include "magick/monitor.h"
 #include "magick/pixel.h"
 #include "magick/static.h"
+#include "magick/statistic.h"
 #include "magick/string_.h"
 #include "magick/utility.h"
 
@@ -170,7 +171,7 @@ static Image *ReadYCBCRImage(const ImageInfo *image_info,
       */
       image->scene++;
       for (y=0; y < (long) image->rows; y++)
-        (void) ReadBlob(image,packet_size*image->extract_info.width,scanline);
+        count=ReadBlob(image,packet_size*image->extract_info.width,scanline);
     }
   offset=(MagickOffsetType) (packet_size*image->extract_info.x);
   do
@@ -191,11 +192,11 @@ static Image *ReadYCBCRImage(const ImageInfo *image_info,
           No interlacing:  YCbCrYCbCrYCbCrYCbCrYCbCrYCbCr...
         */
         for (y=0; y < image->extract_info.y; y++)
-          (void) ReadBlob(image,packet_size*image->extract_info.width,scanline);
+          count=ReadBlob(image,packet_size*image->extract_info.width,scanline);
         for (y=0; y < (long) image->rows; y++)
         {
           if ((y > 0) || (image->previous == (Image *) NULL))
-            (void) ReadBlob(image,packet_size*image->extract_info.width,
+            count=ReadBlob(image,packet_size*image->extract_info.width,
               scanline);
           q=SetImagePixels(image,0,y,image->columns,1);
           if (q == (PixelPacket *) NULL)
@@ -218,7 +219,7 @@ static Image *ReadYCBCRImage(const ImageInfo *image_info,
         }
         width=image->extract_info.height-image->rows-image->extract_info.y;
         for (i=0; i < (long) width; i++)
-          (void) ReadBlob(image,packet_size*image->extract_info.width,scanline);
+          count=ReadBlob(image,packet_size*image->extract_info.width,scanline);
         break;
       }
       case LineInterlace:
@@ -228,23 +229,23 @@ static Image *ReadYCBCRImage(const ImageInfo *image_info,
         */
         packet_size=(size_t) (image->depth > 8 ? 2 : 1);
         for (y=0; y < image->extract_info.y; y++)
-          (void) ReadBlob(image,packet_size*image->extract_info.width,scanline);
+          count=ReadBlob(image,packet_size*image->extract_info.width,scanline);
         for (y=0; y < (long) image->rows; y++)
         {
           if ((y > 0) || (image->previous == (Image *) NULL))
-            (void) ReadBlob(image,packet_size*image->extract_info.width,
+            count=ReadBlob(image,packet_size*image->extract_info.width,
               scanline);
           q=SetImagePixels(image,0,y,image->columns,1);
           if (q == (PixelPacket *) NULL)
             break;
           (void) ExportQuantumPixels(image,RedQuantum,0,scanline+offset);
-          (void) ReadBlob(image,packet_size*image->extract_info.width,scanline);
+          count=ReadBlob(image,packet_size*image->extract_info.width,scanline);
           (void) ExportQuantumPixels(image,GreenQuantum,0,scanline+offset);
-          (void) ReadBlob(image,packet_size*image->extract_info.width,scanline);
+          count=ReadBlob(image,packet_size*image->extract_info.width,scanline);
           (void) ExportQuantumPixels(image,BlueQuantum,0,scanline+offset);
           if (image->matte != MagickFalse)
             {
-              (void) ReadBlob(image,packet_size*image->extract_info.width,
+              count=ReadBlob(image,packet_size*image->extract_info.width,
                 scanline);
               (void) ExportQuantumPixels(image,AlphaQuantum,0,scanline+offset);
             }
@@ -262,7 +263,7 @@ static Image *ReadYCBCRImage(const ImageInfo *image_info,
         }
         width=image->extract_info.height-image->rows-image->extract_info.y;
         for (i=0; i < (long) width; i++)
-          (void) ReadBlob(image,packet_size*image->extract_info.width,scanline);
+          count=ReadBlob(image,packet_size*image->extract_info.width,scanline);
         break;
       }
       case PlaneInterlace:
@@ -286,13 +287,13 @@ static Image *ReadYCBCRImage(const ImageInfo *image_info,
           }
         packet_size=(size_t) (image->depth > 8 ? 2 : 1);
         for (y=0; y < image->extract_info.y; y++)
-          (void) ReadBlob(image,packet_size*image->extract_info.width,scanline);
+          count=ReadBlob(image,packet_size*image->extract_info.width,scanline);
         i=0;
         span=image->rows*(image->matte != MagickFalse ? 5 : 4);
         for (y=0; y < (long) image->rows; y++)
         {
           if ((y > 0) || (image->previous == (Image *) NULL))
-            (void) ReadBlob(image,packet_size*image->extract_info.width,
+            count=ReadBlob(image,packet_size*image->extract_info.width,
               scanline);
           q=SetImagePixels(image,0,y,image->columns,1);
           if (q == (PixelPacket *) NULL)
@@ -313,7 +314,7 @@ static Image *ReadYCBCRImage(const ImageInfo *image_info,
         }
         width=image->extract_info.height-image->rows-image->extract_info.y;
         for (i=0; i < (long) width; i++)
-          (void) ReadBlob(image,packet_size*image->extract_info.width,scanline);
+          count=ReadBlob(image,packet_size*image->extract_info.width,scanline);
         if (image_info->interlace == PartitionInterlace)
           {
             CloseBlob(image);
@@ -326,10 +327,10 @@ static Image *ReadYCBCRImage(const ImageInfo *image_info,
               }
           }
         for (y=0; y < image->extract_info.y; y++)
-          (void) ReadBlob(image,packet_size*image->extract_info.width,scanline);
+          count=ReadBlob(image,packet_size*image->extract_info.width,scanline);
         for (y=0; y < (long) image->rows; y++)
         {
-          (void) ReadBlob(image,packet_size*image->extract_info.width,scanline);
+          count=ReadBlob(image,packet_size*image->extract_info.width,scanline);
           q=GetImagePixels(image,0,y,image->columns,1);
           if (q == (PixelPacket *) NULL)
             break;
@@ -349,7 +350,7 @@ static Image *ReadYCBCRImage(const ImageInfo *image_info,
         }
         width=image->extract_info.height-image->rows-image->extract_info.y;
         for (i=0; i < (long) width; i++)
-          (void) ReadBlob(image,packet_size*image->extract_info.width,scanline);
+          count=ReadBlob(image,packet_size*image->extract_info.width,scanline);
         if (image_info->interlace == PartitionInterlace)
           {
             CloseBlob(image);
@@ -362,10 +363,10 @@ static Image *ReadYCBCRImage(const ImageInfo *image_info,
               }
           }
         for (y=0; y < image->extract_info.y; y++)
-          (void) ReadBlob(image,packet_size*image->extract_info.width,scanline);
+          count=ReadBlob(image,packet_size*image->extract_info.width,scanline);
         for (y=0; y < (long) image->rows; y++)
         {
-          (void) ReadBlob(image,packet_size*image->extract_info.width,scanline);
+          count=ReadBlob(image,packet_size*image->extract_info.width,scanline);
           q=GetImagePixels(image,0,y,image->columns,1);
           if (q == (PixelPacket *) NULL)
             break;
@@ -385,7 +386,7 @@ static Image *ReadYCBCRImage(const ImageInfo *image_info,
         }
         width=image->extract_info.height-image->rows-image->extract_info.y;
         for (i=0; i < (long) width; i++)
-          (void) ReadBlob(image,packet_size*image->extract_info.width,scanline);
+          count=ReadBlob(image,packet_size*image->extract_info.width,scanline);
         if (image->matte != MagickFalse)
           {
             /*
@@ -403,11 +404,11 @@ static Image *ReadYCBCRImage(const ImageInfo *image_info,
                   }
               }
             for (y=0; y < image->extract_info.y; y++)
-              (void) ReadBlob(image,packet_size*image->extract_info.width,
+              count=ReadBlob(image,packet_size*image->extract_info.width,
                 scanline);
             for (y=0; y < (long) image->rows; y++)
             {
-              (void) ReadBlob(image,packet_size*image->extract_info.width,
+              count=ReadBlob(image,packet_size*image->extract_info.width,
                 scanline);
               q=GetImagePixels(image,0,y,image->columns,1);
               if (q == (PixelPacket *) NULL)
@@ -428,7 +429,7 @@ static Image *ReadYCBCRImage(const ImageInfo *image_info,
             }
             width=image->extract_info.height-image->rows-image->extract_info.y;
             for (i=0; i < (long) width; i++)
-              (void) ReadBlob(image,packet_size*image->extract_info.width,
+              count=ReadBlob(image,packet_size*image->extract_info.width,
                 scanline);
           }
         if (image_info->interlace == PartitionInterlace)
