@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -223,7 +223,7 @@ static Image *ReadYUVImage(const ImageInfo *image_info,ExceptionInfo *exception)
       if (interlace == NoInterlace)
         {
           if ((y > 0) || (image->previous == (Image *) NULL))
-            (void) ReadBlob(image,(size_t) (2*image->columns),scanline);
+            count=ReadBlob(image,(size_t) (2*image->columns),scanline);
           p=scanline;
           q=SetImagePixels(image,0,y,image->columns,1);
           if (q == (PixelPacket *) NULL)
@@ -250,7 +250,7 @@ static Image *ReadYUVImage(const ImageInfo *image_info,ExceptionInfo *exception)
       else
         {
           if ((y > 0) || (image->previous == (Image *) NULL))
-            (void) ReadBlob(image,(size_t) image->columns,scanline);
+            count=ReadBlob(image,(size_t) image->columns,scanline);
           p=scanline;
           q=SetImagePixels(image,0,y,image->columns,1);
           if (q == (PixelPacket *) NULL)
@@ -292,7 +292,7 @@ static Image *ReadYUVImage(const ImageInfo *image_info,ExceptionInfo *exception)
       {
         for (y=0; y < (long) chroma_image->rows; y++)
         {
-          (void) ReadBlob(image,(size_t) chroma_image->columns,scanline);
+          count=ReadBlob(image,(size_t) chroma_image->columns,scanline);
           p=scanline;
           q=SetImagePixels(chroma_image,0,y,chroma_image->columns,1);
           if (q == (PixelPacket *) NULL)
@@ -320,7 +320,7 @@ static Image *ReadYUVImage(const ImageInfo *image_info,ExceptionInfo *exception)
         }
       for (y=0; y < (long) chroma_image->rows; y++)
       {
-        (void) ReadBlob(image,(size_t) chroma_image->columns,scanline);
+        count=ReadBlob(image,(size_t) chroma_image->columns,scanline);
         p=scanline;
         q=GetImagePixels(chroma_image,0,y,chroma_image->columns,1);
         if (q == (PixelPacket *) NULL)
