@@ -5,7 +5,7 @@
   You may not use this file except in compliance with the License.
   obtain a copy of the License at
   
-    http://www.imagemagick.org/www/Copyright.html
+    http://www.imagemagick.org/script/license.php
   
   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
@@ -59,7 +59,7 @@ typedef unsigned char Quantum;
 #define MaxColormapSize  65536
 #define MaxMap  65535
 #define MaxRGB  ((Quantum) 65535)
-#define ScaleCharToQuantum(value)  ((Quantum) (257*(value)))
+#define ScaleCharToQuantum(value)  ((Quantum) (257*((int) (value))))
 #define ScaleLongToQuantum(value)  ((Quantum) ((value)/65537UL))
 #define ScaleMapToQuantum(value)  ((Quantum) (value))
 #define ScaleQuantum(quantum)  ((unsigned long) ((quantum)/257))
@@ -78,9 +78,9 @@ typedef unsigned short Quantum;
 #define MaxColormapSize  65536
 #define MaxMap  65535
 #define MaxRGB  ((Quantum) 4294967295U)
-#define ScaleCharToQuantum(value)  ((Quantum) (16843009UL*value))
+#define ScaleCharToQuantum(value)  ((Quantum) (16843009UL*(value)))
 #define ScaleLongToQuantum(value)  ((Quantum) (value))
-#define ScaleMapToQuantum(value)  ((Quantum) (65537UL*value))
+#define ScaleMapToQuantum(value)  ((Quantum) (65537UL*(value)))
 #define ScaleQuantum(quantum)  ((unsigned long) ((quantum)/16843009UL))
 #define ScaleQuantumToChar(quantum)  ((unsigned char) ((quantum)/16843009UL))
 #define ScaleQuantumToIndex(value)   ((unsigned short) ((value)/65537UL))
@@ -136,7 +136,7 @@ typedef enum
   MatteChannel = 0x0008,  /* deprecated */
   BlackChannel = 0x0020,
   IndexChannel = 0x0020,
-  AllChannels = 0x7fffffff
+  AllChannels = 0xff
 } ChannelType;
 
 typedef enum
@@ -164,7 +164,9 @@ typedef enum
   sRGBColorspace,
   HSBColorspace,
   HSLColorspace,
-  HWBColorspace
+  HWBColorspace,
+  Rec601LumaColorspace,
+  Rec709LumaColorspace
 } ColorspaceType;
 
 typedef enum
@@ -232,6 +234,7 @@ typedef enum
   FaxCompression,
   Group4Compression,
   JPEGCompression,
+  JPEG2000Compression,
   LosslessJPEGCompression,
   LZWCompression,
   RLECompression,
@@ -547,14 +550,6 @@ typedef struct _RectangleInfo
     y;
 } RectangleInfo;
 
-typedef struct _Timer
-{
-  double
-    start,
-    stop,
-    total;
-} Timer;
-
 typedef struct _SegmentInfo
 {
   double
@@ -564,6 +559,14 @@ typedef struct _SegmentInfo
     y2;
 } SegmentInfo;
 
+typedef struct _Timer
+{
+  double
+    start,
+    stop,
+    total;
+} Timer;
+
 typedef struct _TimerInfo
 {
   Timer
@@ -606,10 +609,6 @@ typedef struct _Ascii85Info _Ascii85Info_;
 
 typedef struct _BlobInfo _BlobInfo_;
 
-typedef struct _ImageAttribute _ImageAttribute_;
-
-typedef struct _SplayTreeInfo _SplayTreeInfo_;
-
 typedef MagickBooleanType
   (*MagickProgressMonitor)(const char *,const MagickOffsetType,
     const MagickSizeType,void *);
@@ -656,7 +655,7 @@ typedef struct _Image
   RenderingIntent
     rendering_intent;
 
-  _SplayTreeInfo_
+  void
     *profiles;
 
   ResolutionType
@@ -729,7 +728,7 @@ typedef struct _Image
   void
     *cache;
 
-  _ImageAttribute_
+  void
     *attributes;
 
   _Ascii85Info_
@@ -865,7 +864,7 @@ typedef struct _ImageInfo
   Image
     *attributes;
 
-  _SplayTreeInfo_
+  void
     *options;
 
   MagickProgressMonitor
