@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -58,6 +58,7 @@
 #include "magick/image-private.h"
 #include "magick/log.h"
 #include "magick/resource_.h"
+#include "magick/statistic.h"
 #include "magick/string_.h"
 #include "magick/transform.h"
 #include "magick/type.h"
@@ -1211,7 +1212,7 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
     Initialize Truetype library.
   */
   status=FT_Init_FreeType(&library);
-  if (status)
+  if (status != 0)
     ThrowBinaryException(TypeError,"UnableToInitializeFreetypeLibrary",
       image->filename);
   args.flags=FT_OPEN_PATHNAME;
@@ -1229,6 +1230,9 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
       (IsAccessible(draw_info->metrics) != MagickFalse))
     (void) FT_Attach_File(face,draw_info->metrics);
   encoding_type=ft_encoding_unicode;
+  status=FT_Select_Charmap(face,encoding_type);
+  if ((status != 0) && (face->num_charmaps != 0))
+    status=FT_Set_Charmap(face,face->charmaps[0]);
   if (encoding != (char *) NULL)
     {
       if (LocaleCompare(encoding,"AdobeCustom") == 0)
@@ -1391,17 +1395,16 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
         origin.x+=kerning.x;
       }
     glyph.origin=origin;
-    if (draw_info->render != MagickFalse)
-      status=FT_Load_Glyph(face,glyph.id,FT_LOAD_DEFAULT);
-    else
-      status=FT_Load_Glyph(face,glyph.id,FT_LOAD_NO_BITMAP);
-    if (status != MagickFalse)
+    status=FT_Load_Glyph(face,glyph.id,FT_LOAD_NO_BITMAP);
+    if (status != 0)
       continue;
     status=FT_Get_Glyph(face->glyph,&glyph.image);
-    if (status != MagickFalse)
+    if (status != 0)
       continue;
-    (void) FT_Outline_Get_BBox(&((FT_OutlineGlyph) glyph.image)->outline,
+    status=FT_Outline_Get_BBox(&((FT_OutlineGlyph) glyph.image)->outline,
       &bounds);
+    if (status != 0)
+      continue;
     if ((i == 0) || (bounds.xMin < metrics->bounds.x1))
       metrics->bounds.x1=bounds.xMin;
     if ((i == 0) || (bounds.yMin < metrics->bounds.y1))
@@ -1431,7 +1434,7 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
         */
         status=FT_Glyph_To_Bitmap(&glyph.image,ft_render_mode_normal,
           (FT_Vector *) NULL,MagickTrue);
-        if (status != MagickFalse)
+        if (status != 0)
           continue;
         bitmap=(FT_BitmapGlyph) glyph.image;
         image->storage_class=DirectClass;
