@@ -10,7 +10,7 @@
 %       A   A    T      T    R  R   IIIII  BBBB    UUU     T    EEEEE         %
 %                                                                             %
 %                                                                             %
-%              Methods to Get/Set/Destroy Image Text Attributes               %
+%                       Methods to Get/Set Attributes                         %
 %                                                                             %
 %                             Software Design                                 %
 %                               John Cristy                                   %
@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -50,6 +50,7 @@
 #include "magick/list.h"
 #include "magick/memory_.h"
 #include "magick/profile.h"
+#include "magick/splay-tree.h"
 #include "magick/string_.h"
 #include "magick/utility.h"
 
@@ -67,6 +68,91 @@ static char
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   C l o n e I m a g e A t t r i b u t e s                                   %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  CloneImageAttributes() clones one or more image attributes.
+%
+%  The format of the CloneImageAttributes method is:
+%
+%      MagickBooleanType CloneImageAttributes(Image *image,
+%        const Image *clone_image)
+%
+%  A description of each parameter follows:
+%
+%    o image: The image.
+%
+%    o clone_image: The clone image.
+%
+*/
+MagickExport MagickBooleanType CloneImageAttributes(Image *image,
+  const Image *clone_image)
+{
+  const ImageAttribute
+    *attribute;
+
+  assert(image != (Image *) NULL);
+  assert(image->signature == MagickSignature);
+  if (image->debug != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image->filename);
+  assert(clone_image != (const Image *) NULL);
+  assert(clone_image->signature == MagickSignature);
+  if (clone_image->attributes == (void *) NULL)
+    return(MagickTrue);
+  ResetImageAttributeIterator(clone_image);
+  attribute=GetNextImageAttribute(clone_image);
+  while (attribute != (const ImageAttribute *) NULL)
+  {
+    (void) SetImageAttribute(image,attribute->key,attribute->value);
+    attribute=GetNextImageAttribute(clone_image);
+  }
+  return(MagickTrue);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%   D e l e t e I m a g e O p t i o n                                         %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  DeleteImageAttribute() deletes an attribute from the image.
+%
+%  The format of the DeleteImageAttribute method is:
+%
+%      MagickBooleanType DeleteImageAttribute(Image *image,const char *key)
+%
+%  A description of each parameter follows:
+%
+%    o image: The image info.
+%
+%    o key: The image key.
+%
+*/
+MagickExport MagickBooleanType DeleteImageAttribute(Image *image,
+  const char *key)
+{
+  assert(image != (Image *) NULL);
+  assert(image->signature == MagickSignature);
+  if (image->debug != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image->filename);
+  if (image->attributes == (void *) NULL)
+    return(MagickFalse);
+  return(RemoveNodeFromSplayTree(image->attributes,key));
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   D e s t r o y I m a g e A t t r i b u t e s                               %
 %                                                                             %
 %                                                                             %
@@ -84,31 +170,15 @@ static char
 %
 %    o image: The image.
 %
-%
 */
 MagickExport void DestroyImageAttributes(Image *image)
 {
-  ImageAttribute
-    *attribute;
-
-  register ImageAttribute
-    *p;
-
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),image->filename);
-  for (p=image->attributes; p != (ImageAttribute *) NULL; )
-  {
-    attribute=p;
-    p=p->next;
-    if (attribute->key != (char *) NULL)
-      attribute->key=(char *) RelinquishMagickMemory(attribute->key);
-    if (attribute->value != (char *) NULL)
-      attribute->value=(char *) RelinquishMagickMemory(attribute->value);
-    attribute=(ImageAttribute *) RelinquishMagickMemory(attribute);
-  }
-  image->attributes=(ImageAttribute *) NULL;
+  if (image->attributes != (void *) NULL)
+    image->attributes=DestroySplayTree(image->attributes);
 }
 
 /*
@@ -424,6 +494,8 @@ typedef struct _TagInfo
 static TagInfo
   tag_table[] =
   {
+    {  0x1, (char *) "InteroperabilityIndex"},
+    {  0x2, (char *) "InteroperabilityVersion"},
     {  0x100, (char *) "ImageWidth"},
     {  0x101, (char *) "ImageLength"},
     {  0x102, (char *) "BitsPerSample"},
@@ -489,7 +561,7 @@ static TagInfo
     {  0x9205, (char *) "MaxApertureValue"},
     {  0x9206, (char *) "SubjectDistance"},
     {  0x9207, (char *) "MeteringMode"},
-    {  0x9208, (char *) "LightSrc"},
+    {  0x9208, (char *) "LightSource"},
     {  0x9209, (char *) "Flash"},
     {  0x920a, (char *) "FocalLength"},
     {  0x920b, (char *) "FlashEnergy"},
@@ -498,7 +570,7 @@ static TagInfo
     {  0x9211, (char *) "ImageNumber"},
     {  0x9212, (char *) "SecurityClassification"},
     {  0x9213, (char *) "ImageHistory"},
-    {  0x9214, (char *) "SubjectLocation"},
+    {  0x9214, (char *) "SubjectArea"},
     {  0x9215, (char *) "ExposureIndex"},
     {  0x9216, (char *) "TIFF/EPStandardID"},
     {  0x927c, (char *) "MakerNote"},
@@ -510,6 +582,7 @@ static TagInfo
     {  0xA001, (char *) "ColorSpace"},
     {  0xA002, (char *) "ExifImageWidth"},
     {  0xA003, (char *) "ExifImageLength"},
+    {  0xA004, (char *) "RelatedSoundFile"},
     {  0xA005, (char *) "InteroperabilityOffset"},
     {  0xA20b, (char *) "FlashEnergy"},
     {  0xA20c, (char *) "SpatialFrequencyResponse"},
@@ -522,6 +595,20 @@ static TagInfo
     {  0xA300, (char *) "FileSource"},
     {  0xA301, (char *) "SceneType"},
     {  0xA302, (char *) "CFAPattern"},
+    {  0xA401, (char *) "CustomRendered"},
+    {  0xA402, (char *) "ExposureMode"},
+    {  0xA403, (char *) "WhiteBalance"},
+    {  0xA404, (char *) "DigitalZoomRatio"},
+    {  0xA405, (char *) "FocalLengthIn35mmFilm"},
+    {  0xA406, (char *) "SceneCaptureType"},
+    {  0xA407, (char *) "GainControl"},
+    {  0xA408, (char *) "Contrast"},
+    {  0xA409, (char *) "Saturation"},
+    {  0xA40a, (char *) "Sharpness"},
+    {  0xA40b, (char *) "DeviceSettingDescription"},
+    {  0xA40c, (char *) "SubjectDistanceRange"},
+    {  0xA420, (char *) "ImageUniqueID"},
+    {  0xC4a5, (char *) "PrintImageMatching" },
     {  0x0000, (char *) NULL}
   };
 
@@ -990,18 +1077,24 @@ static int GenerateEXIFAttribute(Image *image,const char *specification)
 MagickExport const ImageAttribute *GetImageAttribute(const Image *image,
   const char *key)
 {
-  register ImageAttribute
+  register const ImageAttribute
     *p;
 
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),image->filename);
-  if (key == (char *) NULL)
-    return(image->attributes);
-  for (p=image->attributes; p != (ImageAttribute *) NULL; p=p->next)
-    if (LocaleCompare(key,p->key) == 0)
+  if (image->attributes == (void *) NULL)
+   return((const ImageAttribute *) NULL);
+  if (key == (const char *) NULL)
+    {
+      ResetSplayTreeIterator(image->attributes);
+      p=(const ImageAttribute *) GetNextValueInSplayTree(image->attributes);
       return(p);
+    }
+  p=(const ImageAttribute *) GetValueFromSplayTree(image->attributes,key);
+  if (p != (const ImageAttribute *) NULL)
+    return(p);
   if (LocaleNCompare("iptc:",key,5) == 0)
     {
       if (GenerateIPTCAttribute((Image *) image,key) == MagickTrue)
@@ -1292,6 +1385,74 @@ MagickExport const ImageAttribute *GetImageInfoAttribute(
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   G e t N e x t I m a g e A t t r i b u t e                                 %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  GetNextImageAttribute() gets the next image attribute.
+%
+%  The format of the GetNextImageAttribute method is:
+%
+%      const ImageAttribute *GetNextImageAttribute(const Image *image)
+%
+%  A description of each parameter follows:
+%
+%    o image: The image.
+%
+*/
+MagickExport const ImageAttribute *GetNextImageAttribute(const Image *image)
+{
+  assert(image != (Image *) NULL);
+  assert(image->signature == MagickSignature);
+  if (image->debug != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image->filename);
+  if (image->attributes == (void *) NULL)
+    return((const ImageAttribute *) NULL);
+  return((const ImageAttribute *) GetNextValueInSplayTree(image->attributes));
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%   R e s e t I m a g e A t t r i b u t e I t e r a t o r                     %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  ResetImageAttributeIterator() resets the image attributes iterator.  Use it
+%  in conjunction with GetNextImageAttribute() to iterate over all the values
+%  associated with an image.
+%
+%  The format of the ResetImageAttributeIterator method is:
+%
+%      ResetImageAttributeIterator(const ImageInfo *image)
+%
+%  A description of each parameter follows:
+%
+%    o image: The image.
+%
+*/
+MagickExport void ResetImageAttributeIterator(const Image *image)
+{
+  assert(image != (Image *) NULL);
+  assert(image->signature == MagickSignature);
+  if (image->debug != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image->filename);
+  if (image->attributes == (void *) NULL)
+    return;
+  ResetSplayTreeIterator(image->attributes);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   S e t I m a g e A t t r i b u t e                                         %
 %                                                                             %
 %                                                                             %
@@ -1300,11 +1461,7 @@ MagickExport const ImageAttribute *GetImageInfoAttribute(
 %
 %  SetImageAttribute() searches the list of image attributes and replaces the
 %  attribute value.  If it is not found in the list, the attribute name
-%  and value is added to the list.   If the attribute exists in the list,
-%  the value is concatenated to the attribute.  SetImageAttribute returns
-%  MagickTrue if the attribute is successfully concatenated or added to the
-%  list, otherwise MagickFalse.  If the value is NULL, the matching key is
-%  deleted from the list.
+%  and value is added to the list.   
 %
 %  The format of the SetImageAttribute method is:
 %
@@ -1315,101 +1472,69 @@ MagickExport const ImageAttribute *GetImageInfoAttribute(
 %
 %    o image: The image.
 %
-%    o key,value:  These character strings are the name and value of an image
-%      attribute to replace or add to the list.
+%    o key: The key.
 %
+%    o value: The value.
 %
 */
+
+static void *DestroyAttribute(void *attribute)
+{
+  register ImageAttribute
+    *p;
+
+  p=(ImageAttribute *) attribute;
+  if (p->value != (char *) NULL)
+    p->value=(char *) RelinquishMagickMemory(p->value);
+  return(RelinquishMagickMemory(p));
+}
+
 MagickExport  MagickBooleanType SetImageAttribute(Image *image,const char *key,
   const char *value)
 {
   ImageAttribute
     *attribute;
 
+  MagickBooleanType
+    status;
+
   register const char
     *q;
 
-  register ImageAttribute
-    *p;
-
-  /*
-    Initialize new attribute.
-  */
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),image->filename);
   if ((key == (const char *) NULL) || (*key == '\0'))
     return(MagickFalse);
+  if (image->attributes == (void *) NULL)
+    image->attributes=NewSplayTree(CompareSplayTreeString,
+      RelinquishMagickMemory,DestroyAttribute);
   if (value == (const char *) NULL)
-    {
-      /*
-        Delete attribute from the image attributes list.
-      */
-      for (p=image->attributes; p != (ImageAttribute *) NULL; p=p->next)
-        if (LocaleCompare(key,p->key) == 0)
-          break;
-      if (p == (ImageAttribute *) NULL)
-        return(MagickFalse);
-      if (p->key != (char *) NULL)
-        p->key=(char *) RelinquishMagickMemory(p->key);
-      if (p->value != (char *) NULL)
-        p->value=(char *) RelinquishMagickMemory(p->value);
-      if (p->previous != (ImageAttribute *) NULL)
-        p->previous->next=p->next;
-      else
-        {
-          image->attributes=p->next;
-          if (p->next != (ImageAttribute *) NULL)
-            p->next->previous=(ImageAttribute *) NULL;
-        }
-      if (p->next != (ImageAttribute *) NULL)
-        p->next->previous=p->previous;
-      attribute=p;
-      attribute=(ImageAttribute *) RelinquishMagickMemory(attribute);
-      return(MagickTrue);
-    }
+    return(DeleteImageAttribute(image,key));
   if (*value == '\0')
     return(MagickFalse);
+  /*
+    Add new image attribute.
+  */
   attribute=(ImageAttribute *) AcquireMagickMemory(sizeof(*attribute));
   if (attribute == (ImageAttribute *) NULL)
-    return(MagickFalse);
-  attribute->key=AcquireString(key);
+    ThrowMagickFatalException(ResourceLimitFatalError,"MemoryAllocationFailed",
+      key);
+  (void) ResetMagickMemory(attribute,0,sizeof(*attribute));
+  attribute->key=ConstantString(AcquireString(key));
   for (q=value; *q != '\0'; q++)
     if (((int) ((unsigned char) *q) < 32) &&
         (isspace((int) ((unsigned char) *q)) == 0))
       break;
   if (*q != '\0')
-    attribute->value=AcquireString(value);
+    attribute->value=ConstantString(AcquireString(value));
   else
-    attribute->value=TranslateText((ImageInfo *) NULL,image,value);
+    attribute->value=
+      ConstantString(TranslateText((ImageInfo *) NULL,image,value));
   attribute->compression=MagickFalse;
-  attribute->previous=(ImageAttribute *) NULL;
-  attribute->next=(ImageAttribute *) NULL;
-  if (image->attributes == (ImageAttribute *) NULL)
-    {
-      image->attributes=attribute;
-      return(MagickTrue);
-    }
-  for (p=image->attributes; p != (ImageAttribute *) NULL; p=p->next)
-  {
-    if (LocaleCompare(attribute->key,p->key) == 0)
-      {
-        (void) ConcatenateString(&p->value,attribute->value);
-        attribute->value=(char *) RelinquishMagickMemory(attribute->value);
-        attribute->key=(char *) RelinquishMagickMemory(attribute->key);
-        attribute=(ImageAttribute *) RelinquishMagickMemory(attribute);
-        return(MagickTrue);
-      }
-    if (p->next == (ImageAttribute *) NULL)
-      break;
-  }
-  /*
-    Place new attribute at the end of the attribute list.
-  */
-  attribute->previous=p;
-  p->next=attribute;
-  return(MagickTrue);
+  status=AddValueToSplayTree(image->attributes,attribute->key,attribute);
+  return(status);
 }
 
 /*
