@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -114,6 +114,7 @@ static const char
     "  <coder magick=\"JNG\" name=\"PNG\" />"
     "  <coder magick=\"JPC\" name=\"JP2\" />"
     "  <coder magick=\"JPG\" name=\"JPEG\" />"
+    "  <coder magick=\"JPX\" name=\"JP2\" />"
     "  <coder magick=\"K\" name=\"GRAY\" />"
     "  <coder magick=\"LOGO\" name=\"MAGICK\" />"
     "  <coder magick=\"M2V\" name=\"MPEG\" />"
@@ -605,8 +606,7 @@ static void *DestroyCoderNode(void *coder_info)
     p->name=(char *) RelinquishMagickMemory(p->name);
   if (p->magick != (char *) NULL)
     p->magick=(char *) RelinquishMagickMemory(p->magick);
-  p=(CoderInfo *) RelinquishMagickMemory(p);
-  return((void *) NULL);
+  return(RelinquishMagickMemory(p));
 }
 
 static MagickBooleanType LoadCoderList(const char *xml,const char *filename,
