@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -85,9 +85,6 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
   const ColorspaceType colorspace)
 {
 #define RGBTransformImageTag  "RGBTransform/Image"
-#define X  0
-#define Y  ((MaxMap+1))
-#define Z  (2*(MaxMap+1))
 
   long
     y;
@@ -95,23 +92,18 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
   IndexPacket
     *indexes;
 
-  LongPixelPacket
-    quantum;
-
   MagickBooleanType
     status;
 
   MagickPixelPacket
     pixel;
 
-  MagickRealType
+  PrimaryInfo
+    primary_info,
     *x_map,
     *y_map,
     *z_map;
 
-  PrimaryInfo
-    primary_info;
-
   register long
     i,
     x;
@@ -126,10 +118,20 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
   assert(colorspace != RGBColorspace);
   assert(colorspace != TransparentColorspace);
   assert(colorspace != UndefinedColorspace);
-  if ((image->colorspace != RGBColorspace) ||
-      (image->colorspace != GRAYColorspace) ||
-      (image->colorspace != TransparentColorspace))
-    (void) SetImageColorspace(image,image->colorspace);
+  switch (image->colorspace)
+  {
+    case GRAYColorspace:
+    case Rec601LumaColorspace:
+    case Rec709LumaColorspace:
+    case RGBColorspace:
+    case TransparentColorspace:
+      break;
+    default:
+    {
+      (void) SetImageColorspace(image,image->colorspace);
+      break;
+    }
+	}
   image->colorspace=colorspace;
   switch (colorspace)
   {
@@ -209,8 +211,8 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
     case HSBColorspace:
     {
       double
+        brightness,
         hue,
-        luminosity,
         saturation;
 
       /*
@@ -221,6 +223,9 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
           (void) SyncImage(image);
           image->storage_class=DirectClass;
         }
+      hue=0.0;
+      saturation=0.0;
+      brightness=0.0;
       for (y=0; y < (long) image->rows; y++)
       {
         q=GetImagePixels(image,0,y,image->columns,1);
@@ -228,10 +233,10 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
           break;
         for (x=(long) image->columns-1; x >= 0; x--)
         {
-          TransformHSB(q->red,q->green,q->blue,&hue,&saturation,&luminosity);
-          q->red=(Quantum) (MaxRGB*hue+0.5);
-          q->green=(Quantum) (MaxRGB*saturation+0.5);
-          q->blue=(Quantum) (MaxRGB*luminosity+0.5);
+          TransformHSB(q->red,q->green,q->blue,&hue,&saturation,&brightness);
+          q->red=RoundToQuantum(MaxRGB*hue);
+          q->green=RoundToQuantum(MaxRGB*saturation);
+          q->blue=RoundToQuantum(MaxRGB*brightness);
           q++;
         }
         if (SyncImagePixels(image) == MagickFalse)
@@ -255,6 +260,9 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
           (void) SyncImage(image);
           image->storage_class=DirectClass;
         }
+      hue=0.0;
+      saturation=0.0;
+      luminosity=0.0;
       for (y=0; y < (long) image->rows; y++)
       {
         q=GetImagePixels(image,0,y,image->columns,1);
@@ -263,9 +271,9 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
         for (x=(long) image->columns-1; x >= 0; x--)
         {
           TransformHSL(q->red,q->green,q->blue,&hue,&saturation,&luminosity);
-          q->red=(Quantum) (MaxRGB*hue+0.5);
-          q->green=(Quantum) (MaxRGB*saturation+0.5);
-          q->blue=(Quantum) (MaxRGB*luminosity+0.5);
+          q->red=RoundToQuantum(MaxRGB*hue);
+          q->green=RoundToQuantum(MaxRGB*saturation);
+          q->blue=RoundToQuantum(MaxRGB*luminosity);
           q++;
         }
         if (SyncImagePixels(image) == MagickFalse)
@@ -289,6 +297,9 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
           (void) SyncImage(image);
           image->storage_class=DirectClass;
         }
+      hue=0.0;
+      whiteness=0.0;
+      blackness=0.0;
       for (y=0; y < (long) image->rows; y++)
       {
         q=GetImagePixels(image,0,y,image->columns,1);
@@ -297,9 +308,9 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
         for (x=(long) image->columns-1; x >= 0; x--)
         {
           TransformHWB(q->red,q->green,q->blue,&hue,&whiteness,&blackness);
-          q->red=(Quantum) (MaxRGB*hue+0.5);
-          q->green=(Quantum) (MaxRGB*whiteness+0.5);
-          q->blue=(Quantum) (MaxRGB*blackness+0.5);
+          q->red=RoundToQuantum(MaxRGB*hue);
+          q->green=RoundToQuantum(MaxRGB*whiteness);
+          q->blue=RoundToQuantum(MaxRGB*blackness);
           q++;
         }
         if (SyncImagePixels(image) == MagickFalse)
@@ -314,38 +325,56 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
   /*
     Allocate the tables.
   */
-  x_map=(MagickRealType *)
-    AcquireMagickMemory(3*(size_t) (MaxMap+1)*sizeof(*x_map));
-  y_map=(MagickRealType *)
-    AcquireMagickMemory(3*(size_t) (MaxMap+1)*sizeof(*y_map));
-  z_map=(MagickRealType *)
-    AcquireMagickMemory(3*(size_t) (MaxMap+1)*sizeof(*z_map));
-  if ((x_map == (MagickRealType *) NULL) ||
-      (y_map == (MagickRealType *) NULL) ||
-      (z_map == (MagickRealType *) NULL))
+  x_map=(PrimaryInfo *) AcquireMagickMemory((size_t) (MaxMap+1)*sizeof(*x_map));
+  y_map=(PrimaryInfo *) AcquireMagickMemory((size_t) (MaxMap+1)*sizeof(*y_map));
+  z_map=(PrimaryInfo *) AcquireMagickMemory((size_t) (MaxMap+1)*sizeof(*z_map));
+  if ((x_map == (PrimaryInfo *) NULL) || (y_map == (PrimaryInfo *) NULL) ||
+      (z_map == (PrimaryInfo *) NULL))
     ThrowBinaryException(ResourceLimitError,"MemoryAllocationFailed",
       image->filename);
   (void) ResetMagickMemory(&primary_info,0,sizeof(primary_info));
   switch (colorspace)
   {
+    case Rec601LumaColorspace:
     case GRAYColorspace:
     {
       /*
-        Initialize GRAY tables:
+        Initialize Rec601 luma tables:
 
           G = 0.29900*R+0.58700*G+0.11400*B
       */
       for (i=0; i <= (long) MaxMap; i++)
       {
-        x_map[i+X]=0.299*i;
-        y_map[i+X]=0.587*i;
-        z_map[i+X]=0.114*i;
-        x_map[i+Y]=0.299*i;
-        y_map[i+Y]=0.587*i;
-        z_map[i+Y]=0.114*i;
-        x_map[i+Z]=0.299*i;
-        y_map[i+Z]=0.587*i;
-        z_map[i+Z]=0.114*i;
+        x_map[i].x=0.299*i;
+        x_map[i].y=0.299*i;
+        x_map[i].z=0.299*i;
+        y_map[i].x=0.587*i;
+        y_map[i].y=0.587*i;
+        y_map[i].z=0.587*i;
+        z_map[i].x=0.114*i;
+        z_map[i].y=0.114*i;
+        z_map[i].z=0.114*i;
+      }
+      break;
+    }
+    case Rec709LumaColorspace:
+    {
+      /*
+        Initialize Rec709 luma tables:
+
+          G = 0.21260*R+0.7152*G+0.07220*B
+      */
+      for (i=0; i <= (long) MaxMap; i++)
+      {
+        x_map[i].x=0.2126*i;
+        x_map[i].y=0.2126*i;
+        x_map[i].z=0.2126*i;
+        y_map[i].x=0.7152*i;
+        y_map[i].y=0.7152*i;
+        y_map[i].z=0.7152*i;
+        z_map[i].x=0.0722*i;
+        z_map[i].y=0.0722*i;
+        z_map[i].z=0.0722*i;
       }
       break;
     }
@@ -361,19 +390,19 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
         I and Q, normally -0.5 through 0.5, are normalized to the range 0
         through MaxRGB.
       */
-      primary_info.y=(MaxMap+1)/2;
-      primary_info.z=(MaxMap+1)/2;
+      primary_info.y=(MaxMap+1)/2.0;
+      primary_info.z=(MaxMap+1)/2.0;
       for (i=0; i <= (long) MaxMap; i++)
       {
-        x_map[i+X]=0.33333*i;
-        y_map[i+X]=0.33334*i;
-        z_map[i+X]=0.33333*i;
-        x_map[i+Y]=0.5*i;
-        y_map[i+Y]=0.0;
-        z_map[i+Y]=(-0.5)*i;
-        x_map[i+Z]=(-0.25)*i;
-        y_map[i+Z]=0.5*i;
-        z_map[i+Z]=(-0.25)*i;
+        x_map[i].x=0.33333*i;
+        x_map[i].y=0.5*i;
+        x_map[i].z=(-0.25)*i;
+        y_map[i].x=0.33334*i;
+        y_map[i].y=0.0;
+        y_map[i].z=0.5*i;
+        z_map[i].x=0.33333*i;
+        z_map[i].y=(-0.5)*i;
+        z_map[i].z=(-0.25)*i;
       }
       break;
     }
@@ -388,31 +417,31 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
 
         sRGB is scaled by 1.3584.  C1 zero is 156 and C2 is at 137.
       */
-      primary_info.y=ScaleQuantumToMap(ScaleCharToQuantum(156));
-      primary_info.z=ScaleQuantumToMap(ScaleCharToQuantum(137));
+      primary_info.y=(double) ScaleQuantumToMap(ScaleCharToQuantum(156));
+      primary_info.z=(double) ScaleQuantumToMap(ScaleCharToQuantum(137));
       for (i=0; i <= (long) (0.018*MaxMap); i++)
       {
-        x_map[i+X]=0.003962014134275617*i;
-        y_map[i+X]=0.007778268551236748*i;
-        z_map[i+X]=0.001510600706713781*i;
-        x_map[i+Y]=(-0.002426619775463276)*i;
-        y_map[i+Y]=(-0.004763965913702149)*i;
-        z_map[i+Y]=0.007190585689165425*i;
-        x_map[i+Z]=0.006927257754597858*i;
-        y_map[i+Z]=(-0.005800713697502058)*i;
-        z_map[i+Z]=(-0.0011265440570958)*i;
+        x_map[i].x=0.003962014134275617*i;
+        x_map[i].y=(-0.002426619775463276)*i;
+        x_map[i].z=0.006927257754597858*i;
+        y_map[i].x=0.007778268551236748*i;
+        y_map[i].y=(-0.004763965913702149)*i;
+        y_map[i].z=(-0.005800713697502058)*i;
+        z_map[i].x=0.001510600706713781*i;
+        z_map[i].y=0.007190585689165425*i;
+        z_map[i].z=(-0.0011265440570958)*i;
       }
       for ( ; i <= (long) MaxMap; i++)
       {
-        x_map[i+X]=0.2201118963486454*(1.099*i-0.099);
-        y_map[i+X]=0.4321260306242638*(1.099*i-0.099);
-        z_map[i+X]=0.08392226148409894*(1.099*i-0.099);
-        x_map[i+Y]=(-0.1348122097479598)*(1.099*i-0.099);
-        y_map[i+Y]=(-0.2646647729834528)*(1.099*i-0.099);
-        z_map[i+Y]=0.3994769827314126*(1.099*i-0.099);
-        x_map[i+Z]=0.3848476530332144*(1.099*i-0.099);
-        y_map[i+Z]=(-0.3222618720834477)*(1.099*i-0.099);
-        z_map[i+Z]=(-0.06258578094976668)*(1.099*i-0.099);
+        x_map[i].x=0.2201118963486454*(1.099*i-0.099);
+        x_map[i].y=(-0.1348122097479598)*(1.099*i-0.099);
+        x_map[i].z=0.3848476530332144*(1.099*i-0.099);
+        y_map[i].x=0.4321260306242638*(1.099*i-0.099);
+        y_map[i].y=(-0.2646647729834528)*(1.099*i-0.099);
+        y_map[i].z=(-0.3222618720834477)*(1.099*i-0.099);
+        z_map[i].x=0.08392226148409894*(1.099*i-0.099);
+        z_map[i].y=0.3994769827314126*(1.099*i-0.099);
+        z_map[i].z=(-0.06258578094976668)*(1.099*i-0.099);
       }
       break;
     }
@@ -427,15 +456,15 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
       */
       for (i=0; i <= (long) MaxMap; i++)
       {
-        x_map[i+X]=0.412453*i;
-        y_map[i+X]=0.35758*i;
-        z_map[i+X]=0.180423*i;
-        x_map[i+Y]=0.212671*i;
-        y_map[i+Y]=0.71516*i;
-        z_map[i+Y]=0.072169*i;
-        x_map[i+Z]=0.019334*i;
-        y_map[i+Z]=0.119193*i;
-        z_map[i+Z]=0.950227*i;
+        x_map[i].x=0.412453*i;
+        x_map[i].y=0.212671*i;
+        x_map[i].z=0.019334*i;
+        y_map[i].x=0.35758*i;
+        y_map[i].y=0.71516*i;
+        y_map[i].z=0.119193*i;
+        z_map[i].x=0.180423*i;
+        z_map[i].y=0.072169*i;
+        z_map[i].z=0.950227*i;
       }
       break;
     }
@@ -451,19 +480,19 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
         Cb and Cr, normally -0.5 through 0.5, are normalized to the range 0
         through MaxRGB.
       */
-      primary_info.y=(MaxMap+1)/2;
-      primary_info.z=(MaxMap+1)/2;
+      primary_info.y=(MaxMap+1)/2.0;
+      primary_info.z=(MaxMap+1)/2.0;
       for (i=0; i <= (long) MaxMap; i++)
       {
-        x_map[i+X]=0.299*i;
-        y_map[i+X]=0.587*i;
-        z_map[i+X]=0.114*i;
-        x_map[i+Y]=(-0.16873)*i;
-        y_map[i+Y]=(-0.331264)*i;
-        z_map[i+Y]=0.500000*i;
-        x_map[i+Z]=0.500000*i;
-        y_map[i+Z]=(-0.418688)*i;
-        z_map[i+Z]=(-0.081316)*i;
+        x_map[i].x=0.299*i;
+        x_map[i].y=(-0.16873)*i;
+        x_map[i].z=0.500000*i;
+        y_map[i].x=0.587*i;
+        y_map[i].y=(-0.331264)*i;
+        y_map[i].z=(-0.418688)*i;
+        z_map[i].x=0.114*i;
+        z_map[i].y=0.500000*i;
+        z_map[i].z=(-0.081316)*i;
       }
       break;
     }
@@ -478,31 +507,31 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
 
         YCC is scaled by 1.3584.  C1 zero is 156 and C2 is at 137.
       */
-      primary_info.y=ScaleQuantumToMap(ScaleCharToQuantum(156));
-      primary_info.z=ScaleQuantumToMap(ScaleCharToQuantum(137));
+      primary_info.y=(double) ScaleQuantumToMap(ScaleCharToQuantum(156));
+      primary_info.z=(double) ScaleQuantumToMap(ScaleCharToQuantum(137));
       for (i=0; i <= (long) (0.018*MaxMap); i++)
       {
-        x_map[i+X]=0.003962014134275617*i;
-        y_map[i+X]=0.007778268551236748*i;
-        z_map[i+X]=0.001510600706713781*i;
-        x_map[i+Y]=(-0.002426619775463276)*i;
-        y_map[i+Y]=(-0.004763965913702149)*i;
-        z_map[i+Y]=0.007190585689165425*i;
-        x_map[i+Z]=0.006927257754597858*i;
-        y_map[i+Z]=(-0.005800713697502058)*i;
-        z_map[i+Z]=(-0.0011265440570958)*i;
+        x_map[i].x=0.003962014134275617*i;
+        x_map[i].y=(-0.002426619775463276)*i;
+        x_map[i].z=0.006927257754597858*i;
+        y_map[i].x=0.007778268551236748*i;
+        y_map[i].y=(-0.004763965913702149)*i;
+        y_map[i].z=(-0.005800713697502058)*i;
+        z_map[i].x=0.001510600706713781*i;
+        z_map[i].y=0.007190585689165425*i;
+        z_map[i].z=(-0.0011265440570958)*i;
       }
       for ( ; i <= (long) MaxMap; i++)
       {
-        x_map[i+X]=0.2201118963486454*(1.099*i-0.099);
-        y_map[i+X]=0.4321260306242638*(1.099*i-0.099);
-        z_map[i+X]=0.08392226148409894*(1.099*i-0.099);
-        x_map[i+Y]=(-0.1348122097479598)*(1.099*i-0.099);
-        y_map[i+Y]=(-0.2646647729834528)*(1.099*i-0.099);
-        z_map[i+Y]=0.3994769827314126*(1.099*i-0.099);
-        x_map[i+Z]=0.3848476530332144*(1.099*i-0.099);
-        y_map[i+Z]=(-0.3222618720834477)*(1.099*i-0.099);
-        z_map[i+Z]=(-0.06258578094976668)*(1.099*i-0.099);
+        x_map[i].x=0.2201118963486454*(1.099*i-0.099);
+        x_map[i].y=(-0.1348122097479598)*(1.099*i-0.099);
+        x_map[i].z=0.3848476530332144*(1.099*i-0.099);
+        y_map[i].x=0.4321260306242638*(1.099*i-0.099);
+        y_map[i].y=(-0.2646647729834528)*(1.099*i-0.099);
+        y_map[i].z=(-0.3222618720834477)*(1.099*i-0.099);
+        z_map[i].x=0.08392226148409894*(1.099*i-0.099);
+        z_map[i].y=0.3994769827314126*(1.099*i-0.099);
+        z_map[i].z=(-0.06258578094976668)*(1.099*i-0.099);
       }
       break;
     }
@@ -518,19 +547,19 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
         I and Q, normally -0.5 through 0.5, are normalized to the range 0
         through MaxRGB.
       */
-      primary_info.y=(MaxMap+1)/2;
-      primary_info.z=(MaxMap+1)/2;
+      primary_info.y=(MaxMap+1)/2.0;
+      primary_info.z=(MaxMap+1)/2.0;
       for (i=0; i <= (long) MaxMap; i++)
       {
-        x_map[i+X]=0.299*i;
-        y_map[i+X]=0.587*i;
-        z_map[i+X]=0.114*i;
-        x_map[i+Y]=0.596*i;
-        y_map[i+Y]=(-0.274)*i;
-        z_map[i+Y]=(-0.322)*i;
-        x_map[i+Z]=0.211*i;
-        y_map[i+Z]=(-0.523)*i;
-        z_map[i+Z]=0.312*i;
+        x_map[i].x=0.299*i;
+        x_map[i].y=0.596*i;
+        x_map[i].z=0.211*i;
+        y_map[i].x=0.587*i;
+        y_map[i].y=(-0.274)*i;
+        y_map[i].z=(-0.523)*i;
+        z_map[i].x=0.114*i;
+        z_map[i].y=(-0.322)*i;
+        z_map[i].z=0.312*i;
       }
       break;
     }
@@ -546,19 +575,19 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
         Pb and Pr, normally -0.5 through 0.5, are normalized to the range 0
         through MaxRGB.
       */
-      primary_info.y=(MaxMap+1)/2;
-      primary_info.z=(MaxMap+1)/2;
+      primary_info.y=(MaxMap+1)/2.0;
+      primary_info.z=(MaxMap+1)/2.0;
       for (i=0; i <= (long) MaxMap; i++)
       {
-        x_map[i+X]=0.299*i;
-        y_map[i+X]=0.587*i;
-        z_map[i+X]=0.114*i;
-        x_map[i+Y]=(-0.168736)*i;
-        y_map[i+Y]=(-0.331264)*i;
-        z_map[i+Y]=0.5*i;
-        x_map[i+Z]=0.5*i;
-        y_map[i+Z]=(-0.418688)*i;
-        z_map[i+Z]=(-0.081312)*i;
+        x_map[i].x=0.299*i;
+        x_map[i].y=(-0.168736)*i;
+        x_map[i].z=0.5*i;
+        y_map[i].x=0.587*i;
+        y_map[i].y=(-0.331264)*i;
+        y_map[i].z=(-0.418688)*i;
+        z_map[i].x=0.114*i;
+        z_map[i].y=0.5*i;
+        z_map[i].z=(-0.081312)*i;
       }
       break;
     }
@@ -575,19 +604,19 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
         U and V, normally -0.5 through 0.5, are normalized to the range 0
         through MaxRGB.  Note that U = 0.493*(B-Y), V = 0.877*(R-Y).
       */
-      primary_info.y=(MaxMap+1)/2;
-      primary_info.z=(MaxMap+1)/2;
+      primary_info.y=(MaxMap+1)/2.0;
+      primary_info.z=(MaxMap+1)/2.0;
       for (i=0; i <= (long) MaxMap; i++)
       {
-        x_map[i+X]=0.299*i;
-        y_map[i+X]=0.587*i;
-        z_map[i+X]=0.114*i;
-        x_map[i+Y]=(-0.1474)*i;
-        y_map[i+Y]=(-0.2895)*i;
-        z_map[i+Y]=0.4369*i;
-        x_map[i+Z]=0.615*i;
-        y_map[i+Z]=(-0.515)*i;
-        z_map[i+Z]=(-0.1)*i;
+        x_map[i].x=0.299*i;
+        x_map[i].y=(-0.1474)*i;
+        x_map[i].z=0.615*i;
+        y_map[i].x=0.587*i;
+        y_map[i].y=(-0.2895)*i;
+        y_map[i].z=(-0.515)*i;
+        z_map[i].x=0.114*i;
+        z_map[i].y=0.4369*i;
+        z_map[i].z=(-0.1)*i;
       }
       break;
     }
@@ -614,21 +643,18 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
           break;
         for (x=0; x < (long) image->columns; x++)
         {
-          pixel.red=x_map[ScaleQuantumToMap(q->red)+X]+
-            y_map[ScaleQuantumToMap(q->green)+X]+
-            z_map[ScaleQuantumToMap(q->blue)+X]+primary_info.x;
-          quantum.red=RoundToMap(pixel.red);
-          pixel.green=x_map[ScaleQuantumToMap(q->red)+Y]+
-            y_map[ScaleQuantumToMap(q->green)+Y]+
-            z_map[ScaleQuantumToMap(q->blue)+Y]+primary_info.y;
-          quantum.green=RoundToMap(pixel.green);
-          pixel.blue=x_map[ScaleQuantumToMap(q->red)+Z]+
-            y_map[ScaleQuantumToMap(q->green)+Z]+
-            z_map[ScaleQuantumToMap(q->blue)+Z]+primary_info.z;
-          quantum.blue=RoundToMap(pixel.blue);
-          q->red=ScaleMapToQuantum(quantum.red);
-          q->green=ScaleMapToQuantum(quantum.green);
-          q->blue=ScaleMapToQuantum(quantum.blue);
+          pixel.red=x_map[ScaleQuantumToMap(q->red)].x+
+            y_map[ScaleQuantumToMap(q->green)].x+
+            z_map[ScaleQuantumToMap(q->blue)].x+primary_info.x;
+          pixel.green=x_map[ScaleQuantumToMap(q->red)].y+
+            y_map[ScaleQuantumToMap(q->green)].y+
+            z_map[ScaleQuantumToMap(q->blue)].y+primary_info.y;
+          pixel.blue=x_map[ScaleQuantumToMap(q->red)].z+
+            y_map[ScaleQuantumToMap(q->green)].z+
+            z_map[ScaleQuantumToMap(q->blue)].z+primary_info.z;
+          q->red=ScaleMapToQuantum(RoundToMap(pixel.red));
+          q->green=ScaleMapToQuantum(RoundToMap(pixel.green));
+          q->blue=ScaleMapToQuantum(RoundToMap(pixel.blue));
           q++;
         }
         if (SyncImagePixels(image) == MagickFalse)
@@ -651,21 +677,18 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
       */
       for (i=0; i < (long) image->colors; i++)
       {
-        pixel.red=x_map[ScaleQuantumToMap(image->colormap[i].red)+X]+
-          y_map[ScaleQuantumToMap(image->colormap[i].green)+X]+
-          z_map[ScaleQuantumToMap(image->colormap[i].blue)+X]+primary_info.x;
-        quantum.red=RoundToMap(pixel.red);
-        pixel.green=x_map[ScaleQuantumToMap(image->colormap[i].red)+Y]+
-          y_map[ScaleQuantumToMap(image->colormap[i].green)+Y]+
-          z_map[ScaleQuantumToMap(image->colormap[i].blue)+Y]+primary_info.y;
-        quantum.green=RoundToMap(pixel.green);
-        pixel.blue=x_map[ScaleQuantumToMap(image->colormap[i].red)+Z]+
-          y_map[ScaleQuantumToMap(image->colormap[i].green)+Z]+
-          z_map[ScaleQuantumToMap(image->colormap[i].blue)+Z]+primary_info.z;
-        quantum.blue=RoundToMap(pixel.blue);
-        image->colormap[i].red=ScaleMapToQuantum(quantum.red);
-        image->colormap[i].green=ScaleMapToQuantum(quantum.green);
-        image->colormap[i].blue=ScaleMapToQuantum(quantum.blue);
+        pixel.red=x_map[ScaleQuantumToMap(image->colormap[i].red)].x+
+          y_map[ScaleQuantumToMap(image->colormap[i].green)].x+
+          z_map[ScaleQuantumToMap(image->colormap[i].blue)].x+primary_info.x;
+        pixel.green=x_map[ScaleQuantumToMap(image->colormap[i].red)].y+
+          y_map[ScaleQuantumToMap(image->colormap[i].green)].y+
+          z_map[ScaleQuantumToMap(image->colormap[i].blue)].y+primary_info.y;
+        pixel.blue=x_map[ScaleQuantumToMap(image->colormap[i].red)].z+
+          y_map[ScaleQuantumToMap(image->colormap[i].green)].z+
+          z_map[ScaleQuantumToMap(image->colormap[i].blue)].z+primary_info.z;
+        image->colormap[i].red=ScaleMapToQuantum(RoundToMap(pixel.red));
+        image->colormap[i].green=ScaleMapToQuantum(RoundToMap(pixel.green));
+        image->colormap[i].blue=ScaleMapToQuantum(RoundToMap(pixel.blue));
       }
       (void) SyncImage(image);
       break;
@@ -674,9 +697,9 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
   /*
     Free resources.
   */
-  z_map=(MagickRealType *) RelinquishMagickMemory(z_map);
-  y_map=(MagickRealType *) RelinquishMagickMemory(y_map);
-  x_map=(MagickRealType *) RelinquishMagickMemory(x_map);
+  z_map=(PrimaryInfo *) RelinquishMagickMemory(z_map);
+  y_map=(PrimaryInfo *) RelinquishMagickMemory(y_map);
+  x_map=(PrimaryInfo *) RelinquishMagickMemory(x_map);
   return(MagickTrue);
 }
 
@@ -764,9 +787,6 @@ MagickExport MagickBooleanType SetImageColorspace(Image *image,
 MagickExport MagickBooleanType TransformRGBImage(Image *image,
   const ColorspaceType colorspace)
 {
-#define B  (2*(MaxMap+1))
-#define G  (MaxMap+1)
-#define R  0
 #define MaxYCC  ((unsigned long) (1.3584*MaxMap+0.5))
 #define TransformRGBImageTag  "Transform/Image"
 
@@ -842,10 +862,10 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
   MagickPixelPacket
     pixel;
 
-  MagickRealType
-    *blue_map,
-    *green_map,
-    *red_map;
+  PrimaryInfo
+    *y_map,
+    *x_map,
+    *z_map;
 
   register long
     x;
@@ -861,9 +881,17 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),image->filename);
   assert(image->colorspace != UndefinedColorspace);
-  if ((colorspace == RGBColorspace) || (colorspace == GRAYColorspace) ||
-      (colorspace == TransparentColorspace))
-    return(MagickTrue);
+  switch (colorspace)
+  {
+    case GRAYColorspace:
+    case Rec601LumaColorspace:
+    case Rec709LumaColorspace:
+    case RGBColorspace:
+    case TransparentColorspace:
+      return(MagickTrue);
+    default:
+      break;
+	}
   switch (colorspace)
   {
     case CMYKColorspace:
@@ -887,12 +915,12 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
         indexes=GetIndexes(image);
         for (x=0; x < (long) image->columns; x++)
         {
-          q->red=(Quantum) (QuantumScale*((MagickRealType)
-            (MaxRGB-q->red)*(MaxRGB-indexes[x]))+0.5);
-          q->green=(Quantum) (QuantumScale*((MagickRealType)
-            (MaxRGB-q->green)*(MaxRGB-indexes[x]))+0.5);
-          q->blue=(Quantum) (QuantumScale*((MagickRealType)
-            (MaxRGB-q->blue)*(MaxRGB-indexes[x]))+0.5);
+          q->red=RoundToQuantum(QuantumScale*
+            ((MagickRealType) (MaxRGB-q->red)*(MaxRGB-indexes[x])));
+          q->green=RoundToQuantum(QuantumScale*
+            ((MagickRealType) (MaxRGB-q->green)*(MaxRGB-indexes[x])));
+          q->blue=RoundToQuantum(QuantumScale*
+            ((MagickRealType) (MaxRGB-q->blue)*(MaxRGB-indexes[x])));
           q++;
         }
         if (SyncImagePixels(image) == MagickFalse)
@@ -1009,15 +1037,11 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
   /*
     Allocate the tables.
   */
-  red_map=(MagickRealType *)
-    AcquireMagickMemory(3*(size_t) (MaxMap+1)*sizeof(*red_map));
-  green_map=(MagickRealType *)
-    AcquireMagickMemory(3*(size_t) (MaxMap+1)*sizeof(*green_map));
-  blue_map=(MagickRealType *)
-    AcquireMagickMemory(3*(size_t) (MaxMap+1)*sizeof(*blue_map));
-  if ((red_map == (MagickRealType *) NULL) ||
-      (green_map == (MagickRealType *) NULL) ||
-      (blue_map == (MagickRealType *) NULL))
+  x_map=(PrimaryInfo *) AcquireMagickMemory((size_t) (MaxMap+1)*sizeof(*x_map));
+  y_map=(PrimaryInfo *) AcquireMagickMemory((size_t) (MaxMap+1)*sizeof(*y_map));
+  z_map=(PrimaryInfo *) AcquireMagickMemory((size_t) (MaxMap+1)*sizeof(*z_map));
+  if ((x_map == (PrimaryInfo *) NULL) || (y_map == (PrimaryInfo *) NULL) ||
+      (z_map == (PrimaryInfo *) NULL))
     ThrowBinaryException(ResourceLimitError,"MemoryAllocationFailed",
       image->filename);
   switch (colorspace)
@@ -1036,15 +1060,15 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
       */
       for (i=0; i <= (long) MaxMap; i++)
       {
-        red_map[i+R]=(MagickRealType) i;
-        green_map[i+R]=0.5*(2.0*i-MaxMap);
-        blue_map[i+R]=(-0.33334)*(2.0*i-MaxMap);
-        red_map[i+G]=(MagickRealType) i;
-        green_map[i+G]=0.0;
-        blue_map[i+G]=0.666665*(2.0*i-MaxMap);
-        red_map[i+B]=(MagickRealType) i;
-        green_map[i+B]=(-0.5)*(2.0*i-MaxMap);
-        blue_map[i+B]=(-0.33334)*(2.0*i-MaxMap);
+        x_map[i].x=(double) i;
+        x_map[i].y=(double) i;
+        x_map[i].z=(double) i;
+        y_map[i].x=0.5*(2.0*i-MaxMap);
+        y_map[i].y=0.0;
+        y_map[i].z=(-0.5)*(2.0*i-MaxMap);
+        z_map[i].x=(-0.33334)*(2.0*i-MaxMap);
+        z_map[i].y=0.666665*(2.0*i-MaxMap);
+        z_map[i].z=(-0.33334)*(2.0*i-MaxMap);
       }
       break;
     }
@@ -1061,19 +1085,19 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
       */
       for (i=0; i <= (long) MaxMap; i++)
       {
-        red_map[i+R]=1.40200*i;
-        green_map[i+R]=0.0;
-        blue_map[i+R]=1.88000*(i-(long)
-          ScaleQuantumToMap(ScaleCharToQuantum(137)));
-        red_map[i+G]=1.40200*i;
-        green_map[i+G]=(-0.444066)*(i-(long)
+        x_map[i].x=1.40200*i;
+        x_map[i].y=1.40200*i;
+        x_map[i].z=1.40200*i;
+        y_map[i].x=0.0;
+        y_map[i].y=(-0.444066)*(i-(long)
           ScaleQuantumToMap(ScaleCharToQuantum(156)));
-        blue_map[i+G]=(-0.95692)*(i-(long)
-          ScaleQuantumToMap(ScaleCharToQuantum(137)));
-        red_map[i+B]=1.40200*i;
-        green_map[i+B]=2.28900*(i-(long)
+        y_map[i].z=2.28900*(i-(long)
           ScaleQuantumToMap(ScaleCharToQuantum(156)));
-        blue_map[i+B]=0.0;
+        z_map[i].x=1.88000*(i-(long)
+          ScaleQuantumToMap(ScaleCharToQuantum(137)));
+        z_map[i].y=(-0.95692)*(i-(long)
+          ScaleQuantumToMap(ScaleCharToQuantum(137)));
+        z_map[i].z=0.0;
       }
       break;
     }
@@ -1088,15 +1112,15 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
       */
       for (i=0; i <= (long) MaxMap; i++)
       {
-        red_map[i+R]=3.240479*i;
-        green_map[i+R]=(-1.537150)*i;
-        blue_map[i+R]=(-0.498535)*i;
-        red_map[i+G]=(-0.969256)*i;
-        green_map[i+G]=1.875992*i;
-        blue_map[i+G]=0.041556*i;
-        red_map[i+B]=0.055648*i;
-        green_map[i+B]=(-0.204043)*i;
-        blue_map[i+B]=1.057311*i;
+        x_map[i].x=3.240479*i;
+        x_map[i].y=(-0.969256)*i;
+        x_map[i].z=0.055648*i;
+        y_map[i].x=(-1.537150)*i;
+        y_map[i].y=1.875992*i;
+        y_map[i].z=(-0.204043)*i;
+        z_map[i].x=(-0.498535)*i;
+        z_map[i].y=0.041556*i;
+        z_map[i].z=1.057311*i;
       }
       break;
     }
@@ -1114,15 +1138,15 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
       */
       for (i=0; i <= (long) MaxMap; i++)
       {
-        red_map[i+R]=(MagickRealType) i;
-        green_map[i+R]=0.0;
-        blue_map[i+R]=(1.402000*0.5)*(2.0*i-MaxMap);
-        red_map[i+G]=(MagickRealType) i;
-        green_map[i+G]=(-0.344136*0.5)*(2.0*i-MaxMap);
-        blue_map[i+G]=(-0.714136*0.5)*(2.0*i-MaxMap);
-        red_map[i+B]=(MagickRealType) i;
-        green_map[i+B]=(1.772000*0.5)*(2.0*i-MaxMap);
-        blue_map[i+B]=0.0;
+        x_map[i].x=(double) i;
+        x_map[i].y=(double) i;
+        x_map[i].z=(double) i;
+        y_map[i].x=0.0;
+        y_map[i].y=(-0.344136*0.5)*(2.0*i-MaxMap);
+        y_map[i].z=(1.772000*0.5)*(2.0*i-MaxMap);
+        z_map[i].x=(1.402000*0.5)*(2.0*i-MaxMap);
+        z_map[i].y=(-0.714136*0.5)*(2.0*i-MaxMap);
+        z_map[i].z=0.0;
       }
       break;
     }
@@ -1139,19 +1163,19 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
       */
       for (i=0; i <= (long) MaxMap; i++)
       {
-        red_map[i+R]=1.3584*i;
-        green_map[i+R]=0.0;
-        blue_map[i+R]=1.8215*(i-(MagickRealType)
-          ScaleQuantumToMap(ScaleCharToQuantum(137)));
-        red_map[i+G]=1.3584*i;
-        green_map[i+G]=(-0.4302726)*(i-(MagickRealType)
+        x_map[i].x=1.3584*i;
+        x_map[i].y=1.3584*i;
+        x_map[i].z=1.3584*i;
+        y_map[i].x=0.0;
+        y_map[i].y=(-0.4302726)*(i-(double)
           ScaleQuantumToMap(ScaleCharToQuantum(156)));
-        blue_map[i+G]=(-0.9271435)*(i-(MagickRealType)
-          ScaleQuantumToMap(ScaleCharToQuantum(137)));
-        red_map[i+B]=1.3584*i;
-        green_map[i+B]=2.2179*(i-(MagickRealType)
+        y_map[i].z=2.2179*(i-(double)
           ScaleQuantumToMap(ScaleCharToQuantum(156)));
-        blue_map[i+B]=0.0;
+        z_map[i].x=1.8215*(i-(double)
+          ScaleQuantumToMap(ScaleCharToQuantum(137)));
+        z_map[i].y=(-0.9271435)*(i-(double)
+          ScaleQuantumToMap(ScaleCharToQuantum(137)));
+        z_map[i].z=0.0;
       }
       break;
     }
@@ -1169,15 +1193,15 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
       */
       for (i=0; i <= (long) MaxMap; i++)
       {
-        red_map[i+R]=(MagickRealType) i;
-        green_map[i+R]=0.4781*(2.0*i-MaxMap);
-        blue_map[i+R]=0.3107*(2.0*i-MaxMap);
-        red_map[i+G]=(MagickRealType) i;
-        green_map[i+G]=(-0.13635)*(2.0*i-MaxMap);
-        blue_map[i+G]=(-0.3234)*(2.0*i-MaxMap);
-        red_map[i+B]=(MagickRealType) i;
-        green_map[i+B]=(-0.55185)*(2.0*i-MaxMap);
-        blue_map[i+B]=0.8503*(2.0*i-MaxMap);
+        x_map[i].x=(double) i;
+        x_map[i].y=(double) i;
+        x_map[i].z=(double) i;
+        y_map[i].x=0.4781*(2.0*i-MaxMap);
+        y_map[i].y=(-0.13635)*(2.0*i-MaxMap);
+        y_map[i].z=(-0.55185)*(2.0*i-MaxMap);
+        z_map[i].x=0.3107*(2.0*i-MaxMap);
+        z_map[i].y=(-0.3234)*(2.0*i-MaxMap);
+        z_map[i].z=0.8503*(2.0*i-MaxMap);
       }
       break;
     }
@@ -1195,15 +1219,15 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
       */
       for (i=0; i <= (long) MaxMap; i++)
       {
-        red_map[i+R]=(MagickRealType) i;
-        green_map[i+R]=0.0;
-        blue_map[i+R]=0.701*(2.0*i-MaxMap);
-        red_map[i+G]=(MagickRealType) i;
-        green_map[i+G]=(-0.172068)*(2.0*i-MaxMap);
-        blue_map[i+G]=0.357068*(2.0*i-MaxMap);
-        red_map[i+B]=(MagickRealType) i;
-        green_map[i+B]=0.886*(2.0*i-MaxMap);
-        blue_map[i+B]=0.0;
+        x_map[i].x=(double) i;
+        x_map[i].y=(double) i;
+        x_map[i].z=(double) i;
+        y_map[i].x=0.0;
+        y_map[i].y=(-0.172068)*(2.0*i-MaxMap);
+        y_map[i].z=0.886*(2.0*i-MaxMap);
+        z_map[i].x=0.701*(2.0*i-MaxMap);
+        z_map[i].y=0.357068*(2.0*i-MaxMap);
+        z_map[i].z=0.0;
       }
       break;
     }
@@ -1222,15 +1246,15 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
       */
       for (i=0; i <= (long) MaxMap; i++)
       {
-        red_map[i+R]=(MagickRealType) i;
-        green_map[i+R]=0.0;
-        blue_map[i+R]=0.5699*(2.0*i-MaxMap);
-        red_map[i+G]=(MagickRealType) i;
-        green_map[i+G]=(-0.1969)*(2.0*i-MaxMap);
-        blue_map[i+G]=(-0.29025)*(2.0*i-MaxMap);
-        red_map[i+B]=(MagickRealType) i;
-        green_map[i+B]=1.01395*(2.0*i-MaxMap);
-        blue_map[i+B]=0.0;
+        x_map[i].x=(double) i;
+        x_map[i].y=(double) i;
+        x_map[i].z=(double) i;
+        y_map[i].x=0.0;
+        y_map[i].y=(-0.1969)*(2.0*i-MaxMap);
+        y_map[i].z=1.01395*(2.0*i-MaxMap);
+        z_map[i].x=0.5699*(2.0*i-MaxMap);
+        z_map[i].y=(-0.29025)*(2.0*i-MaxMap);
+        z_map[i].z=0.0;
       }
       break;
     }
@@ -1257,28 +1281,28 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
           break;
         for (x=0; x < (long) image->columns; x++)
         {
-          pixel.red=red_map[ScaleQuantumToMap(q->red)+R]+
-            green_map[ScaleQuantumToMap(q->green)+R]+
-            blue_map[ScaleQuantumToMap(q->blue)+R];
-          pixel.green=red_map[ScaleQuantumToMap(q->red)+G]+
-            green_map[ScaleQuantumToMap(q->green)+G]+
-            blue_map[ScaleQuantumToMap(q->blue)+G];
-          pixel.blue=red_map[ScaleQuantumToMap(q->red)+B]+
-            green_map[ScaleQuantumToMap(q->green)+B]+
-            blue_map[ScaleQuantumToMap(q->blue)+B];
+          pixel.red=x_map[ScaleQuantumToMap(q->red)].x+
+            y_map[ScaleQuantumToMap(q->green)].x+
+            z_map[ScaleQuantumToMap(q->blue)].x;
+          pixel.green=x_map[ScaleQuantumToMap(q->red)].y+
+            y_map[ScaleQuantumToMap(q->green)].y+
+            z_map[ScaleQuantumToMap(q->blue)].y;
+          pixel.blue=x_map[ScaleQuantumToMap(q->red)].z+
+            y_map[ScaleQuantumToMap(q->green)].z+
+            z_map[ScaleQuantumToMap(q->blue)].z;
           switch (colorspace)
           {
             case sRGBColorspace:
             case YCCColorspace:
             {
               quantum.red=(unsigned long) ((pixel.red < 0.0) ? 0.0 :
-                (pixel.red > (MagickRealType) MaxYCC) ? (MagickRealType)
+                (pixel.red > (double) MaxYCC) ? (double)
                 MaxYCC : pixel.red+0.5);
               quantum.green=(unsigned long) ((pixel.green < 0.0) ? 0.0 :
-                (pixel.green > (MagickRealType) MaxYCC) ? (MagickRealType)
+                (pixel.green > (double) MaxYCC) ? (double)
                 MaxYCC : pixel.green+0.5);
               quantum.blue=(unsigned long) ((pixel.blue < 0.0) ? 0.0 :
-                (pixel.blue > (MagickRealType) MaxYCC) ? (MagickRealType)
+                (pixel.blue > (double) MaxYCC) ? (double)
                 MaxYCC : pixel.blue+0.5);
               if (colorspace == sRGBColorspace)
                 {
@@ -1331,29 +1355,29 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
       */
       for (i=0; i < (long) image->colors; i++)
       {
-        pixel.red=red_map[ScaleQuantumToMap(image->colormap[i].red)+R]+
-          green_map[ScaleQuantumToMap(image->colormap[i].green)+R]+
-          blue_map[ScaleQuantumToMap(image->colormap[i].blue)+R];
-        pixel.green=red_map[ScaleQuantumToMap(image->colormap[i].red)+G]+
-          green_map[ScaleQuantumToMap(image->colormap[i].green)+G]+
-          blue_map[ScaleQuantumToMap(image->colormap[i].blue)+G];
-        pixel.blue=red_map[ScaleQuantumToMap(image->colormap[i].red)+B]+
-          green_map[ScaleQuantumToMap(image->colormap[i].green)+B]+
-          blue_map[ScaleQuantumToMap(image->colormap[i].blue)+B];
+        pixel.red=x_map[ScaleQuantumToMap(image->colormap[i].red)].x+
+          y_map[ScaleQuantumToMap(image->colormap[i].green)].x+
+          z_map[ScaleQuantumToMap(image->colormap[i].blue)].x;
+        pixel.green=x_map[ScaleQuantumToMap(image->colormap[i].red)].y+
+          y_map[ScaleQuantumToMap(image->colormap[i].green)].y+
+          z_map[ScaleQuantumToMap(image->colormap[i].blue)].y;
+        pixel.blue=x_map[ScaleQuantumToMap(image->colormap[i].red)].z+
+          y_map[ScaleQuantumToMap(image->colormap[i].green)].z+
+          z_map[ScaleQuantumToMap(image->colormap[i].blue)].z;
         switch (colorspace)
         {
           case sRGBColorspace:
           case YCCColorspace:
           {
             quantum.red=(unsigned long) ((pixel.red < 0.0) ? 0.0 :
-              (pixel.red > (MagickRealType) MaxYCC) ? (MagickRealType)
-              MaxYCC : pixel.red+0.5);
+              (pixel.red > (double) MaxYCC) ? (double) MaxYCC :
+              pixel.red+0.5);
             quantum.green=(unsigned long) ((pixel.green < 0.0) ? 0.0 :
-              (pixel.green > (MagickRealType) MaxYCC) ? (MagickRealType)
-              MaxYCC : pixel.green+0.5);
+              (pixel.green > (double) MaxYCC) ? (double) MaxYCC :
+              pixel.green+0.5);
             quantum.blue=(unsigned long) ((pixel.blue < 0.0) ? 0.0 :
-              (pixel.blue > (MagickRealType) MaxYCC) ? (MagickRealType)
-              MaxYCC : pixel.blue+0.5);
+              (pixel.blue > (double) MaxYCC) ? (double) MaxYCC :
+              pixel.blue+0.5);
             if (colorspace == sRGBColorspace)
               {
                 image->colormap[i].red=(Quantum)
@@ -1392,8 +1416,8 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
   /*
     Free resources.
   */
-  blue_map=(MagickRealType *) RelinquishMagickMemory(blue_map);
-  green_map=(MagickRealType *) RelinquishMagickMemory(green_map);
-  red_map=(MagickRealType *) RelinquishMagickMemory(red_map);
+  z_map=(PrimaryInfo *) RelinquishMagickMemory(z_map);
+  y_map=(PrimaryInfo *) RelinquishMagickMemory(y_map);
+  x_map=(PrimaryInfo *) RelinquishMagickMemory(x_map);
   return(MagickTrue);
 }
