@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -58,6 +58,7 @@
 #include "magick/mogrify.h"
 #include "magick/mogrify-private.h"
 #include "magick/option.h"
+#include "magick/pixel-private.h"
 #include "magick/resource_.h"
 #include "magick/string_.h"
 #include "magick/utility.h"
@@ -291,9 +292,12 @@ static void CompareUsage(void)
       "-monitor             monitor progress",
       "-profile filename    add, delete, or apply an image profile",
       "-quality value       JPEG/MIFF/PNG compression level",
+      "-quiet               suppress all error or warning messages",
       "-sampling-factor geometry",
       "                     horizontal and vertical sampling factor",
+      "-set attribute value set an image attribute",
       "-size geometry       width and height of image",
+      "-type type           image type",
       "-verbose             print detailed information about the image",
       "-version             print version information",
       "-virtual-pixel method",
@@ -701,6 +705,8 @@ MagickExport MagickBooleanType CompareImageCommand(ImageInfo *image_info,
               ThrowCompareInvalidArgumentException(option,argv[i]);
             break;
           }
+        if (LocaleCompare("quiet",option+1) == 0)
+          break;
         ThrowCompareException(OptionError,"UnrecognizedOption",option)
       }
       case 's':
@@ -716,6 +722,18 @@ MagickExport MagickBooleanType CompareImageCommand(ImageInfo *image_info,
               ThrowCompareInvalidArgumentException(option,argv[i]);
             break;
           }
+        if (LocaleCompare("set",option+1) == 0)
+          {
+            i++;
+            if (i == (long) argc)
+              ThrowCompareException(OptionError,"MissingArgument",option);
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) argc)
+              ThrowCompareException(OptionError,"MissingArgument",option);
+            break;
+          }
         if (LocaleCompare("size",option+1) == 0)
           {
             if (*option == '+')
@@ -729,6 +747,26 @@ MagickExport MagickBooleanType CompareImageCommand(ImageInfo *image_info,
           }
         ThrowCompareException(OptionError,"UnrecognizedOption",option)
       }
+      case 't':
+      {
+        if (LocaleCompare("type",option+1) == 0)
+          {
+            long
+              type;
+
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) argc)
+              ThrowCompareException(OptionError,"MissingArgument",option);
+            type=ParseMagickOption(MagickImageOptions,MagickFalse,argv[i]);
+            if (type < 0)
+              ThrowCompareException(OptionError,"UnrecognizedImageType",
+                argv[i]);
+            break;
+          }
+        ThrowCompareException(OptionError,"UnrecognizedOption",option)
+      }
       case 'v':
       {
         if (LocaleCompare("verbose",option+1) == 0)
@@ -779,9 +817,9 @@ MagickExport MagickBooleanType CompareImageCommand(ImageInfo *image_info,
     metric,&distortion,exception);
   if (difference_image != (Image *) NULL)
     {
+      GetImageException(difference_image,exception);
       if (image_info->verbose != MagickFalse)
         (void) IsImagesEqual(image,reconstruct_image);
-      difference_image->error=image->error;
       status&=WriteImages(image_info,difference_image,argv[argc-1],exception);
       difference_image=DestroyImageList(difference_image);
     }
