@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -1102,6 +1102,81 @@ MagickExport MagickBooleanType JPEGEncodeImage(const ImageInfo *image_info,
 }
 #endif
 
+#if defined(HasJP2)
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%   J P 2 E n c o d e I m a g e                                               %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  JP2EncodeImage() compresses an image via JPEG-2000 compression.
+%
+%  The format of the JP2EncodeImage method is:
+%
+%      MagickBooleanType JP2EncodeImage(const ImageInfo *image_info,
+%        Image *image)
+%
+%  A description of each parameter follows:
+%
+%    o image_info: The image info..
+%
+%    o image: The image.
+%
+*/
+MagickExport MagickBooleanType JP2EncodeImage(const ImageInfo *image_info,
+  Image *image)
+{
+  Image
+    *jp2_image;
+
+  ImageInfo
+    *jp2_info;
+
+  size_t
+    length;
+
+  unsigned char
+    *blob;
+
+  /*
+    Write image as JP2 image to a temporary file.
+  */
+  jp2_image=CloneImage(image,0,0,MagickTrue,&image->exception);
+  if (jp2_image == (Image *) NULL)
+    ThrowWriterException(CoderError,image->exception.reason);
+  DestroyBlob(jp2_image);
+  jp2_image->blob=CloneBlobInfo((BlobInfo *) NULL);
+  jp2_info=CloneImageInfo(image_info);
+  *jp2_info->filename='\0';
+  (void) strcpy(jp2_info->magick,"JP2");
+  length=0;
+  blob=ImageToBlob(jp2_info,jp2_image,&length,&image->exception);
+  jp2_info=DestroyImageInfo(jp2_info);
+  if (blob == (void *) NULL)
+    ThrowWriterException(CoderError,image->exception.reason);
+  (void) WriteBlob(image,length,blob);
+  jp2_image=DestroyImage(jp2_image);
+  blob=(unsigned char *) RelinquishMagickMemory(blob);
+  return(MagickTrue);
+}
+#else
+MagickExport MagickBooleanType JP2EncodeImage(const ImageInfo *image_info,
+  Image *image)
+{
+  assert(image != (Image *) NULL);
+  assert(image->signature == MagickSignature);
+  if (image->debug != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image->filename);
+  ThrowBinaryException(MissingDelegateError,"JP2LibraryIsNotAvailable",
+    image->filename);
+}
+#endif
+
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %                                                                             %
