@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -61,6 +61,7 @@
 #include "magick/semaphore.h"
 #include "magick/stream.h"
 #include "magick/string_.h"
+#include "magick/timer.h"
 #include "magick/utility.h"
 
 static SemaphoreInfo
@@ -148,7 +149,7 @@ MagickExport Image *ConstituteImage(const unsigned long columns,
     ThrowImageException(OptionError,"NonZeroWidthAndHeightRequired");
   image->columns=columns;
   image->rows=rows;
-  SetImage(image,OpaqueOpacity);
+  SetImageBackgroundColor(image);
   status=ImportImagePixels(image,0,0,columns,rows,map,storage,pixels);
   if (status == MagickFalse)
     {
@@ -246,6 +247,7 @@ MagickExport Image *PingImage(const ImageInfo *image_info,
   ping_info->ping=MagickTrue;
   image=ReadStream(ping_info,&PingStream,exception);
   ping_info=DestroyImageInfo(ping_info);
+  ResetTimer(&image->timer);
   if ((image != (Image *) NULL) && (image_info->verbose != MagickFalse))
     (void) IdentifyImage(image,stdout,MagickFalse);
   return(image);
@@ -458,65 +460,18 @@ MagickExport Image *ReadImage(const ImageInfo *image_info,
   if ((image->next != (Image *) NULL) &&
       (IsSceneGeometry(read_info->scenes,MagickFalse) != MagickFalse))
     {
-      char
-        *q;
-
       Image
-        *read_image,
-        *scenes;
+        *clones;
 
-      long
-        quantum;
-
-      register char
-        *p;
-
-      register long
-        i;
-
-      unsigned long
-        first,
-        last;
-
-      /*
-        User specified scenes (e.g. image.miff[1,3-5,7-6,2]).
-      */
-      scenes=NewImageList();
-      p=read_info->scenes;
-      for (q=p; *q != '\0'; p++)
-      {
-        while ((isspace((int) ((unsigned char) *p)) != 0) || (*p == ','))
-          p++;
-        first=strtoul(p,&q,10);
-        last=first;
-        while (isspace((int) ((unsigned char) *q)) != 0)
-          q++;
-        if (*q == '-')
-          last=strtoul(q+1,&q,10);
-        quantum=first > last ? -1 : 1;
-        for (p=q; first != (last+quantum); first+=quantum)
-        {
-          i=0;
-          for (next=image; next != (Image *) NULL; next=next->next)
-          {
-            if (next->scene != 0)
-              i=(long) next->scene;
-            if (i == (long) first)
-              {
-                read_image=CloneImage(next,0,0,MagickTrue,exception);
-                if (read_image == (Image *) NULL)
-                  break;
-                AppendImageToList(&scenes,read_image);
-              }
-            i++;
-          }
-        }
-      }
-      if (scenes != (Image *) NULL)
-        image=GetFirstImageInList(scenes);
-      else
+      clones=CloneImages(image,read_info->scenes,exception);
+      if (clones == (Image *) NULL)
         (void) ThrowMagickException(exception,GetMagickModule(),OptionError,
           "SubimageSpecificationReturnsNoImages","`%s'",read_info->filename);
+      else
+        {
+          image=DestroyImageList(image);
+          image=GetFirstImageInList(clones);
+        }
     }
   if (GetBlobError(image) != MagickFalse)
     {
@@ -543,7 +498,7 @@ MagickExport Image *ReadImage(const ImageInfo *image_info,
         (void) ParseGeometry(attribute->value,&geometry_info);
         if (geometry_info.sigma != 0)
           next->x_resolution=geometry_info.rho/geometry_info.sigma;
-        (void) SetImageAttribute(next,"EXIF:XResolution",(char *) NULL);
+        (void) DeleteImageAttribute(next,"EXIF:XResolution");
       }
     attribute=GetImageAttribute(next,"EXIF:YResolution");
     if ((attribute != (const ImageAttribute *) NULL) &&
@@ -554,7 +509,7 @@ MagickExport Image *ReadImage(const ImageInfo *image_info,
         (void) ParseGeometry(attribute->value,&geometry_info);
         if (geometry_info.sigma != 0)
           next->y_resolution=geometry_info.rho/geometry_info.sigma;
-        (void) SetImageAttribute(next,"EXIF:YResolution",(char *) NULL);
+        (void) DeleteImageAttribute(next,"EXIF:YResolution");
       }
     attribute=GetImageAttribute(next,"EXIF:ResolutionUnit");
     if ((attribute != (const ImageAttribute *) NULL) &&
@@ -566,7 +521,7 @@ MagickExport Image *ReadImage(const ImageInfo *image_info,
           case 3: next->units=PixelsPerCentimeterResolution; break;
           default: next->units=UndefinedResolution; break;
         }
-        (void) SetImageAttribute(next,"EXIF:ResolutionUnit",(char *) NULL);
+        (void) DeleteImageAttribute(next,"EXIF:ResolutionUnit");
       }
     page=GetImageOption(image_info,"page");
     if ((page != (char *) NULL) && (LocaleCompare(next->magick,"TEXT") != 0))
@@ -606,14 +561,14 @@ MagickExport Image *ReadImage(const ImageInfo *image_info,
     comment=GetImageOption(image_info,"Comment");
     if (comment != (char *) NULL)
       {
-        (void) SetImageAttribute(next,"Comment",(char *) NULL);
+        (void) DeleteImageAttribute(next,"Comment");
         (void) SetImageAttribute(next,"Comment",comment);
       }
-    label=GetImageOption(image_info,"label");
+    label=GetImageOption(image_info,"Label");
     if (label != (char *) NULL)
       {
-        (void) SetImageAttribute(next,"label",(char *) NULL);
-        (void) SetImageAttribute(next,"label",label);
+        (void) DeleteImageAttribute(next,"Label");
+        (void) SetImageAttribute(next,"Label",label);
       }
     if (next->magick_columns == 0)
       next->magick_columns=next->columns;
@@ -826,15 +781,17 @@ MagickExport Image *ReadInlineImage(const ImageInfo *image_info,
 %
 */
 
-static void SyncImageInfo(const ImageInfo *image_info,Image *image)
+static void SyncImageInfo(const ImageInfo *image_info,Image *image,
+  ExceptionInfo *exception)
 {
+  const MagickInfo
+    *magick_info;
+
   (void) CopyMagickString(image->filename,image_info->filename,MaxTextExtent);
   if (image_info->extract != (char *) NULL)
     (void) ParseAbsoluteGeometry(image_info->extract,&image->extract_info);
   if (image_info->depth != 0)
     image->depth=image_info->depth;
-  if (image_info->endian != UndefinedEndian)
-    image->endian=image_info->endian;
   if (image_info->compression != UndefinedCompression)
     image->compression=image_info->compression;
   if (image_info->quality != UndefinedCompressionQuality)
@@ -843,6 +800,12 @@ static void SyncImageInfo(const ImageInfo *image_info,Image *image)
     image->interlace=image_info->interlace;
   if (image_info->orientation != UndefinedOrientation)
     image->orientation=image_info->orientation;
+  if (image_info->endian != UndefinedEndian)
+    image->endian=image_info->endian;
+  magick_info=GetMagickInfo(image_info->magick,exception);
+  if ((magick_info == (const MagickInfo *) NULL) ||
+      (GetMagickEndianSupport(magick_info) == MagickFalse))
+    image->endian=UndefinedEndian;
 }
 
 MagickExport MagickBooleanType WriteImage(const ImageInfo *image_info,
@@ -895,7 +858,7 @@ MagickExport MagickBooleanType WriteImage(const ImageInfo *image_info,
       (void) SetImageInfo(write_info,MagickTrue,&sans_exception);
     }
   (void) CopyMagickString(filename,image->filename,MaxTextExtent);
-  SyncImageInfo(write_info,image);
+  SyncImageInfo(write_info,image,&sans_exception);
   if ((image->next == (Image *) NULL) && (image->previous == (Image *) NULL) &&
       (write_info->page == (char *) NULL) &&
       (IsTaintImage(image) == MagickFalse))
