@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -197,7 +197,7 @@ static void ConvertUsage(void)
       "-contrast            enhance or reduce the image contrast",
       "-convolve coefficients",
       "                     apply a convolution kernel to the image",
-      "-crop geometry       preferred size and location of the cropped image",
+      "-crop geometry       crop the image",
       "-cycle amount        cycle the image colormap",
       "-debug events        display copious debugging information",
       "-define format:option",
@@ -240,6 +240,7 @@ static void ConvertUsage(void)
       "-green-primary point chromaticity green primary point",
       "-gravity type        horizontal and vertical text placement",
       "-help                print program options",
+      "-identify            describe the format and characteristics of the image",
       "-implode amount      implode image pixels about the center",
       "-insert index        insert last image into the image sequence",
       "-intent type         type of rendering intent when managing the image color",
@@ -275,6 +276,7 @@ static void ConvertUsage(void)
       "-preview type        image preview type",
       "-profile filename    add, delete, or apply an image profile",
       "-quality value       JPEG/MIFF/PNG compression level",
+      "-quiet               suppress all error or warning messages",
       "-radial-blur angle   radial blur the image",
       "-raise value         lighten/darken image edges to create a 3-D effect",
       "-random-threshold low,high",
@@ -298,11 +300,14 @@ static void ConvertUsage(void)
       "-separate            separate an image channel into a grayscale image",
       "-sepia-tone threshold",
       "                     simulate a sepia-toned photo",
+      "-set attribute value set an image attribute",
       "-shade degrees       shade the image using a distant light source",
       "-shadow geometry     simulate an image shadow",
       "-sharpen geometry    sharpen the image",
       "-shave geometry      shave pixels from the image edges",
       "-shear geometry      slide one edge of the image along the X or Y axis",
+      "-sigmodial-contrast geometry",
+      "                     lightness rescaling using sigmoidal contrast enhancement",
       "-size geometry       width and height of image",
       "-solarize threshold  negate all pixels above the threshold level",
       "-splice geometry     splice the background color into the image",
@@ -405,8 +410,7 @@ MagickExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
     k;
 
   MagickBooleanType
-    pend,
-    ping;
+    pend;
 
   MagickStatusType
     status;
@@ -431,7 +435,6 @@ MagickExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
   image_stack[k]=NewImageList();
   option=(char *) NULL;
   pend=MagickFalse;
-  ping=MagickFalse;
   status=MagickTrue;
   /*
     Parse command-line arguments.
@@ -481,7 +484,7 @@ MagickExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
         MogrifyImageStack(image_stack[k],MagickTrue,pend);
         filename=argv[i];
         (void) CopyMagickString(image_info->filename,filename,MaxTextExtent);
-        if (ping != MagickFalse)
+        if (image_info->ping != MagickFalse)
           image=PingImage(image_info,exception);
         else
           image=ReadImage(image_info,exception);
@@ -691,33 +694,28 @@ MagickExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
         if (LocaleCompare("clone",option+1) == 0)
           {
             Image
-              *clone_image;
+              *clone_images;
 
-            long
-              index;
-
-            index=(-1);
-            if (*option == '-')
+            clone_images=image_stack[k];
+            if (k != 0)
+              clone_images=image_stack[k-1];
+            if (clone_images == (Image *) NULL)
+              ThrowConvertException(ImageError,"ImageSequenceRequired",option);
+            if (*option == '+')
+              clone_images=CloneImages(clone_images,"-1",exception);
+            else
               {
                 i++;
                 if (i == (long) (argc-1))
                   ThrowConvertException(OptionError,"MissingArgument",option);
-                if (IsGeometry(argv[i]) == MagickFalse)
+                if (IsSceneGeometry(argv[i],MagickFalse) == MagickFalse)
                   ThrowConvertInvalidArgumentException(option,argv[i]);
-                index=atol(argv[i]);
+                clone_images=CloneImages(clone_images,argv[i],exception);
               }
-            if (k == 0)
-              ThrowConvertException(ImageError,"ImageSequenceRequired",option);
-            clone_image=GetImageFromList(image_stack[k-1],index);
-            if (clone_image == (Image *) NULL)
-              ThrowConvertException(ImageError,"NoSuchImage",option);
-            clone_image=CloneImage(clone_image,0,0,MagickTrue,
-              &image_stack[k-1]->exception);
-            if (clone_image == (Image *) NULL)
-              ThrowConvertException(ResourceLimitError,
-                "MemoryAllocationFailed",strerror(errno));
+            if (clone_images == (Image *) NULL)
+              ThrowConvertException(OptionError,"NoSuchImage",option);
             MogrifyImageStack(image_stack[k],MagickTrue,MagickTrue);
-            AppendImageToList(&image_stack[k],clone_image);
+            AppendImageToList(&image_stack[k],clone_images);
             break;
           }
         if (LocaleCompare("coalesce",option+1) == 0)
@@ -1232,6 +1230,8 @@ MagickExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
       }
       case 'i':
       {
+        if (LocaleCompare("identify",option+1) == 0)
+          break;
         if (LocaleCompare("implode",option+1) == 0)
           {
             if (*option == '+')
@@ -1561,10 +1561,7 @@ MagickExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
             break;
           }
         if (LocaleCompare("ping",option+1) == 0)
-          {
-            ping=(MagickBooleanType) (*option == '-');
-            break;
-          }
+          break;
         if (LocaleCompare("pointsize",option+1) == 0)
           {
             if (*option == '+')
@@ -1635,6 +1632,8 @@ MagickExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
               ThrowConvertInvalidArgumentException(option,argv[i]);
             break;
           }
+        if (LocaleCompare("quiet",option+1) == 0)
+          break;
         ThrowConvertException(OptionError,"UnrecognizedOption",option)
       }
       case 'r':
@@ -1833,6 +1832,18 @@ MagickExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
               ThrowConvertInvalidArgumentException(option,argv[i]);
             break;
           }
+        if (LocaleCompare("set",option+1) == 0)
+          {
+            i++;
+            if (i == (long) argc)
+              ThrowConvertException(OptionError,"MissingArgument",option);
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) argc)
+              ThrowConvertException(OptionError,"MissingArgument",option);
+            break;
+          }
         if (LocaleCompare("shade",option+1) == 0)
           {
             i++;
@@ -1882,6 +1893,15 @@ MagickExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
               ThrowConvertInvalidArgumentException(option,argv[i]);
             break;
           }
+        if (LocaleCompare("sigmoidal-contrast",option+1) == 0)
+          {
+            i++;
+            if (i == (long) (argc-1))
+              ThrowConvertException(OptionError,"MissingArgument",option);
+            if (IsGeometry(argv[i]) == MagickFalse)
+              ThrowConvertInvalidArgumentException(option,argv[i]);
+            break;
+          }
         if (LocaleCompare("size",option+1) == 0)
           {
             if (*option == '+')
@@ -2249,7 +2269,7 @@ MagickExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
   if (k != 0)
     ThrowConvertException(OptionError,"UnbalancedParenthesis",argv[i]);
   if (i != (long) (argc-1))
-    ThrowConvertException(OptionError,"MissingAnImageFilename",argv[i]);
+    ThrowConvertException(OptionError,"MissingAnImageFilename",argv[argc-1]);
   if (image_stack[k] == (Image *) NULL)
     ThrowConvertException(OptionError,"MissingAnImageFilename",argv[argc-1]);
   MogrifyImageStack(image_stack[k],MagickTrue,MagickTrue);
