@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -50,6 +50,7 @@
 #include "magick/image.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
+#include "magick/pixel-private.h"
 
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -215,15 +216,15 @@ MagickExport Image *FrameImage(const Image *image,const FrameInfo *frame_info,
   /*
     Initialize 3D effects color.
   */
-  GetMagickPixelPacket(image,&interior);
-  interior.opacity=TransparentOpacity;
-  GetMagickPixelPacket(image,&matte);
+  GetMagickPixelPacket(frame_image,&interior);
+  SetMagickPixelPacket(&image->border_color,(IndexPacket *) NULL,&interior);
+  GetMagickPixelPacket(frame_image,&matte);
   matte.colorspace=RGBColorspace;
   SetMagickPixelPacket(&image->matte_color,(IndexPacket *) NULL,&matte);
-  GetMagickPixelPacket(image,&border);
+  GetMagickPixelPacket(frame_image,&border);
   border.colorspace=RGBColorspace;
   SetMagickPixelPacket(&image->border_color,(IndexPacket *) NULL,&border);
-  GetMagickPixelPacket(image,&accentuate);
+  GetMagickPixelPacket(frame_image,&accentuate);
   accentuate.red=QuantumScale*((MaxRGB-AccentuateModulate)*matte.red+
     (MaxRGB*AccentuateModulate));
   accentuate.green=QuantumScale*((MaxRGB-AccentuateModulate)*matte.green+
@@ -231,7 +232,7 @@ MagickExport Image *FrameImage(const Image *image,const FrameInfo *frame_info,
   accentuate.blue=QuantumScale*((MaxRGB-AccentuateModulate)*matte.blue+
     (MaxRGB*AccentuateModulate));
   accentuate.opacity=matte.opacity;
-  GetMagickPixelPacket(image,&highlight);
+  GetMagickPixelPacket(frame_image,&highlight);
   highlight.red=QuantumScale*((MaxRGB-HighlightModulate)*matte.red+
     (MaxRGB*HighlightModulate));
   highlight.green=QuantumScale*((MaxRGB-HighlightModulate)*matte.green+
@@ -239,12 +240,12 @@ MagickExport Image *FrameImage(const Image *image,const FrameInfo *frame_info,
   highlight.blue=QuantumScale*((MaxRGB-HighlightModulate)*matte.blue+
     (MaxRGB*HighlightModulate));
   highlight.opacity=matte.opacity;
-  GetMagickPixelPacket(image,&shadow);
+  GetMagickPixelPacket(frame_image,&shadow);
   shadow.red=QuantumScale*matte.red*ShadowModulate;
   shadow.green=QuantumScale*matte.green*ShadowModulate;
   shadow.blue=QuantumScale*matte.blue*ShadowModulate;
   shadow.opacity=matte.opacity;
-  GetMagickPixelPacket(image,&trough);
+  GetMagickPixelPacket(frame_image,&trough);
   trough.red=QuantumScale*matte.red*TroughModulate;
   trough.green=QuantumScale*matte.green*TroughModulate;
   trough.blue=QuantumScale*matte.blue*TroughModulate;
