@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -67,6 +67,7 @@
 #include "magick/resource_.h"
 #include "magick/semaphore.h"
 #include "magick/segment.h"
+#include "magick/splay-tree.h"
 #include "magick/string_.h"
 #include "magick/utility.h"
 
@@ -1904,6 +1905,99 @@ MagickExport void SetCacheThreshold(const unsigned long size)
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %                                                                             %
 %                                                                             %
+%   S e t I m a g e                                                           %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  SetImage() sets the red, green, and blue components of each pixel to
+%  the image background color and the opacity component to the specified
+%  level of transparency.  The background color is defined by the
+%  background_color member of the image.
+%
+%  The format of the SetImage method is:
+%
+%      void SetImage(Image *image,const Quantum opacity)
+%
+%  A description of each parameter follows:
+%
+%    o image: The image.
+%
+%    o opacity: Set each pixel to this level of transparency.
+%
+%
+*/
+MagickExport void SetImage(Image *image,const Quantum opacity)
+{
+  long
+    y;
+
+  PixelPacket
+    background_color;
+
+  register IndexPacket
+    *indexes;
+
+  register long
+    x;
+
+  register PixelPacket
+    *q;
+
+  (void) LogMagickEvent(DeprecateEvent,GetMagickModule(),"last use: v6.2.0");
+  assert(image != (Image *) NULL);
+  if (image->debug != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
+  assert(image->signature == MagickSignature);
+  background_color=image->background_color;
+  if (opacity != OpaqueOpacity)
+    background_color.opacity=opacity;
+  if (background_color.opacity != OpaqueOpacity)
+    {
+      image->storage_class=DirectClass;
+      image->matte=MagickTrue;
+    }
+  if ((image->storage_class == PseudoClass) ||
+      (image->colorspace == CMYKColorspace))
+    {
+      /*
+        Set colormapped or CMYK image.
+      */
+      for (y=0; y < (long) image->rows; y++)
+      {
+        q=SetImagePixels(image,0,y,image->columns,1);
+        if (q == (PixelPacket *) NULL)
+          break;
+        for (x=(long) image->columns-1; x >= 0; x--)
+          *q++=background_color;
+        indexes=GetIndexes(image);
+        for (x=0; x < (long) image->columns; x++)
+          indexes[x]=0;
+        if (SyncImagePixels(image) == MagickFalse)
+          break;
+      }
+      return;
+    }
+  /*
+    Set DirectClass image.
+  */
+  for (y=0; y < (long) image->rows; y++)
+  {
+    q=SetImagePixels(image,0,y,image->columns,1);
+    if (q == (PixelPacket *) NULL)
+      break;
+    for (x=(long) image->columns-1; x >= 0; x--)
+      *q++=background_color;
+    if (SyncImagePixels(image) == MagickFalse)
+      break;
+  }
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
 %                                                                             %
 %   S e t I m a g e L i s t                                                   %
 %                                                                             %
