@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -1408,8 +1408,8 @@ static MagickRealType FxGetSymbol(FxInfo *fx,const char *expression)
             luminosity,
             saturation;
 
-          TransformHSB(color.red,color.green,color.blue,&hue,&saturation,
-            &luminosity);
+          TransformHSB(RoundToQuantum(color.red),RoundToQuantum(color.green),
+            RoundToQuantum(color.blue),&hue,&saturation,&luminosity);
           return(luminosity);
         }
       break;
@@ -2208,14 +2208,14 @@ MagickExport Image *SepiaToneImage(const Image *image,const double threshold,
     *sepia_image;
 
   long
-    tone,
     y;
 
   MagickBooleanType
     status;
 
-  Quantum
-    intensity;
+  MagickRealType
+    intensity,
+    tone;
 
   register const PixelPacket
     *p;
@@ -2250,19 +2250,20 @@ MagickExport Image *SepiaToneImage(const Image *image,const double threshold,
       break;
     for (x=(long) image->columns-1; x >= 0; x--)
     {
-      intensity=(long) PixelIntensityToQuantum(p);
-      tone=intensity > threshold ? MaxRGB : intensity+MaxRGB-threshold;
+      intensity=(MagickRealType) PixelIntensityToQuantum(p);
+      tone=intensity > threshold ? (MagickRealType) MaxRGB :
+        intensity+MaxRGB-threshold;
       q->red=RoundToQuantum(tone);
-      tone=intensity > (7.0*threshold/6.0) ? MaxRGB : intensity+MaxRGB-
-        7.0*threshold/6.0;
+      tone=intensity > (7.0*threshold/6.0) ? (MagickRealType) MaxRGB :
+        intensity+MaxRGB-7.0*threshold/6.0;
       q->green=RoundToQuantum(tone);
       tone=intensity < (threshold/6.0) ? 0 : intensity-threshold/6.0;
       q->blue=RoundToQuantum(tone);
       tone=threshold/7.0;
-      if (q->green < tone)
-        q->green=tone;
-      if (q->blue < tone)
-        q->blue=tone;
+      if ((MagickRealType) q->green < tone)
+        q->green=RoundToQuantum(tone);
+      if ((MagickRealType) q->blue < tone)
+        q->blue=RoundToQuantum(tone);
       p++;
       q++;
     }
@@ -2408,7 +2409,8 @@ MagickExport Image *ShadowImage(const Image *image,const double opacity,
 %
 %
 */
-MagickExport MagickBooleanType SolarizeImage(Image *image,const double threshold)
+MagickExport MagickBooleanType SolarizeImage(Image *image,
+  const double threshold)
 {
 #define SolarizeImageTag  "Solarize/Image"
 
@@ -2429,46 +2431,10 @@ MagickExport MagickBooleanType SolarizeImage(Image *image,const double threshold
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),image->filename);
-  switch (image->storage_class)
-  {
-    case DirectClass:
-    default:
+  if (image->storage_class == PseudoClass)
     {
       /*
-        Solarize DirectClass packets.
-      */
-      for (y=0; y < (long) image->rows; y++)
-      {
-        q=GetImagePixels(image,0,y,image->columns,1);
-        if (q == (PixelPacket *) NULL)
-          break;
-        for (x=0; x < (long) image->columns; x++)
-        {
-          q->red=(Quantum) ((MagickRealType) q->red > threshold ?
-            MaxRGB-q->red : q->red);
-          q->green=(Quantum) ((MagickRealType) q->green > threshold ?
-            MaxRGB-q->green : q->green);
-          q->blue=(Quantum) ((MagickRealType) q->blue > threshold ?
-            MaxRGB-q->blue : q->blue);
-          q++;
-        }
-        if (SyncImagePixels(image) == MagickFalse)
-          break;
-        if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-            (QuantumTick(y,image->rows) != MagickFalse))
-          {
-            status=image->progress_monitor(SolarizeImageTag,y,image->rows,
-              image->client_data);
-            if (status == MagickFalse)
-              break;
-          }
-      }
-      break;
-    }
-    case PseudoClass:
-    {
-      /*
-        Solarize PseudoClass packets.
+        Solarize colormap.
       */
       for (i=0; i < (long) image->colors; i++)
       {
@@ -2482,9 +2448,35 @@ MagickExport MagickBooleanType SolarizeImage(Image *image,const double threshold
           image->colormap[i].blue > threshold ? MaxRGB-
           image->colormap[i].blue : image->colormap[i].blue);
       }
-      (void) SyncImage(image);
-      break;
     }
+  /*
+    Solarize image.
+  */
+  for (y=0; y < (long) image->rows; y++)
+  {
+    q=GetImagePixels(image,0,y,image->columns,1);
+    if (q == (PixelPacket *) NULL)
+      break;
+    for (x=0; x < (long) image->columns; x++)
+    {
+      q->red=(Quantum) ((MagickRealType) q->red > threshold ?
+        MaxRGB-q->red : q->red);
+      q->green=(Quantum) ((MagickRealType) q->green > threshold ?
+        MaxRGB-q->green : q->green);
+      q->blue=(Quantum) ((MagickRealType) q->blue > threshold ?
+        MaxRGB-q->blue : q->blue);
+      q++;
+    }
+    if (SyncImagePixels(image) == MagickFalse)
+      break;
+    if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
+        (QuantumTick(y,image->rows) != MagickFalse))
+      {
+        status=image->progress_monitor(SolarizeImageTag,y,image->rows,
+          image->client_data);
+        if (status == MagickFalse)
+          break;
+      }
   }
   return(MagickTrue);
 }
