@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -187,7 +187,7 @@ MagickExport MagickStatusType GetGeometry(const char *geometry,long *x,long *y,
       if (LocaleNCompare(p,"0x",2) == 0)
         *width=(unsigned long) strtol(p,&p,10);
       else
-        *width=(unsigned long) (strtod(p,&p)+0.5);
+        *width=(unsigned long) floor(strtod(p,&p)+0.5);
       if (p != q)
         flags|=WidthValue;
     }
@@ -200,7 +200,7 @@ MagickExport MagickStatusType GetGeometry(const char *geometry,long *x,long *y,
             Parse height.
           */
           q=p;
-          *height=(unsigned long) (strtod(p,&p)+0.5);
+          *height=(unsigned long) floor(strtod(p,&p)+0.5);
           if (p != q)
             flags|=HeightValue;
         }
@@ -213,7 +213,7 @@ MagickExport MagickStatusType GetGeometry(const char *geometry,long *x,long *y,
       if (*p == '-')
         flags|=XNegative;
       q=p;
-      *x=(long) (strtod(p,&p)+0.5);
+      *x=(long) ceil(strtod(p,&p)-0.5);
       if (p != q)
         flags|=XValue;
       if ((*p == '+') || (*p == '-'))
@@ -224,7 +224,7 @@ MagickExport MagickStatusType GetGeometry(const char *geometry,long *x,long *y,
           if (*p == '-')
             flags|=YNegative;
           q=p;
-          *y=(long) (strtod(p,&p)+0.5);
+          *y=(long) ceil(strtod(p,&p)-0.5);
           if (p != q)
             flags|=YValue;
         }
