@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -79,7 +79,7 @@
 #include "magick/random_.h"
 #include "magick/resize.h"
 #include "magick/resource_.h"
-#include "magick/splay-tree.h"
+#include "magick/statistic.h"
 #include "magick/string_.h"
 #include "magick/timer.h"
 #include "magick/utility.h"
@@ -123,6 +123,9 @@ MagickExport MagickBooleanType IdentifyImage(Image *image,FILE *file,
     format[MaxTextExtent],
     key[MaxTextExtent];
 
+  ChannelStatistics
+    *channel_statistics;
+
   ColorspaceType
     colorspace;
 
@@ -134,8 +137,6 @@ MagickExport MagickBooleanType IdentifyImage(Image *image,FILE *file,
 
   double
     elapsed_time,
-    mean,
-    standard_deviation,
     user_time;
 
   Image
@@ -150,9 +151,6 @@ MagickExport MagickBooleanType IdentifyImage(Image *image,FILE *file,
 
   unsigned long
     count,
-    depth,
-    maxima,
-    minima,
     scale;
 
   assert(image != (Image *) NULL);
@@ -163,7 +161,7 @@ MagickExport MagickBooleanType IdentifyImage(Image *image,FILE *file,
   *format='\0';
   elapsed_time=GetElapsedTime(&image->timer);
   user_time=GetUserTime(&image->timer);
-  (void) ContinueTimer(&image->timer);
+  GetTimerInfo(&image->timer);
   if (verbose == MagickFalse)
     {
       /*
@@ -215,8 +213,10 @@ MagickExport MagickBooleanType IdentifyImage(Image *image,FILE *file,
           FormatSize(GetBlobSize(image),format);
           (void) fprintf(file,"%s ",format);
         }
-      (void) fprintf(file,"%0.3fu %ld:%02ld\n",user_time,
-        (long) (elapsed_time/60.0+0.5),(long) ceil(fmod(elapsed_time,60.0)));
+      if (elapsed_time > 0.02)
+        (void) fprintf(file,"%0.3fu %ld:%02ld",user_time,
+          (long) (elapsed_time/60.0+0.5),(long) ceil(fmod(elapsed_time,60.0)));
+      (void) fprintf(file,"\n");
       (void) fflush(file);
       return(ferror(file) != 0 ? MagickFalse : MagickTrue);
     }
@@ -253,191 +253,160 @@ MagickExport MagickBooleanType IdentifyImage(Image *image,FILE *file,
     colorspace=GRAYColorspace;
   (void) fprintf(file,"  Colorspace: %s\n",
     MagickOptionToMnemonic(MagickColorspaceOptions,(long) colorspace));
-  depth=GetImageDepth(image,&image->exception);
-  (void) fprintf(file,"  Depth: %lu bits\n",depth);
+  channel_statistics=GetImageChannelStatistics(image,&image->exception);
   (void) fprintf(file,"  Channel depth:\n");
   switch (colorspace)
   {
     case RGBColorspace:
     default:
     {
-      depth=GetImageChannelDepth(image,RedChannel,&image->exception);
-      (void) fprintf(file,"    Red: %lu-bits\n",depth);
-      depth=GetImageChannelDepth(image,GreenChannel,&image->exception);
-      (void) fprintf(file,"    Green: %lu-bits\n",depth);
-      depth=GetImageChannelDepth(image,BlueChannel,&image->exception);
-      (void) fprintf(file,"    Blue: %lu-bits\n",depth);
+      (void) fprintf(file,"    Red: %lu-bits\n",
+        channel_statistics[RedChannel].depth);
+      (void) fprintf(file,"    Green: %lu-bits\n",
+        channel_statistics[GreenChannel].depth);
+      (void) fprintf(file,"    Blue: %lu-bits\n",
+        channel_statistics[BlueChannel].depth);
       if (image->matte != MagickFalse)
-        {
-          depth=GetImageChannelDepth(image,OpacityChannel,&image->exception);
-          (void) fprintf(file,"    Opacity: %lu-bits\n",depth);
-        }
+        (void) fprintf(file,"    Opacity: %lu-bits\n",
+          channel_statistics[OpacityChannel].depth);
       break;
     }
     case CMYKColorspace:
     {
-      depth=GetImageChannelDepth(image,CyanChannel,&image->exception);
-      (void) fprintf(file,"    Cyan: %lu-bits\n",depth);
-      depth=GetImageChannelDepth(image,MagentaChannel,&image->exception);
-      (void) fprintf(file,"    Magenta: %lu-bits\n",depth);
-      depth=GetImageChannelDepth(image,YellowChannel,&image->exception);
-      (void) fprintf(file,"    Yellow: %lu-bits\n",depth);
-      depth=GetImageChannelDepth(image,BlackChannel,&image->exception);
-      (void) fprintf(file,"    Black: %lu-bits\n",depth);
+      (void) fprintf(file,"    Cyan: %lu-bits\n",
+        channel_statistics[CyanChannel].depth);
+      (void) fprintf(file,"    Magenta: %lu-bits\n",
+        channel_statistics[MagentaChannel].depth);
+      (void) fprintf(file,"    Yellow: %lu-bits\n",
+        channel_statistics[YellowChannel].depth);
+      (void) fprintf(file,"    Black: %lu-bits\n",
+        channel_statistics[BlackChannel].depth);
       if (image->matte != MagickFalse)
-        {
-          depth=GetImageChannelDepth(image,OpacityChannel,&image->exception);
-          (void) fprintf(file,"    Opacity: %lu-bits\n",depth);
-        }
+        (void) fprintf(file,"    Opacity: %lu-bits\n",
+          channel_statistics[OpacityChannel].depth);
       break;
     }
     case GRAYColorspace:
     {
-      depth=GetImageChannelDepth(image,GrayChannel,&image->exception);
-      (void) fprintf(file,"    Gray: %lu-bits\n",depth);
+      (void) fprintf(file,"    Gray: %lu-bits\n",
+        channel_statistics[GrayChannel].depth);
       if (image->matte != MagickFalse)
-        {
-          depth=GetImageChannelDepth(image,OpacityChannel,&image->exception);
-          (void) fprintf(file,"    Opacity: %lu-bits\n",depth);
-        }
+        (void) fprintf(file,"    Opacity: %lu-bits\n",
+          channel_statistics[OpacityChannel].depth);
       break;
     }
   }
-  minima=0;
-  maxima=0;
-  mean=0.0;
-  standard_deviation=0.0;
+  scale=MaxRGB/(MaxRGB >> (QuantumDepth-channel_statistics[AllChannels].depth));
   (void) fprintf(file,"  Channel statistics:\n");
   switch (colorspace)
   {
     case RGBColorspace:
     default:
     {
-      (void) GetImageChannelExtrema(image,RedChannel,&minima,&maxima,
-        &image->exception);
-      (void) GetImageChannelMean(image,RedChannel,&mean,&standard_deviation,
-        &image->exception);
-      depth=GetImageDepth(image,&image->exception);
-      scale=MaxRGB/(MaxRGB >> (QuantumDepth-depth));
       (void) fprintf(file,"    Red:\n      Min: %lu (%g)\n      Max: %lu "
         "(%g)\n      Mean: %g (%g)\n      Standard deviation: %g (%g)\n",
-        minima/scale,(double) minima/MaxRGB,maxima/scale,(double) maxima/MaxRGB,
-        mean/scale,mean/MaxRGB,standard_deviation/scale,
-        standard_deviation/MaxRGB);
-      (void) GetImageChannelExtrema(image,GreenChannel,&minima,&maxima,
-        &image->exception);
-      (void) GetImageChannelMean(image,GreenChannel,&mean,&standard_deviation,
-        &image->exception);
+        channel_statistics[RedChannel].minima/scale,(double)
+        channel_statistics[RedChannel].minima/MaxRGB,
+        channel_statistics[RedChannel].maxima/scale,(double)
+        channel_statistics[RedChannel].maxima/MaxRGB,
+        channel_statistics[RedChannel].mean/scale,
+        channel_statistics[RedChannel].mean/MaxRGB,
+        channel_statistics[RedChannel].standard_deviation/scale,
+        channel_statistics[RedChannel].standard_deviation/MaxRGB);
       (void) fprintf(file,"    Green:\n      Min: %lu (%g)\n      Max: %lu "
         "(%g)\n      Mean: %g (%g)\n      Standard deviation: %g (%g)\n",
-        minima/scale,(double) minima/MaxRGB,maxima/scale,(double) maxima/MaxRGB,
-        mean/scale,mean/MaxRGB,standard_deviation/scale,
-        standard_deviation/MaxRGB);
-      (void) GetImageChannelExtrema(image,BlueChannel,&minima,&maxima,
-        &image->exception);
-      (void) GetImageChannelMean(image,BlueChannel,&mean,&standard_deviation,
-        &image->exception);
+        channel_statistics[GreenChannel].minima/scale,(double)
+        channel_statistics[GreenChannel].minima/MaxRGB,
+        channel_statistics[GreenChannel].maxima/scale,(double)
+        channel_statistics[GreenChannel].maxima/MaxRGB,
+        channel_statistics[GreenChannel].mean/scale,
+        channel_statistics[GreenChannel].mean/MaxRGB,
+        channel_statistics[GreenChannel].standard_deviation/scale,
+        channel_statistics[GreenChannel].standard_deviation/MaxRGB);
       (void) fprintf(file,"    Blue:\n      Min: %lu (%g)\n      Max: %lu "
         "(%g)\n      Mean: %g (%g)\n      Standard deviation: %g (%g)\n",
-        minima/scale,(double) minima/MaxRGB,maxima/scale,(double) maxima/MaxRGB,
-        mean/scale,mean/MaxRGB,standard_deviation/scale,
-        standard_deviation/MaxRGB);
-      if (image->matte != MagickFalse)
-        {
-          (void) GetImageChannelExtrema(image,OpacityChannel,&minima,&maxima,
-            &image->exception);
-          (void) GetImageChannelMean(image,OpacityChannel,&mean,
-            &standard_deviation,&image->exception);
-          (void) fprintf(file,"    Opacity:\n      Min: %lu (%g)\n      Max: %"
-            "lu (%g)\n      Mean: %g (%g)\n      Standard deviation: %g (%g)\n",
-            minima/scale,(double) minima/MaxRGB,maxima/scale,(double)
-            maxima/MaxRGB,mean/scale,mean/MaxRGB,standard_deviation/scale,
-            standard_deviation/MaxRGB);
-        }
+        channel_statistics[BlueChannel].minima/scale,(double)
+        channel_statistics[BlueChannel].minima/MaxRGB,
+        channel_statistics[BlueChannel].maxima/scale,(double)
+        channel_statistics[BlueChannel].maxima/MaxRGB,
+        channel_statistics[BlueChannel].mean/scale,
+        channel_statistics[BlueChannel].mean/MaxRGB,
+        channel_statistics[BlueChannel].standard_deviation/scale,
+        channel_statistics[BlueChannel].standard_deviation/MaxRGB);
       break;
     }
     case CMYKColorspace:
     {
-      (void) GetImageChannelExtrema(image,CyanChannel,&minima,&maxima,
-        &image->exception);
-      (void) GetImageChannelMean(image,CyanChannel,&mean,&standard_deviation,
-        &image->exception);
-      depth=GetImageDepth(image,&image->exception);
-      scale=MaxRGB/(MaxRGB >> (QuantumDepth-depth));
       (void) fprintf(file,"    Cyan:\n      Min: %lu (%g)\n      Max: %lu "
         "(%g)\n      Mean: %g (%g)\n      Standard deviation: %g (%g)\n",
-        minima/scale,(double) minima/MaxRGB,maxima/scale,(double) maxima/MaxRGB,
-        mean/scale,mean/MaxRGB,standard_deviation/scale,
-        standard_deviation/MaxRGB);
-      (void) GetImageChannelExtrema(image,MagentaChannel,&minima,&maxima,
-        &image->exception);
-      (void) GetImageChannelMean(image,MagentaChannel,&mean,&standard_deviation,
-        &image->exception);
+        channel_statistics[CyanChannel].minima/scale,(double)
+        channel_statistics[CyanChannel].minima/MaxRGB,
+        channel_statistics[CyanChannel].maxima/scale,(double)
+        channel_statistics[CyanChannel].maxima/MaxRGB,
+        channel_statistics[CyanChannel].mean/scale,
+        channel_statistics[CyanChannel].mean/MaxRGB,
+        channel_statistics[CyanChannel].standard_deviation/scale,
+        channel_statistics[CyanChannel].standard_deviation/MaxRGB);
       (void) fprintf(file,"    Magenta:\n      Min: %lu (%g)\n      Max: %lu "
         "(%g)\n      Mean: %g (%g)\n      Standard deviation: %g (%g)\n",
-        minima/scale,(double) minima/MaxRGB,maxima/scale,(double) maxima/MaxRGB,
-        mean/scale,mean/MaxRGB,standard_deviation/scale,
-        standard_deviation/MaxRGB);
-      (void) GetImageChannelExtrema(image,YellowChannel,&minima,&maxima,
-        &image->exception);
-      (void) GetImageChannelMean(image,YellowChannel,&mean,&standard_deviation,
-        &image->exception);
+        channel_statistics[MagentaChannel].minima/scale,(double)
+        channel_statistics[MagentaChannel].minima/MaxRGB,
+        channel_statistics[MagentaChannel].maxima/scale,(double)
+        channel_statistics[MagentaChannel].maxima/MaxRGB,
+        channel_statistics[MagentaChannel].mean/scale,
+        channel_statistics[MagentaChannel].mean/MaxRGB,
+        channel_statistics[MagentaChannel].standard_deviation/scale,
+        channel_statistics[MagentaChannel].standard_deviation/MaxRGB);
       (void) fprintf(file,"    Yellow:\n      Min: %lu (%g)\n      Max: %lu "
         "(%g)\n      Mean: %g (%g)\n      Standard deviation: %g (%g)\n",
-        minima/scale,(double) minima/MaxRGB,maxima/scale,(double) maxima/MaxRGB,
-        mean/scale,mean/MaxRGB,standard_deviation/scale,
-        standard_deviation/MaxRGB);
-      (void) GetImageChannelExtrema(image,BlackChannel,&minima,&maxima,
-        &image->exception);
-      (void) GetImageChannelMean(image,BlackChannel,&mean,&standard_deviation,
-        &image->exception);
+        channel_statistics[YellowChannel].minima/scale,(double)
+        channel_statistics[YellowChannel].minima/MaxRGB,
+        channel_statistics[YellowChannel].maxima/scale,(double)
+        channel_statistics[YellowChannel].maxima/MaxRGB,
+        channel_statistics[YellowChannel].mean/scale,
+        channel_statistics[YellowChannel].mean/MaxRGB,
+        channel_statistics[YellowChannel].standard_deviation/scale,
+        channel_statistics[YellowChannel].standard_deviation/MaxRGB);
       (void) fprintf(file,"    Black:\n      Min: %lu (%g)\n      Max: %lu "
         "(%g)\n      Mean: %g (%g)\n      Standard deviation: %g (%g)\n",
-        minima/scale,(double) minima/MaxRGB,maxima/scale,(double) maxima/MaxRGB,
-        mean/scale,mean/MaxRGB,standard_deviation/scale,
-        standard_deviation/MaxRGB);
-      if (image->matte != MagickFalse)
-        {
-          (void) GetImageChannelExtrema(image,OpacityChannel,&minima,&maxima,
-            &image->exception);
-          (void) GetImageChannelMean(image,OpacityChannel,&mean,
-            &standard_deviation,&image->exception);
-          (void) fprintf(file,"    Opacity:\n      Min: %lu (%g)\n      Max: %"
-            "lu (%g)\n      Mean: %g (%g)\n      Standard deviation: %g (%g)\n",
-            minima/scale,(double) minima/MaxRGB,maxima/scale,(double)
-            maxima/MaxRGB,mean/scale,mean/MaxRGB,standard_deviation/scale,
-            standard_deviation/MaxRGB);
-        }
+        channel_statistics[BlackChannel].minima/scale,(double)
+        channel_statistics[BlackChannel].minima/MaxRGB,
+        channel_statistics[BlackChannel].maxima/scale,(double)
+        channel_statistics[BlackChannel].maxima/MaxRGB,
+        channel_statistics[BlackChannel].mean/scale,
+        channel_statistics[BlackChannel].mean/MaxRGB,
+        channel_statistics[BlackChannel].standard_deviation/scale,
+        channel_statistics[BlackChannel].standard_deviation/MaxRGB);
       break;
     }
     case GRAYColorspace:
     {
-      (void) GetImageChannelExtrema(image,GrayChannel,&minima,&maxima,
-        &image->exception);
-      (void) GetImageChannelMean(image,GrayChannel,&mean,&standard_deviation,
-        &image->exception);
-      depth=GetImageDepth(image,&image->exception);
-      scale=MaxRGB/(MaxRGB >> (QuantumDepth-depth));
       (void) fprintf(file,"    Gray:\n      Min: %lu (%g)\n      Max: %lu "
         "(%g)\n      Mean: %g (%g)\n      Standard deviation: %g (%g)\n",
-        minima/scale,(double) minima/MaxRGB,maxima/scale,(double) maxima/MaxRGB,
-        mean/scale,mean/MaxRGB,standard_deviation/scale,
-        standard_deviation/MaxRGB);
-      if (image->matte != MagickFalse)
-        {
-          (void) GetImageChannelExtrema(image,OpacityChannel,&minima,&maxima,
-            &image->exception);
-          (void) GetImageChannelMean(image,OpacityChannel,&mean,
-            &standard_deviation,&image->exception);
-          (void) fprintf(file,"    Opacity:\n      Min: %lu (%g)\n      Max: %"
-            "lu (%g)\n      Mean: %g (%g)\n      Standard deviation: %g (%g)\n",
-            minima/scale,(double) minima/MaxRGB,maxima/scale,(double)
-            maxima/MaxRGB,mean/scale,mean/MaxRGB,standard_deviation/scale,
-            standard_deviation/MaxRGB);
-        }
+        channel_statistics[GrayChannel].minima/scale,(double)
+        channel_statistics[GrayChannel].minima/MaxRGB,
+        channel_statistics[GrayChannel].maxima/scale,(double)
+        channel_statistics[GrayChannel].maxima/MaxRGB,
+        channel_statistics[GrayChannel].mean/scale,
+        channel_statistics[GrayChannel].mean/MaxRGB,
+        channel_statistics[GrayChannel].standard_deviation/scale,
+        channel_statistics[GrayChannel].standard_deviation/MaxRGB);
       break;
     }
   }
+  if (image->matte != MagickFalse)
+    (void) fprintf(file,"    Opacity:\n      Min: %lu (%g)\n      Max: %lu "
+      "(%g)\n      Mean: %g (%g)\n      Standard deviation: %g (%g)\n",
+      channel_statistics[OpacityChannel].minima/scale,(double)
+      channel_statistics[OpacityChannel].minima/MaxRGB,
+      channel_statistics[OpacityChannel].maxima/scale,(double)
+      channel_statistics[OpacityChannel].maxima/MaxRGB,
+      channel_statistics[OpacityChannel].mean/scale,
+      channel_statistics[OpacityChannel].mean/MaxRGB,
+      channel_statistics[OpacityChannel].standard_deviation/scale,
+      channel_statistics[OpacityChannel].standard_deviation/MaxRGB);
+  channel_statistics=(ChannelStatistics *)
+    RelinquishMagickMemory(channel_statistics);
   x=0;
   p=(Image *) NULL;
   if (((image->matte != MagickFalse) &&
@@ -651,13 +620,15 @@ MagickExport MagickBooleanType IdentifyImage(Image *image,FILE *file,
         (void) fprintf(file," %lux%lu %s\n",tile->magick_columns,
           tile->magick_rows,tile->magick);
         (void) SignatureImage(tile);
-        attribute=GetImageAttribute(tile,(char *) NULL);
-        for ( ; attribute != (const ImageAttribute *) NULL; attribute=attribute->next)
+        ResetImageAttributeIterator(tile);
+        attribute=GetNextImageAttribute(tile);
+        while (attribute != (const ImageAttribute *) NULL)
         {
           if (*attribute->key == '[')
             continue;
           (void) fprintf(file,"  %s:\n",attribute->key);
           (void) fprintf(file,"%s\n",attribute->value);
+          attribute=GetNextImageAttribute(tile);
         }
         tile=DestroyImage(tile);
       }
@@ -666,15 +637,18 @@ MagickExport MagickBooleanType IdentifyImage(Image *image,FILE *file,
   /*
     Display image attributes.
   */
-  attribute=GetImageAttribute(image,(char *) NULL);
-  for ( ; attribute != (const ImageAttribute *) NULL; attribute=attribute->next)
+  ResetImageAttributeIterator(image);
+  attribute=GetNextImageAttribute(image);
+  while (attribute != (const ImageAttribute *) NULL)
   {
-    if (*attribute->key == '[')
-      continue;
-    (void) fprintf(file,"  %s: ",attribute->key);
-    if (strlen(attribute->value) > 80)
-      (void) fputc('\n',file);
-    (void) fprintf(file,"%s\n",attribute->value);
+    if (*attribute->key != '[')
+      {
+        (void) fprintf(file,"  %s: ",attribute->key);
+        if (strlen(attribute->value) > 80)
+          (void) fputc('\n',file);
+        (void) fprintf(file,"%s\n",attribute->value);
+      }
+    attribute=GetNextImageAttribute(image);
   }
   (void) FormatMagickString(key,MaxTextExtent,"8BIM:1999,2998:#1");
   attribute=GetImageAttribute(image,key);
@@ -685,7 +659,7 @@ MagickExport MagickBooleanType IdentifyImage(Image *image,FILE *file,
         (void) fputc('\n',file);
       (void) fprintf(file,"%s\n",attribute->value);
     }
-  if (image->profiles != (SplayTreeInfo *) NULL)
+  if (image->profiles != (void *) NULL)
     {
       const char
         *name;
@@ -859,12 +833,11 @@ MagickExport MagickBooleanType IdentifyImage(Image *image,FILE *file,
     (void) fprintf(file,"  Tainted: True\n");
   else
     (void) fprintf(file,"  Tainted: False\n");
-  if (user_time != 0.0)
-    (void) fprintf(file,"  User Time: %0.3fu\n",user_time);
-  if (elapsed_time != 0.0)
+  if (elapsed_time > 0.02)
     {
+      (void) fprintf(file,"  User Time: %0.3fu\n",user_time);
       (void) fprintf(file,"  Elapsed Time: %ld:%02ld\n",
-        (long) (elapsed_time/60.0+0.5),(long) ceil(fmod(elapsed_time,60.0)));
+      (long) (elapsed_time/60.0+0.5),(long) ceil(fmod(elapsed_time,60.0)));
       FormatSize((MagickSizeType) ((double) image->columns*image->rows/
         elapsed_time),format);
       (void) fprintf(file,"  Pixels per second: %s\n",format);
@@ -924,6 +897,7 @@ static void IdentifyUsage(void)
     {
       "-authenticate value  decrypt image with this password",
       "-channel type        apply option to select image channels",
+      "-crop geometry       crop the image",
       "-debug events        display copious debugging information",
       "-define format:option",
       "                     define one or more image format options",
@@ -940,8 +914,11 @@ static void IdentifyUsage(void)
       "-log format          format of debugging information",
       "-matte               store matte channel if the image has one",
       "-monitor             monitor progress",
+      "-ping                efficiently determine image attributes",
+      "-quiet               suppress all error or warning messages",
       "-sampling-factor geometry",
       "                     horizontal and vertical sampling factor",
+      "-set attribute value set an image attribute",
       "-size geometry       width and height of image",
       "-strip               strip image of all profiles and comments",
       "-units type          the units of image resolution",
@@ -1151,6 +1128,18 @@ MagickExport MagickBooleanType IdentifyImageCommand(ImageInfo *image_info,
               }
             break;
           }
+        if (LocaleCompare("crop",option+1) == 0)
+          {
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) (argc-1))
+              ThrowIdentifyException(OptionError,"MissingArgument",option);
+            if (IsGeometry(argv[i]) == MagickFalse)
+              ThrowIdentifyInvalidArgumentException(option,argv[i]);
+            image_info->ping=MagickFalse;
+            break;
+          }
         ThrowIdentifyException(OptionError,"UnrecognizedOption",option)
       }
       case 'd':
@@ -1228,8 +1217,8 @@ MagickExport MagickBooleanType IdentifyImageCommand(ImageInfo *image_info,
             format=argv[i];
             image_info->ping=MagickTrue;
             for (q=strchr(format,'%'); q != (char *) NULL; q=strchr(q+1,'%'))
-              if ((*(q+1) == 'g') || (*(q+1) == 'k') || (*(q+1) == 'z') ||
-                  (*(q+1) == '@') || (*(q+1) == '#'))
+              if ((*(q+1) == 'g') || (*(q+1) == 'k') || (*(q+1) == 'r') ||
+                  (*(q+1) == 'z') || (*(q+1) == '@') || (*(q+1) == '#'))
                 image_info->ping=MagickFalse;
             break;
           }
@@ -1342,6 +1331,12 @@ MagickExport MagickBooleanType IdentifyImageCommand(ImageInfo *image_info,
           break;
         ThrowIdentifyException(OptionError,"UnrecognizedOption",option)
       }
+      case 'q':
+      {
+        if (LocaleCompare("quiet",option+1) == 0)
+          break;
+        ThrowIdentifyException(OptionError,"UnrecognizedOption",option)
+      }
       case 's':
       {
         if (LocaleCompare("sampling-factor",option+1) == 0)
@@ -1355,6 +1350,18 @@ MagickExport MagickBooleanType IdentifyImageCommand(ImageInfo *image_info,
               ThrowIdentifyInvalidArgumentException(option,argv[i]);
             break;
           }
+        if (LocaleCompare("set",option+1) == 0)
+          {
+            i++;
+            if (i == (long) argc)
+              ThrowIdentifyException(OptionError,"MissingArgument",option);
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) argc)
+              ThrowIdentifyException(OptionError,"MissingArgument",option);
+            break;
+          }
         if (LocaleCompare("size",option+1) == 0)
           {
             if (*option == '+')
@@ -1405,9 +1412,7 @@ MagickExport MagickBooleanType IdentifyImageCommand(ImageInfo *image_info,
       case 'v':
       {
         if (LocaleCompare("verbose",option+1) == 0)
-          {
-            break;
-          }
+          break;
         if (LocaleCompare("version",option+1) == 0)
           break;
         if (LocaleCompare("virtual-pixel",option+1) == 0)
