@@ -5,7 +5,7 @@
   You may not use this file except in compliance with the License.
   obtain a copy of the License at
   
-    http://www.imagemagick.org/www/Copyright.html
+    http://www.imagemagick.org/script/license.php
   
   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
@@ -57,6 +57,7 @@ extern MagickExport Image
   *AverageImages(const Image *,ExceptionInfo *),
   *CloneImage(const Image *,const unsigned long,const unsigned long,
     const MagickBooleanType,ExceptionInfo *),
+  *CloneImages(const Image *,const char *,ExceptionInfo *),
   *CombineImages(const Image *,const ChannelType,ExceptionInfo *),
   *DestroyImage(Image *),
   *GetImageClipMask(const Image *,ExceptionInfo *),
@@ -80,23 +81,14 @@ extern MagickExport MagickBooleanType
   ClipPathImage(Image *,const char *,const MagickBooleanType),
   GradientImage(Image *,const PixelPacket *,const PixelPacket *),
   CycleColormapImage(Image *,const long),
-  GetImageChannelExtrema(const Image *,const ChannelType,unsigned long *,
-    unsigned long *,ExceptionInfo *),
-  GetImageExtrema(const Image *,unsigned long *,unsigned long *,
-    ExceptionInfo *),
-  GetImageChannelMean(const Image *,const ChannelType,double *,double *,
-    ExceptionInfo *),
-  GetImageMean(const Image *,double *,double *,ExceptionInfo *),
   GradientImage(Image *,const PixelPacket *,const PixelPacket *),
   IsTaintImage(const Image *),
   IsMagickConflict(const char *),
   ListMagickInfo(FILE *,ExceptionInfo *),
   PlasmaImage(Image *,const SegmentInfo *,unsigned long,unsigned long),
   SeparateImageChannel(Image *,const ChannelType),
-  SetImageChannelDepth(Image *,const ChannelType,const unsigned long),
   SetImageClipMask(Image *,const Image *),
   SetImageInfo(ImageInfo *,const MagickBooleanType,ExceptionInfo *),
-  SetImageDepth(Image *,const unsigned long),
   SetImageType(Image *,const ImageType),
   SignatureImage(Image *),
   SortColormapByIntensity(Image *),
@@ -114,14 +106,6 @@ extern MagickExport PixelPacket
   *SetImagePixels(Image *,const long,const long,const unsigned long,
     const unsigned long);
 
-extern MagickExport RectangleInfo
-  GetImageBoundingBox(const Image *,ExceptionInfo *exception);
-
-extern MagickExport unsigned long
-  GetImageChannelDepth(const Image *,const ChannelType,ExceptionInfo *),
-  GetImageDepth(const Image *,ExceptionInfo *),
-  GetImageQuantumDepth(const Image *,const MagickBooleanType);
-
 extern MagickExport void
   AllocateNextImage(const ImageInfo *,Image *),
   DestroyColorList(void),
@@ -129,7 +113,7 @@ extern MagickExport void
   GetImageException(Image *,ExceptionInfo *),
   GetImageInfo(ImageInfo *),
   ModifyImage(Image **,ExceptionInfo *),
-  SetImage(Image *,const Quantum),
+  SetImageBackgroundColor(Image *),
   SetImageInfoBlob(ImageInfo *,const void *,const size_t),
   SetImageInfoFile(ImageInfo *,FILE *),
   SetImageOpacity(Image *,const Quantum);
