@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -169,6 +169,7 @@ static void ImportUsage(void)
       "-pause value         seconds delay between snapshots",
       "-pointsize value     font point size",
       "-quality value       JPEG/MIFF/PNG compression level",
+      "-quiet               suppress all error or warning messages",
       "-repage geometry     size and location of an image canvas",
       "-resize geometry     resize the image",
       "-rotate degrees      apply Paeth rotation to the image",
@@ -176,6 +177,7 @@ static void ImportUsage(void)
       "                     horizontal and vertical sampling factor",
       "-scene value         image scene number",
       "-screen              select image from root window",
+      "-set attribute value set an image attribute",
       "-silent              operate silently, i.e. don't ring any bells ",
       "-snaps value         number of screen snapshots",
       "-strip               strip image of all profiles and comments",
@@ -937,6 +939,8 @@ MagickExport MagickBooleanType ImportImageCommand(ImageInfo *image_info,
               ThrowImportInvalidArgumentException(option,argv[i]);
             break;
           }
+        if (LocaleCompare("quiet",option+1) == 0)
+          break;
         ThrowImportException(OptionError,"UnrecognizedOption",option);
       }
       case 'r':
@@ -998,6 +1002,18 @@ MagickExport MagickBooleanType ImportImageCommand(ImageInfo *image_info,
               ThrowImportInvalidArgumentException(option,argv[i]);
             break;
           }
+        if (LocaleCompare("set",option+1) == 0)
+          {
+            i++;
+            if (i == (long) argc)
+              ThrowImportException(OptionError,"MissingArgument",option);
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) argc)
+              ThrowImportException(OptionError,"MissingArgument",option);
+            break;
+          }
         if (LocaleCompare("screen",option+1) == 0)
           {
             ximage_info.screen=(MagickBooleanType) (*option == '-');
