@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -764,7 +764,7 @@ static void *DestroyLocaleNode(void *locale_info)
     p->tag=(char *) RelinquishMagickMemory(p->tag);
   if (p->message != (char *) NULL)
     p->message=(char *) RelinquishMagickMemory(p->message);
-  return((LocaleInfo *) RelinquishMagickMemory(p));
+  return(RelinquishMagickMemory(p));
 }
 
 static MagickBooleanType LoadLocaleList(const char *xml,const char *filename,
