@@ -24,7 +24,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -153,8 +153,6 @@ MagickExport void DestroyMagick(void)
   DestroyRandomReservoir();
   DestroyLocaleList();
   DestroyLogList();
-  DestroyMagickMemory();
-  DestroySemaphore();
   instantiate_magick=MagickFalse;
 }
 
@@ -985,8 +983,7 @@ static void *DestroyMagickNode(void *magick_info)
     p->note=(char *) RelinquishMagickMemory(p->note);
   if (p->module != (char *) NULL)
     p->module=(char *) RelinquishMagickMemory(p->module);
-  p=(MagickInfo *) RelinquishMagickMemory(p);
-  return((void *) NULL);
+  return(RelinquishMagickMemory(p));
 }
 
 static MagickBooleanType InitializeMagickList(ExceptionInfo *exception)
@@ -1447,14 +1444,5 @@ MagickExport MagickBooleanType UnregisterMagickInfo(const char *name)
     p=(const MagickInfo *) GetNextValueInSplayTree(magick_list);
   }
   RelinquishSemaphoreInfo(magick_semaphore);
-  if (p != (const MagickInfo *) NULL)
-    {
-      MagickInfo
-        *magick_info;
-
-      magick_info=(MagickInfo *)
-        RemoveNodeByValueFromSplayTree(magick_list,p);
-      (void) DestroyMagickNode(magick_info);
-    }
-  return(status);
+  return(RemoveNodeByValueFromSplayTree(magick_list,p));
 }
