@@ -10,7 +10,7 @@
 %                  M   M   OOO   DDDD    UUU   LLLLL  EEEEE                   %
 %                                                                             %
 %                                                                             %
-%                         ImageMagick Module Methods                           %
+%                         ImageMagick Module Methods                          %
 %                                                                             %
 %                              Software Design                                %
 %                              Bob Friesenhahn                                %
@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -862,9 +862,8 @@ static void *DestroyModuleNode(void *module_info)
     p->tag=(char *) RelinquishMagickMemory(p->tag);
   if (p->path != (char *) NULL)
     p->path=(char *) RelinquishMagickMemory(p->path);
-  p=(ModuleInfo *) RelinquishMagickMemory(p);
   DestroyExceptionInfo(&exception);
-  return((void *) NULL);
+  return(RelinquishMagickMemory(p));
 }
 
 static MagickBooleanType InitializeModuleList(ExceptionInfo *exception)
