@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -332,6 +332,7 @@ static void MontageUsage(void)
       "-pointsize value     font point size",
       "-profile filename    add, delete, or apply an image profile",
       "-quality value       JPEG/MIFF/PNG compression level",
+      "-quiet               suppress all error or warning messages",
       "-red-primary point   chromaticity red primary point",
       "-repage geometry     size and location of an image canvas (operator)",
       "-resize geometry     resize the image",
@@ -339,6 +340,7 @@ static void MontageUsage(void)
       "-sampling-factor geometry",
       "                     horizontal and vertical sampling factor",
       "-scenes range        image scene range",
+      "-set attribute value set an image attribute",
       "-shadow              add a shadow beneath a tile to simulate depth",
       "-size geometry       width and height of image",
       "-strip               strip image of all profiles and comments",
@@ -669,33 +671,28 @@ MagickExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
         if (LocaleCompare("clone",option+1) == 0)
           {
             Image
-              *clone_image;
+              *clone_images;
 
-            long
-              index;
-
-            index=(-1);
-            if (*option == '-')
+            clone_images=image_stack[k];
+            if (k != 0)
+              clone_images=image_stack[k-1];
+            if (clone_images == (Image *) NULL)
+              ThrowMontageException(ImageError,"ImageSequenceRequired",option);
+            if (*option == '+')
+              clone_images=CloneImages(clone_images,"-1",exception);
+            else
               {
                 i++;
                 if (i == (long) (argc-1))
                   ThrowMontageException(OptionError,"MissingArgument",option);
-                if (IsGeometry(argv[i]) == MagickFalse)
+                if (IsSceneGeometry(argv[i],MagickFalse) == MagickFalse)
                   ThrowMontageInvalidArgumentException(option,argv[i]);
-                index=atol(argv[i]);
+                clone_images=CloneImages(clone_images,argv[i],exception);
               }
-            if (k == 0)
-              ThrowMontageException(ImageError,"ImageSequenceRequired",option);
-            clone_image=GetImageFromList(image_stack[k-1],index);
-            if (clone_image == (Image *) NULL)
-              ThrowMontageException(ImageError,"NoSuchImage",option);
-            clone_image=CloneImage(clone_image,0,0,MagickTrue,
-              &image_stack[k-1]->exception);
-            if (clone_image == (Image *) NULL)
-              ThrowMontageException(ResourceLimitError,
-                "MemoryAllocationFailed",strerror(errno));
+            if (clone_images == (Image *) NULL)
+              ThrowMontageException(OptionError,"NoSuchImage",option);
             MogrifyImageStack(image_stack[k],MagickTrue,MagickTrue);
-            AppendImageToList(&image_stack[k],clone_image);
+            AppendImageToList(&image_stack[k],clone_images);
             break;
           }
         if (LocaleCompare("colors",option+1) == 0)
@@ -1243,6 +1240,8 @@ MagickExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
               ThrowMontageInvalidArgumentException(option,argv[i]);
             break;
           }
+        if (LocaleCompare("quiet",option+1) == 0)
+          break;
         ThrowMontageException(OptionError,"UnrecognizedOption",option)
       }
       case 'r':
@@ -1322,6 +1321,18 @@ MagickExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
             (void) sscanf(argv[i],"%ld-%ld",&first_scene,&last_scene);
             break;
           }
+        if (LocaleCompare("set",option+1) == 0)
+          {
+            i++;
+            if (i == (long) argc)
+              ThrowMontageException(OptionError,"MissingArgument",option);
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) argc)
+              ThrowMontageException(OptionError,"MissingArgument",option);
+            break;
+          }
         if (LocaleCompare("shadow",option+1) == 0)
           {
             montage_info->shadow=(MagickBooleanType) (*option == '-');
@@ -1958,7 +1969,7 @@ MagickExport Image *MontageImages(const Image *images,
       MaxTextExtent);
     montage->columns=bounds.width;
     montage->rows=bounds.height;
-    SetImage(montage,OpaqueOpacity);
+    SetImageBackgroundColor(montage);
     /*
       Set montage geometry.
     */
