@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -194,6 +194,7 @@ static const OptionInfo
     { "-green-primary", 1L },
     { "-gravity", 1L },
     { "-help", 0L },
+    { "-identify", 0L },
     { "-implode", 1L },
     { "-insert", 1L },
     { "-intent", 1L },
@@ -226,6 +227,7 @@ static const OptionInfo
     { "-page", 1L },
     { "-paint", 1L },
     { "-pen", 1L },
+    { "-ping", 0L },
     { "-pointsize", 1L },
     { "-posterize", 1L },
     { "-preview", 1L },
@@ -252,6 +254,8 @@ static const OptionInfo
     { "-seed", 1L },
     { "-segment", 1L },
     { "-separate", 0L },
+    { "+set", 1L },
+    { "-set", 2L },
     { "-shade", 1L },
     { "-shadow", 1L },
     { "-sharpen", 1L },
@@ -364,6 +368,7 @@ static const OptionInfo
     { "Fax", (long) FaxCompression },
     { "Group4", (long) Group4Compression },
     { "JPEG", (long) JPEGCompression },
+    { "JPEG2000", (long) JPEG2000Compression },
     { "Lossless", (long) LosslessJPEGCompression },
     { "LosslessJPEG", (long) LosslessJPEGCompression },
     { "LZW", (long) LZWCompression },
@@ -383,6 +388,8 @@ static const OptionInfo
     { "HWB", (long) HWBColorspace },
     { "LAB", (long) LABColorspace },
     { "OHTA", (long) OHTAColorspace },
+    { "Rec601Luma", (long) Rec601LumaColorspace },
+    { "Rec709Luma", (long) Rec709LumaColorspace },
     { "RGB", (long) RGBColorspace },
     { "sRGB", (long) sRGBColorspace },
     { "Transparent", (long) TransparentColorspace },
@@ -798,7 +805,7 @@ MagickExport MagickBooleanType CloneImageOptions(ImageInfo *image_info,
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),image_info->filename);
   assert(clone_info != (const ImageInfo *) NULL);
   assert(clone_info->signature == MagickSignature);
-  if (clone_info->options == (SplayTreeInfo *) NULL)
+  if (clone_info->options == (void *) NULL)
     return(MagickTrue);
   ResetImageOptionIterator(clone_info);
   for (key=GetNextImageOption(clone_info); key != (char *) NULL; )
@@ -844,9 +851,6 @@ MagickExport MagickBooleanType DefineImageOption(ImageInfo *image_info,
     key[MaxTextExtent],
     value[MaxTextExtent];
 
-  MagickBooleanType
-    status;
-
   register char
     *p;
 
@@ -860,8 +864,7 @@ MagickExport MagickBooleanType DefineImageOption(ImageInfo *image_info,
   if (*p == '=')
     (void) CopyMagickString(value,p+1,MaxTextExtent);
   *p='\0';
-  status=SetImageOption(image_info,key,value);
-  return(status);
+  return(SetImageOption(image_info,key,value));
 }
 
 /*
@@ -879,7 +882,8 @@ MagickExport MagickBooleanType DefineImageOption(ImageInfo *image_info,
 %
 %  The format of the DeleteImageOption method is:
 %
-%      char DeleteImageOption(ImageInfo *image_info,const char *option)
+%      MagickBooleanType DeleteImageOption(ImageInfo *image_info,
+%        const char *key)
 %
 %  A description of each parameter follows:
 %
@@ -891,23 +895,13 @@ MagickExport MagickBooleanType DefineImageOption(ImageInfo *image_info,
 MagickExport MagickBooleanType DeleteImageOption(ImageInfo *image_info,
   const char *option)
 {
-  char
-    key[MaxTextExtent],
-    *value;
-
   assert(image_info != (ImageInfo *) NULL);
   assert(image_info->signature == MagickSignature);
   if (image_info->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),image_info->filename);
-  if (image_info->options == (SplayTreeInfo *) NULL)
+  if (image_info->options == (void *) NULL)
     return(MagickFalse);
-  (void) CopyMagickString(key,option,MaxTextExtent);
-  LocaleLower(key);
-  value=(char *) RemoveNodeFromSplayTree(image_info->options,key);
-  if (value == (char *) NULL)
-    return(MagickFalse);
-  value=(char *) RelinquishMagickMemory(value);
-  return(MagickTrue);
+  return(RemoveNodeFromSplayTree(image_info->options,option));
 }
 
 /*
@@ -935,7 +929,11 @@ MagickExport MagickBooleanType DeleteImageOption(ImageInfo *image_info,
 */
 MagickExport void DestroyImageOptions(ImageInfo *image_info)
 {
-  if (image_info->options != (SplayTreeInfo *) NULL)
+  assert(image_info != (ImageInfo *) NULL);
+  assert(image_info->signature == MagickSignature);
+  if (image_info->debug != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image_info->filename);
+  if (image_info->options != (void *) NULL)
     image_info->options=DestroySplayTree(image_info->options);
 }
 
@@ -967,18 +965,13 @@ MagickExport void DestroyImageOptions(ImageInfo *image_info)
 MagickExport const char *GetImageOption(const ImageInfo *image_info,
   const char *key)
 {
-  char
-    node[MaxTextExtent];
-
   assert(image_info != (ImageInfo *) NULL);
   assert(image_info->signature == MagickSignature);
   if (image_info->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),image_info->filename);
-  if (image_info->options == (SplayTreeInfo *) NULL)
+  if (image_info->options == (void *) NULL)
     return((const char *) NULL);
-  (void) CopyMagickString(node,key,MaxTextExtent);
-  LocaleLower(node);
-  return((const char *) GetValueFromSplayTree(image_info->options,node));
+  return((const char *) GetValueFromSplayTree(image_info->options,key));
 }
 
 /*
@@ -1095,7 +1088,7 @@ MagickExport char **GetMagickOptions(const MagickOption value)
 %
 %  A description of each parameter follows:
 %
-%    o hash_info: The hash info.
+%    o image_info: The image info.
 %
 */
 MagickExport char *GetNextImageOption(const ImageInfo *image_info)
@@ -1104,7 +1097,7 @@ MagickExport char *GetNextImageOption(const ImageInfo *image_info)
   assert(image_info->signature == MagickSignature);
   if (image_info->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),image_info->filename);
-  if (image_info->options == (SplayTreeInfo *) NULL)
+  if (image_info->options == (void *) NULL)
     return((char *) NULL);
   return((char *) GetNextKeyInSplayTree(image_info->options));
 }
@@ -1396,11 +1389,12 @@ MagickExport long ParseMagickOption(const MagickOption option,
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  RemoveImageOption() removes an option from the image map by its option.
+%  RemoveImageOption() removes an option from the image map.
 %
 %  The format of the RemoveImageOption method is:
 %
-%      char RemoveImageOption(ImageInfo *image_info,const char *option)
+%      MagickBooleanType RemoveImageOption(ImageInfo *image_info,
+%        const char *option)
 %
 %  A description of each parameter follows:
 %
@@ -1409,20 +1403,16 @@ MagickExport long ParseMagickOption(const MagickOption option,
 %    o option: The image option.
 %
 */
-MagickExport char *RemoveImageOption(ImageInfo *image_info,const char *option)
+MagickExport MagickBooleanType RemoveImageOption(ImageInfo *image_info,
+  const char *option)
 {
-  char
-    key[MaxTextExtent];
-
   assert(image_info != (ImageInfo *) NULL);
   assert(image_info->signature == MagickSignature);
   if (image_info->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),image_info->filename);
-  if (image_info->options == (SplayTreeInfo *) NULL)
-    return((char *) NULL);
-  (void) CopyMagickString(key,option,MaxTextExtent);
-  LocaleLower(key);
-  return((char *) RemoveNodeFromSplayTree(image_info->options,key));
+  if (image_info->options == (void *) NULL)
+    return(MagickFalse);
+  return(RemoveNodeFromSplayTree(image_info->options,option));
 }
 
 /*
@@ -1455,7 +1445,7 @@ MagickExport void ResetImageOptionIterator(const ImageInfo *image_info)
   assert(image_info->signature == MagickSignature);
   if (image_info->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),image_info->filename);
-  if (image_info->options == (SplayTreeInfo *) NULL)
+  if (image_info->options == (void *) NULL)
     return;
   ResetSplayTreeIterator(image_info->options);
 }
@@ -1490,9 +1480,6 @@ MagickExport void ResetImageOptionIterator(const ImageInfo *image_info)
 MagickExport MagickBooleanType SetImageOption(ImageInfo *image_info,
   const char *option,const char *value)
 {
-  char
-    key[MaxTextExtent];
-
   MagickBooleanType
     status;
 
@@ -1500,12 +1487,10 @@ MagickExport MagickBooleanType SetImageOption(ImageInfo *image_info,
   assert(image_info->signature == MagickSignature);
   if (image_info->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),image_info->filename);
-  if (image_info->options == (SplayTreeInfo *) NULL)
+  if (image_info->options == (void *) NULL)
     image_info->options=NewSplayTree(CompareSplayTreeString,
       RelinquishMagickMemory,RelinquishMagickMemory);
-  (void) CopyMagickString(key,option,MaxTextExtent);
-  LocaleLower(key);
   status=AddValueToSplayTree(image_info->options,
-    ConstantString(AcquireString(key)),ConstantString(AcquireString(value)));
+    ConstantString(AcquireString(option)),ConstantString(AcquireString(value)));
   return(status);
 }
