@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -233,7 +233,7 @@ MagickExport char *GetNextImageProfile(const Image *image)
 %  The format of the ProfileImage method is:
 %
 %      MagickBooleanType ProfileImage(Image *image,const char *name,
-%        const unsigned char *datum,const unsigned long length,
+%        const void *datum,const unsigned long length,
 %        const MagickBooleanType clone)
 %
 %  A description of each parameter follows:
@@ -263,8 +263,7 @@ static int LCMSErrorHandler(int severity,const char *context)
 #endif
 
 MagickExport MagickBooleanType ProfileImage(Image *image,const char *name,
-  const unsigned char *datum,const unsigned long length,
-  const MagickBooleanType clone)
+  const void *datum,const unsigned long length,const MagickBooleanType clone)
 {
 #define ThrowProfileException(severity,tag,context) \
 { \
@@ -284,18 +283,14 @@ MagickExport MagickBooleanType ProfileImage(Image *image,const char *name,
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),image->filename);
   assert(name != (const char *) NULL);
-  if ((datum == (const unsigned char *) NULL) || (length == 0))
+  if ((datum == (const void *) NULL) || (length == 0))
     {
       if (*name == '*')
         {
           DestroyImageProfiles(image);
           return(MagickTrue);
         }
-      profile=RemoveImageProfile(image,name);
-      if (profile == (StringInfo *) NULL)
-        ThrowBinaryException(OptionError,"NoProfileNameFound",name);
-      profile=DestroyStringInfo(profile);
-      return(MagickTrue);
+      return(RemoveImageProfile(image,name));
     }
   /*
     Add a ICC, IPTC, or generic profile to the image.
@@ -602,7 +597,7 @@ MagickExport MagickBooleanType ProfileImage(Image *image,const char *name,
 %
 %  The format of the RemoveImageProfile method is:
 %
-%      StringInfo RemoveImageProfile(Image *image,const char *name)
+%      MagickBooleanTyupe RemoveImageProfile(Image *image,const char *name)
 %
 %  A description of each parameter follows:
 %
@@ -611,17 +606,15 @@ MagickExport MagickBooleanType ProfileImage(Image *image,const char *name,
 %    o name: The profile name.
 %
 */
-MagickExport StringInfo *RemoveImageProfile(Image *image,const char *name)
+MagickExport MagickBooleanType RemoveImageProfile(Image *image,
+  const char *name)
 {
-  char
-    key[MaxTextExtent];
-
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),image->filename);
   if (image->profiles == (SplayTreeInfo *) NULL)
-    return((StringInfo *) NULL);
+    return(MagickFalse);
   if (LocaleCompare(name,"icc") == 0)
     {
       /*
@@ -638,9 +631,7 @@ MagickExport StringInfo *RemoveImageProfile(Image *image,const char *name)
       image->iptc_profile.length=0;
       image->iptc_profile.info=(unsigned char *) NULL;
     }
-  (void) CopyMagickString(key,name,MaxTextExtent);
-  LocaleLower(key);
-  return((StringInfo *) RemoveNodeFromSplayTree(image->profiles,key));
+  return(RemoveNodeFromSplayTree(image->profiles,name));
 }
 
 /*
