@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -132,17 +132,8 @@ MagickExport MagickBooleanType DeleteMagickRegistry(const long id)
       break;
     p=(const RegistryInfo *) GetNextValueInSplayTree(registry_list);
   }
-  if (p != (const RegistryInfo *) NULL)
-    {
-      RegistryInfo
-        *registry_info;
-
-      registry_info=(RegistryInfo *)
-        RemoveNodeByValueFromSplayTree(registry_list,p);
-      (void) DestroyRegistryNode(registry_info);
-    }
   RelinquishSemaphoreInfo(registry_semaphore);
-  return((MagickBooleanType) (p != (RegistryInfo *) NULL));
+  return(RemoveNodeByValueFromSplayTree(registry_list,p));
 }
 
 /*
@@ -416,8 +407,7 @@ static void *DestroyRegistryNode(void *registry_info)
       break;
     }
   }
-  p=(RegistryInfo *) RelinquishMagickMemory(p);
-  return((void *) NULL);
+  return(RelinquishMagickMemory(p));
 }
 
 MagickExport long SetMagickRegistry(const RegistryType type,const void *blob,
