@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -248,11 +248,11 @@ MagickExport void AsynchronousDestroyMagickResources(void)
         Remove any lingering temporary files.
       */
       ResetSplayTreeIterator(temporary_resources);
-      file=(int) GetNextValueInSplayTree(temporary_resources);
+      file=(int) ((long) GetNextValueInSplayTree(temporary_resources));
       while (file != 0)
       {
         (void) close(file);
-        file=(int) GetNextValueInSplayTree(temporary_resources);
+        file=(int) ((long) GetNextValueInSplayTree(temporary_resources));
       }
       ResetSplayTreeIterator(temporary_resources);
       path=(const char *) GetNextKeyInSplayTree(temporary_resources);
@@ -396,7 +396,8 @@ MagickExport int AcquireUniqueFileResource(char *path)
     temporary_resources=NewSplayTree(CompareSplayTreeString,
       RelinquishMagickMemory,(void *(*)(void *)) NULL);
   resource=ConstantString(AcquireString(path));
-  (void) AddValueToSplayTree(temporary_resources,resource,(void *) file);
+  (void) AddValueToSplayTree(temporary_resources,resource,
+    (void *) ((long) file));
   return(file);
 }
 
@@ -775,7 +776,6 @@ MagickExport MagickBooleanType RelinquishUniqueFileResource(const char *path)
       if (p != (char *) NULL)
         {
           (void) RemoveNodeFromSplayTree(temporary_resources,p);
-          p=(char *) RelinquishMagickMemory(p);
           RelinquishMagickResource(FileResource,1);
         }
     }
