@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -150,7 +150,8 @@ MagickExport Image *AffineTransformImage(const Image *image,
     (unsigned long) (max.y-min.y+0.5),MagickTrue,exception);
   if (affine_image == (Image *) NULL)
     return((Image *) NULL);
-  SetImage(affine_image,TransparentOpacity);
+  affine_image->background_color.opacity=TransparentOpacity;
+  SetImageBackgroundColor(affine_image);
   transform.sx=affine->sx;
   transform.rx=affine->rx;
   transform.ry=affine->ry;
@@ -515,6 +516,35 @@ static Image *IntegralRotateImage(const Image *image,unsigned long rotations,
 %      to shear.
 %
 */
+
+static inline MagickRealType Blend_(const MagickRealType p,
+  const MagickRealType alpha,const MagickRealType q,const MagickRealType beta)
+{
+  return((1.0-QuantumScale*alpha)*p+(1.0-QuantumScale*beta)*q);
+}
+
+static inline void MagickCompositeBlend(const PixelPacket *p,
+  const MagickRealType alpha,const PixelPacket *q,const MagickRealType beta,
+  const MagickRealType area,PixelPacket *composite)
+{
+  MagickRealType
+    gamma;
+
+  gamma=RoundToUnity((1.0-QuantumScale*(MaxRGB-(1.0-area)*(MaxRGB-alpha)))+
+    (1.0-QuantumScale*(MaxRGB-area*(MaxRGB-beta))));
+  composite->opacity=RoundToQuantum(MaxRGB*(1.0-gamma));
+  gamma=1.0/(fabs(gamma) <= MagickEpsilon ? 1.0 : gamma);
+  composite->red=RoundToQuantum(gamma*Blend_((MagickRealType) p->red,MaxRGB-
+    (1.0-area)*(MaxRGB-alpha),(MagickRealType) q->red,MaxRGB-area*
+    (MaxRGB-beta)));
+  composite->green=RoundToQuantum(gamma*Blend_((MagickRealType) p->green,MaxRGB-
+    (1.0-area)*(MaxRGB-alpha),(MagickRealType) q->green,MaxRGB-area*
+    (MaxRGB-beta)));
+  composite->blue=RoundToQuantum(gamma*Blend_((MagickRealType) p->blue,MaxRGB-
+    (1.0-area)*(MaxRGB-alpha),(MagickRealType) q->blue,MaxRGB-area*
+    (MaxRGB-beta)));
+}
+
 static inline void XShearImage(Image *image,const MagickRealType degrees,
   const unsigned long width,const unsigned long height,const long x_offset,
   long y_offset)
@@ -532,8 +562,8 @@ static inline void XShearImage(Image *image,const MagickRealType degrees,
     status;
 
   MagickRealType
-    displacement,
-    opacity;
+    area,
+    displacement;
 
   PixelPacket
     pixel;
@@ -564,7 +594,7 @@ static inline void XShearImage(Image *image,const MagickRealType degrees,
         direction=LEFT;
       }
     step=(long) floor((double) displacement);
-    opacity=MaxRGB*(MagickRealType) (displacement-step);
+    area=(MagickRealType) (displacement-step);
     step++;
     pixel=image->background_color;
     switch (direction)
@@ -589,12 +619,14 @@ static inline void XShearImage(Image *image,const MagickRealType degrees,
               q++;
               continue;
             }
-          MagickCompositeAtop(&pixel,opacity,p,(MagickRealType) p->opacity,q);
+          MagickCompositeBlend(&pixel,(MagickRealType) pixel.opacity,p,
+            (MagickRealType) p->opacity,area,q);
           q++;
           pixel=(*p++);
         }
-        MagickCompositeAtop(&pixel,opacity,&image->background_color,
-          (MagickRealType) image->background_color.opacity,q);
+        MagickCompositeBlend(&pixel,(MagickRealType) pixel.opacity,
+          &image->background_color,(MagickRealType)
+          image->background_color.opacity,area,q);
         q++;
         for (i=0; i < (step-1); i++)
           *q++=image->background_color;
@@ -616,13 +648,14 @@ static inline void XShearImage(Image *image,const MagickRealType degrees,
           q--;
           if ((unsigned long) (x_offset+width+step-i) >= image->columns)
             continue;
-          MagickCompositeAtop(&pixel,opacity,p,(MagickRealType)
-            p->opacity,q);
+          MagickCompositeBlend(&pixel,(MagickRealType) pixel.opacity,p,
+            (MagickRealType) p->opacity,area,q);
           pixel=(*p);
         }
         q--;
-        MagickCompositeAtop(&pixel,opacity,&image->background_color,
-          (MagickRealType) image->background_color.opacity,q);
+        MagickCompositeBlend(&pixel,(MagickRealType) pixel.opacity,
+          &image->background_color,(MagickRealType)
+          image->background_color.opacity,area,q);
         for (i=0; i < (step-1); i++)
           *--q=image->background_color;
         break;
@@ -693,8 +726,8 @@ static inline void YShearImage(Image *image,const MagickRealType degrees,
     status;
 
   MagickRealType
-    displacement,
-    opacity;
+    area,
+    displacement;
 
   register PixelPacket
     *p,
@@ -722,7 +755,7 @@ static inline void YShearImage(Image *image,const MagickRealType degrees,
         direction=UP;
       }
     step=(long) floor((double) displacement);
-    opacity=MaxRGB*(MagickRealType) (displacement-step);
+    area=(MagickRealType) (displacement-step);
     step++;
     pixel=image->background_color;
     switch (direction)
@@ -747,12 +780,14 @@ static inline void YShearImage(Image *image,const MagickRealType degrees,
               q++;
               continue;
             }
-          MagickCompositeAtop(&pixel,opacity,p,(MagickRealType) p->opacity,q);
+          MagickCompositeBlend(&pixel,(MagickRealType) pixel.opacity,p,
+            (MagickRealType) p->opacity,area,q);
           q++;
           pixel=(*p++);
         }
-        MagickCompositeAtop(&pixel,opacity,&image->background_color,
-          (MagickRealType) image->background_color.opacity,q);
+        MagickCompositeBlend(&pixel,(MagickRealType) pixel.opacity,
+          &image->background_color,(MagickRealType)
+          image->background_color.opacity,area,q);
         q++;
         for (i=0; i < (step-1); i++)
           *q++=image->background_color;
@@ -774,13 +809,14 @@ static inline void YShearImage(Image *image,const MagickRealType degrees,
           q--;
           if ((unsigned long) (y_offset+height+step-i) >= image->rows)
             continue;
-          MagickCompositeAtop(&pixel,opacity,p,(MagickRealType)
-            p->opacity,q);
+          MagickCompositeBlend(&pixel,(MagickRealType) pixel.opacity,p,
+            (MagickRealType) p->opacity,area,q);
           pixel=(*p);
         }
         q--;
-        MagickCompositeAtop(&pixel,opacity,&image->background_color,
-          (MagickRealType) image->background_color.opacity,q);
+        MagickCompositeBlend(&pixel,(MagickRealType) pixel.opacity,
+          &image->background_color,(MagickRealType)
+          image->background_color.opacity,area,q);
         for (i=0; i < (step-1); i++)
           *--q=image->background_color;
         break;
@@ -891,6 +927,8 @@ MagickExport Image *RotateImage(const Image *image,const double degrees,
   if ((shear.x == 0.0) && (shear.y == 0.0))
     return(integral_image);
   integral_image->storage_class=DirectClass;
+  if (integral_image->matte == MagickFalse)
+    SetImageOpacity(integral_image,OpaqueOpacity);
   /*
     Compute image size.
   */
@@ -901,9 +939,9 @@ MagickExport Image *RotateImage(const Image *image,const double degrees,
       width=image->rows;
       height=image->columns;
     }
-  x_offset=(long) (fabs(2.0*height*shear.y)+0.5);
-  y_width=(unsigned long) (fabs(height*shear.x)+width+0.5);
-  y_offset=(long) (fabs(y_width*shear.y)+0.5);
+  x_offset=(long) (fabs(2.0*(double) height*shear.y)+0.5);
+  y_width=(unsigned long) (fabs((double) height*shear.x)+width+0.5);
+  y_offset=(long) (fabs((double) y_width*shear.y)+0.5);
   /*
     Surround image with a border.
   */
@@ -917,14 +955,12 @@ MagickExport Image *RotateImage(const Image *image,const double degrees,
   /*
     Rotate the image.
   */
-  if (rotate_image->matte == MagickFalse)
-    SetImageOpacity(rotate_image,OpaqueOpacity);
   XShearImage(rotate_image,shear.x,width,height,x_offset,
-    (rotate_image->rows-(long) height)/2);
+    ((long) rotate_image->rows-height)/2);
   YShearImage(rotate_image,shear.y,y_width,height,
-    (rotate_image->columns-(long) y_width)/2,y_offset);
+    ((long) rotate_image->columns-y_width)/2,y_offset);
   XShearImage(rotate_image,shear.x,y_width,rotate_image->rows,
-    (rotate_image->columns-(long) y_width)/2,0);
+    ((long) rotate_image->columns-y_width)/2,0);
   CropToFitImage(&rotate_image,shear.x,shear.y,(MagickRealType) width,
     (MagickRealType) height,MagickTrue,exception);
   rotate_image->page.width=0;
@@ -998,7 +1034,9 @@ MagickExport Image *ShearImage(const Image *image,const double x_shear,
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),image->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
-  if ((fmod(x_shear,90.0) == 0.0) || (fmod(y_shear,90.0) == 0.0))
+  if ((x_shear != 0.0) && (fmod(x_shear,90.0) == 0.0))
+    ThrowImageException(ImageError,"AngleIsDiscontinuous");
+  if ((y_shear != 0.0) && (fmod(y_shear,90.0) == 0.0))
     ThrowImageException(ImageError,"AngleIsDiscontinuous");
   /*
     Initialize shear angle.
@@ -1011,12 +1049,15 @@ MagickExport Image *ShearImage(const Image *image,const double x_shear,
   if ((shear.x == 0.0) && (shear.y == 0.0))
     return(integral_image);
   integral_image->storage_class=DirectClass;
+  if (integral_image->matte == MagickFalse)
+    SetImageOpacity(integral_image,OpaqueOpacity);
   /*
     Compute image size.
   */
-  x_offset=(long) (fabs(image->rows*shear.x)+0.5);
-  y_width=(unsigned long) (fabs(image->rows*shear.x)+image->columns+0.5);
-  y_offset=(long) (fabs(y_width*shear.y)+0.5);
+  x_offset=(long) (fabs((double) image->rows*shear.x)+0.5);
+  y_width=(unsigned long)
+    (fabs((double) image->rows*shear.x)+image->columns+0.5);
+  y_offset=(long) (fabs((double) y_width*shear.y)+0.5);
   /*
     Surround image with border.
   */
@@ -1033,9 +1074,9 @@ MagickExport Image *ShearImage(const Image *image,const double x_shear,
   if (shear_image->matte == MagickFalse)
     SetImageOpacity(shear_image,OpaqueOpacity);
   XShearImage(shear_image,shear.x,image->columns,image->rows,x_offset,
-    (shear_image->rows-(long) image->rows)/2);
+    ((long) shear_image->rows-image->rows)/2);
   YShearImage(shear_image,shear.y,y_width,image->rows,
-    (shear_image->columns-(long) y_width)/2,y_offset);
+    ((long) shear_image->columns-y_width)/2,y_offset);
   CropToFitImage(&shear_image,shear.x,shear.y,(MagickRealType) image->columns,
     (MagickRealType) image->rows,MagickFalse,exception);
   shear_image->page.width=0;
