@@ -22,7 +22,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -289,7 +289,7 @@ MagickExport MagickBooleanType SignatureImage(Image *image)
     signature_info.digest[1],signature_info.digest[2],signature_info.digest[3],
     signature_info.digest[4],signature_info.digest[5],signature_info.digest[6],
     signature_info.digest[7]);
-  (void) SetImageAttribute(image,"Signature",(char *) NULL);
+  (void) DeleteImageAttribute(image,"Signature");
   (void) SetImageAttribute(image,"Signature",signature);
   return(MagickTrue);
 }
