@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -165,10 +165,12 @@ MagickExport MagickBooleanType AddValueToSplayTree(SplayTreeInfo *splay_info,
           ((splay_info->root->key < key) ? -1 : 0);
       if (compare == 0)
         {
-          if (splay_info->relinquish_key != (void *(*)(void *)) NULL)
+          if ((splay_info->relinquish_key != (void *(*)(void *)) NULL) &&
+              (splay_info->root->key != (void *) NULL))
             splay_info->root->key=
               splay_info->relinquish_key(splay_info->root->key);
-          if (splay_info->relinquish_value != (void *(*)(void *)) NULL)
+          if ((splay_info->relinquish_value != (void *(*)(void *)) NULL) &&
+              (splay_info->root->value != (void *) NULL))
             splay_info->root->value=
               splay_info->relinquish_value(splay_info->root->value);
           splay_info->root->key=(void *) key;
@@ -322,7 +324,7 @@ MagickExport int CompareSplayTreeString(const void *target,const void *source)
 
   p=(char *) target;
   q=(char *) source;
-  return(strcmp(p,q));
+  return(LocaleCompare(p,q));
 }
 
 /*
@@ -396,9 +398,11 @@ MagickExport SplayTreeInfo *DestroySplayTree(SplayTreeInfo *splay_info)
   if (splay_info->root == (NodeInfo *) NULL)
     return((SplayTreeInfo *) NULL);
   splay_info->semaphore=AcquireSemaphoreInfo(splay_info->semaphore);
-  if (splay_info->relinquish_key != (void *(*)(void *)) NULL)
+  if ((splay_info->relinquish_key != (void *(*)(void *)) NULL) &&
+      (splay_info->root->key != (void *) NULL))
     splay_info->root->key=splay_info->relinquish_key(splay_info->root->key);
-  if (splay_info->relinquish_value != (void *(*)(void *)) NULL)
+  if ((splay_info->relinquish_value != (void *(*)(void *)) NULL) &&
+      (splay_info->root->value != (void *) NULL))
     splay_info->root->value=
       splay_info->relinquish_value(splay_info->root->value);
   splay_info->root->key=(void *) NULL;
@@ -409,9 +413,11 @@ MagickExport SplayTreeInfo *DestroySplayTree(SplayTreeInfo *splay_info)
     {
       if (active->left != (NodeInfo *) NULL)
         {
-          if (splay_info->relinquish_key != (void *(*)(void *)) NULL)
+          if ((splay_info->relinquish_key != (void *(*)(void *)) NULL) &&
+              (active->left->key != (void *) NULL))
             active->left->key=splay_info->relinquish_key(active->left->key);
-          if (splay_info->relinquish_value != (void *(*)(void *)) NULL)
+          if ((splay_info->relinquish_value != (void *(*)(void *)) NULL) &&
+              (active->left->value != (void *) NULL))
             active->left->value=
               splay_info->relinquish_value(active->left->value);
           active->left->key=(void *) pend;
@@ -419,9 +425,11 @@ MagickExport SplayTreeInfo *DestroySplayTree(SplayTreeInfo *splay_info)
         }
       if (active->right != (NodeInfo *) NULL)
         {
-          if (splay_info->relinquish_key != (void *(*)(void *)) NULL)
+          if ((splay_info->relinquish_key != (void *(*)(void *)) NULL) &&
+              (active->right->key != (void *) NULL))
             active->right->key=splay_info->relinquish_key(active->right->key);
-          if (splay_info->relinquish_value != (void *(*)(void *)) NULL)
+          if ((splay_info->relinquish_value != (void *(*)(void *)) NULL) &&
+              (active->right->value != (void *) NULL))
             active->right->value=
               splay_info->relinquish_value(active->right->value);
           active->right->key=(void *) pend;
@@ -820,7 +828,7 @@ MagickExport SplayTreeInfo *NewSplayTree(
 %
 %  The format of the RemoveNodeByValueFromSplayTree method is:
 %
-%      void *RemoveNodeByValueFromSplayTree(SplayInfo *splay_info,
+%      MagickBooleanType RemoveNodeByValueFromSplayTree(SplayInfo *splay_info,
 %        const void *value)
 %
 %  A description of each parameter follows:
@@ -844,8 +852,8 @@ static void *GetFirstSplayTreeNode(SplayTreeInfo *splay_info)
   return(node->key);
 }
 
-MagickExport void *RemoveNodeByValueFromSplayTree(SplayTreeInfo *splay_info,
-  const void *value)
+MagickExport MagickBooleanType RemoveNodeByValueFromSplayTree(
+  SplayTreeInfo *splay_info,const void *value)
 {
   register NodeInfo
     *next,
@@ -856,7 +864,7 @@ MagickExport void *RemoveNodeByValueFromSplayTree(SplayTreeInfo *splay_info,
   if (splay_info->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
   if (splay_info->root == (NodeInfo *) NULL)
-    return((void *) NULL);
+    return(MagickFalse);
   splay_info->semaphore=AcquireSemaphoreInfo(splay_info->semaphore);
   for (next=GetFirstSplayTreeNode(splay_info); next != (void *) NULL; )
   {
@@ -876,7 +884,7 @@ MagickExport void *RemoveNodeByValueFromSplayTree(SplayTreeInfo *splay_info,
       }
   }
   RelinquishSemaphoreInfo(splay_info->semaphore);
-  return((void *) NULL);
+  return(MagickFalse);
 }
 
 /*
@@ -894,7 +902,8 @@ MagickExport void *RemoveNodeByValueFromSplayTree(SplayTreeInfo *splay_info,
 %
 %  The format of the RemoveNodeFromSplayTree method is:
 %
-%      void *RemoveNodeFromSplayTree(SplayInfo *splay_info,const void *key)
+%      MagickBooleanType RemoveNodeFromSplayTree(SplayInfo *splay_info,
+%        const void *key)
 %
 %  A description of each parameter follows:
 %
@@ -903,8 +912,8 @@ MagickExport void *RemoveNodeByValueFromSplayTree(SplayTreeInfo *splay_info,
 %    o key: The key.
 %
 */
-MagickExport void *RemoveNodeFromSplayTree(SplayTreeInfo *splay_info,
-  const void *key)
+MagickExport MagickBooleanType RemoveNodeFromSplayTree(
+  SplayTreeInfo *splay_info,const void *key)
 {
   int
     compare;
@@ -913,15 +922,12 @@ MagickExport void *RemoveNodeFromSplayTree(SplayTreeInfo *splay_info,
     *left,
     *right;
 
-  void
-    *value;
-
   assert(splay_info != (SplayTreeInfo *) NULL);
   assert(splay_info->signature == MagickSignature);
   if (splay_info->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
   if (splay_info->root == (NodeInfo *) NULL)
-    return((void *) NULL);
+    return(MagickFalse);
   splay_info->semaphore=AcquireSemaphoreInfo(splay_info->semaphore);
   SplaySplayTree(splay_info,key);
   splay_info->key=(void *) NULL;
@@ -933,18 +939,24 @@ MagickExport void *RemoveNodeFromSplayTree(SplayTreeInfo *splay_info,
   if (compare != 0)
     {
       RelinquishSemaphoreInfo(splay_info->semaphore);
-      return((void *) NULL);
+      return(MagickFalse);
     }
   left=splay_info->root->left;
   right=splay_info->root->right;
-  value=splay_info->root->value;
+  if ((splay_info->relinquish_key != (void *(*)(void *)) NULL) &&
+      (splay_info->root->key != (void *) NULL))
+    splay_info->root->key=splay_info->relinquish_key(splay_info->root->key);
+  if ((splay_info->relinquish_value != (void *(*)(void *)) NULL) &&
+      (splay_info->root->value != (void *) NULL))
+    splay_info->root->value=
+      splay_info->relinquish_value(splay_info->root->value);
   splay_info->root=(NodeInfo *) RelinquishMagickMemory(splay_info->root);
   splay_info->nodes--;
   if (left == (NodeInfo *) NULL)
     {
       splay_info->root=right;
       RelinquishSemaphoreInfo(splay_info->semaphore);
-      return(value);
+      return(MagickTrue);
     }
   splay_info->root=left;
   if (right != (NodeInfo *) NULL)
@@ -954,7 +966,7 @@ MagickExport void *RemoveNodeFromSplayTree(SplayTreeInfo *splay_info,
       left->right=right;
     }
   RelinquishSemaphoreInfo(splay_info->semaphore);
-  return(value);
+  return(MagickTrue);
 }
 
 /*
