@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -105,15 +105,12 @@ static const unsigned char
 %
 %  A description of each parameter follows:
 %
-%    o allocate_string:  Method AcquireString returns a copy of the source
-%      string.
-%
 %    o source: A character string.
 %
-%
 */
 
-static size_t CheckOverflowException(size_t length,size_t extend)
+static inline size_t CheckOverflowException(const size_t length,
+  const size_t extend)
 {
   if ((length+extend) < length)
     ThrowMagickFatalException(ResourceLimitFatalError,"UnableToAcquireString",
