@@ -5,7 +5,7 @@
   You may not use this file except in compliance with the License.
   obtain a copy of the License at
   
-    http://www.imagemagick.org/www/Copyright.html
+    http://www.imagemagick.org/script/license.php
   
   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
@@ -175,11 +175,6 @@ extern size_t
   strlcpy(char *,const char *,size_t);
 #endif
 
-#if defined(HAVE_VSNPRINTF) && !defined(HAVE_VSNPRINTF_PROTOTYPE)
-extern int
-  vsnprintf(char *,size_t,const char *,va_list);
-#endif
-
 #if !defined(magick_attribute)
 #  if !defined(__GNUC__)
 #    define magick_attribute(x)  /* nothing */
