@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -51,8 +51,10 @@
 #include "magick/memory_.h"
 #include "magick/list.h"
 #include "magick/monitor.h"
+#include "magick/pixel-private.h"
 #include "magick/resource_.h"
 #include "magick/resize.h"
+#include "magick/statistic.h"
 #include "magick/string_.h"
 #include "magick/transform.h"
 
@@ -279,7 +281,8 @@ MagickExport Image *CoalesceImages(const Image *image,ExceptionInfo *exception)
     MagickTrue,exception);
   if (coalesce_image == (Image *) NULL)
     return((Image *) NULL);
-  SetImage(coalesce_image,TransparentOpacity);
+  coalesce_image->background_color.opacity=TransparentOpacity;
+  SetImageBackgroundColor(coalesce_image);
   (void) CompositeImage(coalesce_image,image->matte != MagickFalse ?
     OverCompositeOp : CopyCompositeOp,image,image->page.x,image->page.y);
   previous_image=coalesce_image;
@@ -301,7 +304,10 @@ MagickExport Image *CoalesceImages(const Image *image,ExceptionInfo *exception)
         coalesce_image->next=CloneImage(coalesce_image,0,0,MagickTrue,
           exception);
         if (coalesce_image->next != (Image *) NULL)
-          SetImage(coalesce_image->next,TransparentOpacity);
+          {
+            coalesce_image->next->background_color.opacity=TransparentOpacity;
+            SetImageBackgroundColor(coalesce_image->next);
+          }
         break;
       }
       case PreviousDispose:
@@ -560,7 +566,8 @@ MagickExport Image *CropImage(const Image *image,const RectangleInfo *geometry,
       crop_image=CloneImage(image,1,1,MagickTrue,exception);
       if (crop_image == (Image *) NULL)
         return((Image *) NULL);
-      SetImage(crop_image,TransparentOpacity);
+      crop_image->background_color.opacity=TransparentOpacity;
+      SetImageBackgroundColor(crop_image);
       crop_image->page=bounding_box;
       crop_image->page.x=(-1);
       crop_image->page.y=(-1);
@@ -924,7 +931,7 @@ MagickExport Image *FlattenImages(const Image *image,ExceptionInfo *exception)
   flatten_image=CloneImage(image,page.width,page.height,MagickTrue,exception);
   if (flatten_image == (Image *) NULL)
     return((Image *) NULL);
-  SetImage(flatten_image,TransparentOpacity);
+  SetImageBackgroundColor(flatten_image);
   flatten_image->page=page;
   /*
     Flatten the images.
@@ -1219,7 +1226,7 @@ MagickExport Image *MosaicImages(const Image *image,ExceptionInfo *exception)
   mosaic_image=CloneImage(image,page.width,page.height,MagickTrue,exception);
   if (mosaic_image == (Image *) NULL)
     return((Image *) NULL);
-  SetImage(mosaic_image,OpaqueOpacity);
+  SetImageBackgroundColor(mosaic_image);
   mosaic_image->page=page;
   /*
     Mosaic the images.
