@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -773,8 +773,7 @@ static void *DestroyTypeNode(void *type_info)
     p->metrics=(char *) RelinquishMagickMemory(p->metrics);
   if (p->glyphs != (char *) NULL)
     p->glyphs=(char *) RelinquishMagickMemory(p->glyphs);
-  p=(TypeInfo *) RelinquishMagickMemory(p);
-  return((void *) NULL);
+  return(RelinquishMagickMemory(p));
 }
 
 static MagickBooleanType LoadTypeList(const char *xml,const char *filename,
