@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -53,6 +53,7 @@
 #include "magick/resource_.h"
 #include "magick/semaphore.h"
 #include "magick/signature.h"
+#include "magick/statistic.h"
 #include "magick/string_.h"
 #include "magick/token.h"
 #include "magick/utility.h"
@@ -733,9 +734,19 @@ MagickExport void FormatSize(const MagickSizeType size,char *format)
       (void) FormatMagickString(format,MaxTextExtent,"%.2fgb",length);
       break;
     }
+    case 4:
+    {
+      (void) FormatMagickString(format,MaxTextExtent,"%.2ftb",length);
+      break;
+    }
+    case 5:
+    {
+      (void) FormatMagickString(format,MaxTextExtent,"%.2fpb",length);
+      break;
+    }
     default:
     {
-      (void) FormatMagickString(format,MaxTextExtent,"%.3ftb",length);
+      (void) FormatMagickString(format,MaxTextExtent,"%.3feb",length);
       break;
     }
   }
@@ -1268,7 +1279,7 @@ MagickExport int SystemCommand(const MagickBooleanType verbose,
 #if defined(POSIX)
   status=system(command);
 #elif defined(__WINDOWS__)
-  status=NTSystemComman(command);
+  status=NTSystemCommand(command);
 #elif defined(macintosh)
   status=MACSystemCommand(command);
 #elif defined(vms)
@@ -1546,9 +1557,15 @@ MagickExport char *TranslateText(const ImageInfo *image_info,Image *image,
       }
       case 'r':
       {
+        ColorspaceType
+          colorspace;
+
+        colorspace=image->colorspace;
+        if (IsGrayImage(image,&image->exception) != MagickFalse)
+          colorspace=GRAYColorspace;
         (void) FormatMagickString(q,MaxTextExtent,"%s%s%s",
           MagickOptionToMnemonic(MagickClassOptions,(long) image->storage_class),
-          MagickOptionToMnemonic(MagickColorspaceOptions,(long) image->colorspace),
+          MagickOptionToMnemonic(MagickColorspaceOptions,(long) colorspace),
           image->matte != MagickFalse ? "Matte" : "");
         while (*q != '\0')
           q++;
