@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -42,18 +42,18 @@
 #include "magick/studio.h"
 #include "magick/exception.h"
 #include "magick/exception-private.h"
-#include "magick/hashmap.h"
 #include "magick/log.h"
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/semaphore.h"
+#include "magick/splay-tree.h"
 #include "magick/string_.h"
 #include "magick/utility.h"
 #include "wand/magick-wand.h"
 #include "wand/wand.h"
 
-static LinkedListInfo
-  *wand_ids = (LinkedListInfo *) NULL;
+static SplayTreeInfo
+  *wand_ids = (SplayTreeInfo *) NULL;
 
 static MagickBooleanType
   instantiate_magick = MagickFalse;
@@ -85,21 +85,22 @@ WandExport unsigned long AcquireWandId(void)
   static unsigned long
     id = 0;
 
-  if (wand_ids == (LinkedListInfo *) NULL)
+  if (wand_ids == (SplayTreeInfo *) NULL)
     {
       wand_semaphore=AcquireSemaphoreInfo(wand_semaphore);
-      if (wand_ids == (LinkedListInfo *) NULL)
-        wand_ids=NewLinkedList(0);
+      if (wand_ids == (SplayTreeInfo *) NULL)
+        wand_ids=NewSplayTree((int (*)(const void *,const void *)) NULL,
+          (void *(*)(void *)) NULL,(void *(*)(void *)) NULL);
       instantiate_magick=IsMagickInstantiated();
       RelinquishSemaphoreInfo(wand_semaphore);
     }
   if ((instantiate_magick == MagickFalse) &&
-      (IsLinkedListEmpty(wand_ids) == MagickTrue))
+      (GetNumberOfNodesInSplayTree(wand_ids) == 0))
     InitializeMagick((char *) NULL);
   wand_semaphore=AcquireSemaphoreInfo(wand_semaphore);
   id++;
   RelinquishSemaphoreInfo(wand_semaphore);
-  (void) AppendValueToLinkedList(wand_ids,(const void *) id);
+  (void) AddValueToSplayTree(wand_ids,(const void *) id,(const void *) id);
   return(id);
 }
 
@@ -129,16 +130,16 @@ WandExport unsigned long AcquireWandId(void)
 WandExport void RelinquishWandId(const unsigned long id)
 {
   (void) LogMagickEvent(WandEvent,GetMagickModule(),"...");
-  (void) RemoveElementByValueFromLinkedList(wand_ids,(const void *) id);
+  if (wand_ids == (SplayTreeInfo *) NULL)
+    return;
+  (void) RemoveNodeByValueFromSplayTree(wand_ids,(const void *) id);
   if ((instantiate_magick != MagickFalse) ||
-      (IsLinkedListEmpty(wand_ids) != MagickTrue))
+      (GetNumberOfNodesInSplayTree(wand_ids) != 0))
     return;
   wand_semaphore=AcquireSemaphoreInfo(wand_semaphore);
   DestroyMagick();
-  (void) DestroyLinkedList(wand_ids,(void *(*)(void *)) NULL);
-  wand_ids=(LinkedListInfo *) NULL;
+  wand_ids=DestroySplayTree(wand_ids);
   instantiate_magick=MagickFalse;
   RelinquishSemaphoreInfo(wand_semaphore);
   wand_semaphore=DestroySemaphoreInfo(wand_semaphore);
-  wand_semaphore=(SemaphoreInfo *) NULL;
 }
